<?php
/*
--------------------------------------------------------------------------
This file is part of the WP Events Calendar project.

For questions, help, comments, discussion, etc., please join our
forum at {@link http://www.wp-eventscalendar.com/forum}. You can
also go to Luke's ({@link http://www.lukehowelll.com}) and
Heirem's ({@link http://heirem.fr}) blogs.

WP Events Calendar is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.   See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
--------------------------------------------------------------------------
*/

/**
 * This file contains the WP Events Calendar Days Events Display Manager class.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @author        Luke and brad are the original authors of the WP Events Calendar
 *                plugin. Ren is the man behing the 7.0 version.
 *
 *                - Luke Howell <luke@wp-eventscalendar.com>
 *                - Brad Bodine <brad@wp-eventscalendar.com>
 *                - Ren MALKA <heirem@wp-eventscalendar.com>
 *
 * @link          For more information regarding WP events calendar,
 *                please visit our site and our team members's site.
 *
 *                - http://wp-eventscalendar.com/
 *                - http://www.lukehowell.com
 *                - http://myboxtool.com/
 *                - http://heirem.fr
 *                - http://laplix.com
 *                - http://www.gwathneydesign.com/
 *
 * @since         6.0
 * @copyright     WP Events Calendar is
 *
 *                - Copyright (c) 2007-2009 Luke Howell
 *                - Copyright (c) 2007-2009 Brad Bodine
 *                - Copyright (c) 2008-2009 Ren Malka
 *                - Copyright (c)      2009 Louis Lapointe
 *                - Copyright (c)      2009 Coe Gwathney
 * @license       GPLv3 {@link http://www.gnu.org/licenses/gpl}
 * @filesource
 *
 */ 

if(!class_exists('EC_ajaxDay')):

/**
 * Displays the events of a day in a thickbox fashion.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @since         6.0
 */
class EC_ajaxDay {

   /**
    * Holds the EC_DB database object.
    * @var object
    * @access private
    */
   var $db;

   /**
    * Initialization.
    * @access public
    */
  function EC_ajaxDay() {
    //require_once(ABSWPINCLUDE.'/pluggable.php');
    $this->db = new EC_DB();
  }

   /**
    * Display a day events.
    *
    * @param date    $d          date of the day to display
    * @param string  $recc       yes or no to display recurring events
    *
    * @global array              the months names.
    * @global string             Holds the week days first letter
    *
    * @todo Are we missing a </div> here? I see this: <div id="EC_daysEvents"> 
    *       but I don't the closing </div. Am I missing something? --laplix
    * @todo Shouldn't the $recc parameter be a boolean? --laplix
    * @access public
    */
  function ajaxDisplay($d) {
    wpec_get_option($this, 'wpecOptionsLc');
    wpec_get_option($this, 'wpecOptionsEv');
    wpec_get_option($this,'wpecOptionsTypes');    
    $tbdf = explode('=',$this->ecopt_lc_tbdf); $tbdf = $tbdf[1];
    $tbtf = explode('=',$this->ecopt_lc_tbtf); $tbtf = $tbtf[1];
    $flag = false; $ajaxEvent = array(); 
    // Gest list of Types colors 
    $this->typesList = mb_unserialize(stripslashes($this->ecopt_sertypes));
    $colorTypesFlag = ($this->typesList != false);
    if($colorTypesFlag) {
      $colorTypes = array(); 
      $eventTypes = array();
      $c = count($this->typesList);
      for($i=1;$i<$c;$i++) {
        $colorTypes[$this->typesList[$i]['tid']] = $this->typesList[$i]['col'];
        $eventTypes[$this->typesList[$i]['tid']] = $this->typesList[$i]['des'];
      }
    }
    $events = $this->db->getDaysEvents($d, true);
    foreach($events as $e) {
      if(($e->accessLevel == 'public') || (current_user_can($e->accessLevel))) {
        $recurrStatus = isset($e->eventRecStatus) ? $e->eventRecStatus : '';
        $recStatusFlag = $recurrStatus ;
        $recProces = $e->eventRecProces;
        $recExcept = $e->eventExceptions;        
        $startDate = isset($e->eventStartDate) ? $e->eventStartDate : '';
        $endTime = isset($e->eventEndTime) ? $e->eventEndTime : '';        
        if ($recurrStatus && $startDate) $recurrStatus = reccurEventokToDisplay($d, $startDate, $recurrStatus, $recProces, $recExcept);
        if ($recurrStatus) continue;
        elseif($recStatusFlag>0) {
          $optVar = 'ecopt_ev_rec'.$recStatusFlag;
          $recColor = $this->$optVar;
        } else $recColor = '';
        $flag = true;        
        if($colorTypesFlag && isset($e->eventType) && $e->eventType != 'evt1') { 
          $eventType = $eventTypes[$e->eventType]; $evtColorType = $colorTypes[$e->eventType];
        } else $eventType = $evtColorType = '';
        $title = $e->eventTitle;
        $location = isset($e->eventLocation) ? $e->eventLocation:'';
        $PostID = isset($e->postID) ? $e->postID : '';
        $linkout = isset($e->eventLinkout) ? $e->eventLinkout : '';
        list($ec_startyear, $ec_startmonth, $ec_startday) = explode("-", $startDate);
        if(!is_null($e->eventStartTime) && !empty($e->eventStartTime)) {
          list($ec_starthour, $ec_startminute, $ec_startsecond) = explode(":", $e->eventStartTime);
          $startTime = wpec_date_i18n($tbtf, mktime($ec_starthour, $ec_startminute, $ec_startsecond, $ec_startmonth, $ec_startday, $ec_startyear),true);
        } else $startTime = null;
        $startDate = wpec_date_i18n($tbdf, mktime($ec_starthour, $ec_startminute, $ec_startsecond, $ec_startmonth, $ec_startday, $ec_startyear),true);
        list($ec_endyear, $ec_endmonth, $ec_endday) = explode("-", $e->eventEndDate);
        if($e->eventEndTime != null && !empty($e->eventEndTime)) {
          list($ec_endhour, $ec_endminute, $ec_endsecond) = explode(":", $e->eventEndTime);
          $endTime = wpec_date_i18n($tbtf, mktime($ec_endhour, $ec_endminute, $ec_endsecond, $ec_endmonth, $ec_endday, $ec_endyear),true);
        } else $endTime = null;
        $endDate = wpec_date_i18n($tbdf, mktime($ec_endhour, $ec_endminute, $ec_endsecond, $ec_endmonth, $ec_endday, $ec_endyear),true);
        if ($PostID != '') {
          $IDtmp = get_post($PostID);
          $ptitle = $IDtmp->post_title;
          $perlink = get_permalink($PostID);
        }         
        $ajaxEvent[] = array(
          'title'     => $title,
          'location'  => $location,
          'startDate' => $startDate,
          'endDate'   => $endDate,
          'startTime' => $startTime,
          'endTime'   => $endTime,
          'eventType' => $eventType,  
          'evtColorType'  => $evtColorType,  
          'recurrStatus'  => $recStatusFlag,
          'recProces'     => $recProces,
          'recColor'      => $recColor,  
          'linkout'       => $linkout
        );
        
        if($PostID) {
          $c = count($ajaxEvent)-1;
          $ajaxEvent[$c]['ptitle'] = $ptitle;
          $ajaxEvent[$c]['perlink'] = $perlink;
        }
      } // if      
    } // for each
    if($flag) {
      if(phpversion()<5) echo array_to_json($ajaxEvent); 
      else echo json_encode($ajaxEvent);      
    } else echo '[{ title: "none" }]';
  } // function display
}
endif;
?>
