<?php
/*
--------------------------------------------------------------------------
This file is part of the WP Events Calendar project.

For questions, help, comments, discussion, etc., please join our
forum at {@link http://www.wp-eventscalendar.com/forum}. You can
also go to Luke's ({@link http://www.lukehowelll.com}) and
Heirem's ({@link http://heirem.fr}) blogs.

WP Events Calendar is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.   See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
--------------------------------------------------------------------------
*/

/**
 * This file contains the WP Events Calendar Days Events Display Manager class.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @author        Luke and brad are the original authors of the WP Events Calendar
 *                plugin. Ren is the man behing the 7.0 version.
 *
 *                - Luke Howell <luke@wp-eventscalendar.com>
 *                - Brad Bodine <brad@wp-eventscalendar.com>
 *                - Ren MALKA <heirem@wp-eventscalendar.com>
 *
 * @link          For more information regarding WP events calendar,
 *                please visit our site and our team members's site.
 *
 *                - http://wp-eventscalendar.com/
 *                - http://www.lukehowell.com
 *                - http://myboxtool.com/
 *                - http://heirem.fr
 *                - http://laplix.com
 *                - http://www.gwathneydesign.com/
 *
 * @since         6.0
 * @copyright     WP Events Calendar is
 *
 *                - Copyright (c) 2007-2009 Luke Howell
 *                - Copyright (c) 2007-2009 Brad Bodine
 *                - Copyright (c) 2008-2009 Ren Malka
 *                - Copyright (c)      2009 Louis Lapointe
 *                - Copyright (c)      2009 Coe Gwathney
 * @license       GPLv3 {@link http://www.gnu.org/licenses/gpl}
 * @filesource
 *
 */ 

if(!class_exists('EC_Day')):

/**
 * Displays the events of a day in a thickbox fashion.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @since         6.0
 */
class EC_Day {

   /**
    * Holds the EC_DB database object.
    * @var object
    * @access private
    */
   var $db;

   /**
    * Initialization.
    * @access public
    */
  function EC_Day() {
    //require_once(ABSWPINCLUDE.'/pluggable.php');
    $this->db = new EC_DB();
  }

   /**
    * Display a day events.
    *
    * @param date    $d          date of the day to display
    * @param string  $recc       yes or no to display recurring events
    *
    * @global array              the months names.
    * @global string             Holds the week days first letter
    *
    * @todo Are we missing a </div> here? I see this: <div id="EC_daysEvents"> 
    *       but I don't the closing </div. Am I missing something? --laplix
    * @todo Shouldn't the $recc parameter be a boolean? --laplix
    * @access public
    */
  function display($d, $recc) {
    global $ec_MonthNames, $ec_WeekdayString;
    ?>
    <link type="text/css" rel="stylesheet" href="<?php bloginfo('wpurl');?>/wp-includes/js/thickbox/thickbox.css" />
    <link type="text/css" rel="stylesheet" href="<?php echo EVENTSCALENDARCSSURL;?>/events-calendar.css" />
    <?php    
    $options = get_option('optionsEventsCalendar');
    $events = $this->db->getDaysEvents($d, ($recc == 'yes'));
    list($ec_year, $ec_month, $ec_day) = explode('-', $d);
    ?>
      <div id="EC_daysEvents">
    <?php
    foreach($events as $event) {
      if(($event->accessLevel == 'public') || (current_user_can($event->accessLevel))) {
        $title = stripslashes($event->eventTitle);
        $description = preg_replace('#\r?\n#', '<br />', $event->eventDescription);
        $description = stripslashes($description);
        $location = stripslashes($event->eventLocation);
        $PostID = isset($event->postID) ? $event->postID : '';
        $linkout = isset($event->eventLinkout) ? $event->eventLinkout : '';
        $recurrStatus = isset($event->eventRecStatus) ? $event->eventRecStatus : '';
        list($ec_startyear, $ec_startmonth, $ec_startday) = explode('-', $event->eventStartDate);
        if(!is_null($event->eventStartTime) && !empty($event->eventStartTime)) {
          list($ec_starthour, $ec_startminute, $ec_startsecond) = explode(":", $event->eventStartTime);
          $startTime = date($options['timeFormatWidget'], mktime($ec_starthour, $ec_startminute, $ec_startsecond, $ec_startmonth, $ec_startday, $ec_startyear));
        } else $startTime = null;
        $startDate = date($options['dateFormatWidget'], mktime($ec_starthour, $ec_startminute, $ec_startsecond, $ec_startmonth, $ec_startday, $ec_startyear));
        list($ec_endyear, $ec_endmonth, $ec_endday) = explode('-', $event->eventEndDate);
        if($event->eventEndTime != null && !empty($event->eventEndTime)) {
          list($ec_endhour, $ec_endminute, $ec_endsecond) = explode(":", $event->eventEndTime);
          $endTime = date($options['timeFormatWidget'], mktime($ec_endhour, $ec_endminute, $ec_endsecond, $ec_endmonth, $ec_endday, $ec_endyear));
        } else $endTime = null;
        $endDate = date($options['dateFormatWidget'], mktime($ec_endhour, $ec_endminute, $ec_endsecond, $ec_endmonth, $ec_endday, $ec_endyear));
        // Title
        $output = '<p>'."\n".'<div for="EC_title" class="EC_title"><strong>&nbsp;'.$title.'</strong></div>'."\n";
        // If Location
        if(!empty($location) || !is_null($location))
          $output .= '<div for="EC_location" class="EC_location"><strong>&nbsp;'._c('Location','events-calendar').':</strong> '.$location.'</div>'."\n";
        // start time
        $output .='<div for="EC_time" class="EC_time"><strong>&nbsp;'.$startTime.'</strong>&nbsp;';
        // end Time
        if((!empty($endTime) && !empty($startTime)) || (!is_null($endTime) && !is_null($startTime)))
          $output .= _c('to','events-calendar').'<strong>&nbsp;'.$endTime.'</strong>';
        // Description
        $output .= '</div><div for="EC_description" class="EC_description">&nbsp;'.$description.'</div>'."\n";
        if ($recurrStatus > 0) {
          $recProces = $event->eventRecProces;
          $output .= "<strong>"._c('Recurrence','events-calendar').": </strong>";
          switch ($recurrStatus) {
            case 1: // A day in the month
              $recparam1 = $recProces;
              $output .= sprintf(__('Every %s / month','events-calendar'),$recparam1);
              break;
            case 2: // Every X days
              $recparam1 = $recProces;
              $output .= sprintf(__('Every %s days','events-calendar'),$recparam1);
              break;
            case 3: // Every some weekdays
              $recparam1 = '';
              $recProces = unserialize($recProces);
              foreach ($recProces as $value) $recparam1 .= substr($ec_WeekdayString, $value, 1)." ";
              $output .= sprintf(__('Every %s','events-calendar'),$recparam1);
              break;
            case 4: // Every some weeks in the month
              $recparam1 = '';
              $recProces = unserialize($recProces);
              foreach ($recProces as $value) {
               if ($value == '5') $recparam1 .= _c('last','events-calendar'); else $recparam1 .= "#".$value." ";
              }
              $output .= sprintf(__('Every %s week','events-calendar'),$recparam1);
              break;
            case 6: // Every X days in somes weeks in the month
              $recparam2 = '';
              list($recparam1, $recpartmp)  = explode('|', $recProces);
              $recpartmp = unserialize($recpartmp);
              foreach ($recpartmp as $value) {
               if ($value == '5') $recparam2 .= _c('last','events-calendar'); else $recparam2 .= "#".$value." ";
              }
              $output .= sprintf(__('Every %s days, %s week','events-calendar'),$recparam1,$recparam2);
              break;
            case 7: // Every some weekdays in somes weeks in the month
              $recparam1 = ''; $recparam2 = '';
              list($recpartmp, $recpartmp1)  = explode('|', $recProces);
              $recpartmp = unserialize($recpartmp);
              $recpartmp1 = unserialize($recpartmp1);
              foreach ($recpartmp as $value) $recparam1 .= substr($ec_WeekdayString, $value, 1)." ";
              foreach ($recpartmp1 as $value) {
               if ($value == '5') $recparam2 .= _c('last','events-calendar'); else $recparam2 .= "#".$value." ";
              }
              $output .= sprintf(__('Every %s, %s week','events-calendar'),$recparam1,$recparam2);
              break;
          }
          $output .= "<br />";
        }
        // If Star Date <> End Date
        if($event->eventStartDate != $event->eventEndDate )
          $output .= '<div for="EC_date" class="EC_date"><strong>'._c('Date range','events-calendar').'</strong></div><center>'._c('Since','events-calendar').'&nbsp;'.$startDate.'&nbsp;'._c('until','events-calendar').'&nbsp;'.$endDate.'</center>'."\n";
        // Link outside the site if the link exist
        if ($linkout != '')
          $output .= '<div for="EC_linkout" class="EC_date"><strong>'._c('Link out','events-calendar').'</strong></div><center><a href="'.$linkout.'" target="_parent">'.substr($linkout,0,19).'</a></center>';
        // Link to a post when exist
        if ($PostID != '') {
          $IDtmp = get_post($PostID);
          $ptitle = $IDtmp->post_title;
          $output .= '<div for="EC_postid" class="EC_date"><strong>'._c('Post','events-calendar').' ('.$PostID.')</strong></div><a href="'.get_permalink($PostID).'" target="_parent"/>'.addslashes($ptitle).'</a><br />';
        }
        echo $output;
      } // if
    } // for each
  } // function display
}
endif;
?>
