<?php
/*
--------------------------------------------------------------------------
This file is part of the WP Events Calendar project.

For questions, help, comments, discussion, etc., please join our
forum at {@link http://www.wp-eventscalendar.com/forum}. You can
also go to Luke's ({@link http://www.lukehowelll.com}) and
Heirem's ({@link http://heirem.fr}) blogs.

WP Events Calendar is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.   See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
--------------------------------------------------------------------------
*/

/**
 * This file contains the WP Events Calendar functions library.
 *
 * Long description to be done.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @author
 *                - Luke Howell <luke@wp-eventscalendar.com>
 *                - Brad Gwathney <coe@wp-eventscalendar.com>
 *                - Ren MALKA <heirem@wp-eventscalendar.com>
 * @link
 *                - http://wp-eventscalendar.com/
 *                - http://www.lukehowell.com
 *                - http://myboxtool.com/
 *                - http://heirem.fr
 *                - http://laplix.com
 *                - http://www.gwathneydesign.com/
 * @since         1.0
 * @copyright
 *                - Copyright (c) 2007-2009 Luke Howell
 *                - Copyright (c) 2007-2009 Brad Bodine
 *                - Copyright (c) 2008-2009 Ren Malka
 *                - Copyright (c)      2009 Louis Lapointe
 *                - Copyright (c)      2009 Coe Gwathney
 * @license       GPLv3 {@link http://www.gnu.org/licenses/gpl}
 * @filesource
 *
 */

/*---------------------------------------*/
/* Loading functions necessary according */
/* to the administration or not          */
/*---------------------------------------*/
if (is_admin()) {
/**
 ****  Dedicaced to PHP 4.x ****
 * Converts an associative array of arbitrary depth and dimension into JSON representation.
 * NOTE: If you pass in a mixed associative and vector array, it will prefix each numerical
 * key with "key_". For example array("foo", "bar" => "baz") will be translated into
 * {'key_0': 'foo', 'bar': 'baz'} but array("foo", "bar") would be translated into [ 'foo', 'bar' ].
 *
 * @param $array The array to convert.
 * @return mixed The resulting JSON string, or false if the argument was not an array.
 * @author Andy Rusterholz
 */
if(phpversion()<5) {
  function array_to_json( $array ){
    if(!is_array( $array )) return false;
    $associative = count( array_diff( array_keys($array), array_keys( array_keys( $array )) ));
    if( $associative ){
        $construct = array();
        foreach( $array as $key => $value ){
            // We first copy each key/value pair into a staging array,
            // formatting each key and value properly as we go.
            // Format the key:
            if( is_numeric($key) ){
                $key = "key_$key";
            }
            $key = "'".addslashes($key)."'";
            // Format the value:
            if( is_array( $value )){
                $value = array_to_json( $value );
            } else if( !is_numeric( $value ) || is_string( $value ) ){
                $value = "'".addslashes($value)."'";
            }
            // Add to staging array:
            $construct[] = "$key: $value";
        }
        // Then we collapse the staging array into the JSON form:
        $result = "{ " . implode( ", ", $construct ) . " }";
    } else { // If the array is a vector (not associative):
        $construct = array();
        foreach( $array as $value ){
            // Format the value:
            if( is_array( $value )){
                $value = array_to_json( $value );
            } else if( !is_numeric( $value ) || is_string( $value ) ){
                $value = "'".addslashes($value)."'";
            }
            // Add to staging array:
            $construct[] = $value;
        }
        // Then we collapse the staging array into the JSON form:
        $result = "[ " . implode( ", ", $construct ) . " ]";
    }
    return $result;
  }
}
 /**
  * Debuging : function to make JSON strings more readable. It's very useful for debugging JSON output...
  */
  function jsonReadable($json, $html=FALSE) {
      $tabcount = 0;
      $result = '';
      $inquote = false;
      $ignorenext = false;
      if ($html) {
          $tab = "&nbsp;&nbsp;&nbsp;";
          $newline = "<br/>";
      } else {
          $tab = "\t";
          $newline = "\n";
      }
      for($i = 0; $i < strlen($json); $i++) {
          $char = $json[$i];
          if ($ignorenext) {
              $result .= $char;
              $ignorenext = false;
          } else {
              switch($char) {
                  case '{':
                      $tabcount++;
                      $result .= $char . $newline . str_repeat($tab, $tabcount);
                      break;
                  case '}':
                      $tabcount--;
                      $result = trim($result) . $newline . str_repeat($tab, $tabcount) . $char;
                      break;
                  case ',':
                      $result .= $char . $newline . str_repeat($tab, $tabcount);
                      break;
                  case '"':
                      $inquote = !$inquote;
                      $result .= $char;
                      break;
                  case '\\':
                      if ($inquote) $ignorenext = true;
                      $result .= $char;
                      break;
                  default:
                      $result .= $char;
              }
          }
      }
      return $result;
  }

 /**
  * This function gets called when activating the plugin.
  *
  * The function creates the eventscalendar_main table and then
  * calls {@link initOptions()} to initialize and populate the
  * admin panel options.
  */
  function EventsCalendarActivated() {
    $db = new EC_DB();
    $db->createTable();
    $db->initOptions();
  }

  /**
   * Access Level treatment. Returns the translated string.
   *
   * @param string $al_value       Contains the acces level of the currently
   *                               logged in user.
   * @return string              The translated user role
   */
  function ec_convAccessLevel($al_value) {
    switch ($al_value) {
      case 'public':
        return _c('Public','events-calendar');
      case 'level_10' : case 'level_8' : case 'level_9' :
        return _c('Administrator','events-calendar');
      case 'level_7': case 'level_6': case 'level_5': case 'level_4': case 'level_3':
        return _c('Editor','events-calendar');
      case 'level_2':
        return _c('Author','events-calendar');
      case 'level_1':
        return _c('Contributor','events-calendar');
      case 'level_0':
        return _c('Subscriber','events-calendar');
    }
  }
  /**
   * Ajax Entry for getting cust field names in events management
   *
   * @return echo jSON format           The liste of the field names for a get type id
   */
  function ajaxGetCustFieldNames() {
    $option = get_option('wpecOptionsTypes');
    if(!isset($_GET['EC_tid']) || $_GET['EC_tid'] == '' || $option == false) exit();
    $custFieldName = array();
    $typesList = mb_unserialize(stripslashes($option));
    $c = count($typesList);
    for($i=0;$i<$c;$i++) {
      $evType = $typesList[$i];
      if($evType['tid'] == $_GET['EC_tid']) {
        $custFieldName = explode(';',$evType['cus']);
      }
    }
    if(!empty($custFieldName)) {
      echo <<<HERE_DOC
[ {custFieldName: "$custFieldName[0]"},
  {custFieldName: "$custFieldName[1]"},
  {custFieldName: "$custFieldName[2]"},
  {custFieldName: "$custFieldName[3]"},
  {custFieldName: "$custFieldName[4]"},
  {custFieldName: "$custFieldName[5]"} ]
HERE_DOC;
}
  }
  /**
   * DatePicker localisation (jQuery plugin in Add and Update Events) NOT a FUNCTION
   * @global string $loc_lang
   */
  $locale = get_locale();
  if (in_array($locale, array('pt_BR','zh_TW','zh_CN'),false)) {
    $loc_lang=str_replace('_','-',$locale);
  } else {
    $loc_lang = explode("_",$locale); $loc_lang = $loc_lang[0];
    if (!in_array($loc_lang, array('ar','bg','ca','cs','da','de','es','fi','fr','he','hu','hy','id','is','it','ja','ko','lt','lv','nl','no','pl','ro','ru','sk','sv','th','tr','uk'),false)) $loc_lang='en';
  }

} else {
/*----------------------------------------*/
/* Functions needed in the front end blog */
/* When we are NOT in the admin mode      */
/*----------------------------------------*/
   /**
    * Returns part of $haystack.
    *
    * If $needle is found, the function will return it if $before_needle
    * is set to FALSE (default) or will return everything before $needle
    * if $before_needle is TRUE.
    *
    * @param string $haystack       Content where to search for $needle.
    * @param string $needle          Content to search for.
    * @param bool   $before_needle    If TRUE, will return everything before $needle.
    *                               If FALSE, will return $needle.
    *                               Defaults to false.
    * @return FALSE|string          Part of $haystack or FALSE if $needle was not found.
    *
      */
     function ec_strstr($haystack, $needle, $before_needle=FALSE) {
      if(($pos=strpos($haystack,$needle))===FALSE) return FALSE;
      if($before_needle) return substr($haystack,0,$pos);
       else return substr($haystack,$pos+strlen($needle));
     }

   /**
    * Replace [[EventsCalendarLarge]] by the Large Calendar in a post.
    *
    * If the short tag is present, the function will display any text that is
    * preceding the tag and then display the large calendar.
    *
    * @param string $content       The post data that may contain the
    *                            [[EventsCalendarLarge]] short tag.
    * @return string             Returns either the post if there no short tag or
    *                            the short tag itself.
   */
   function filterEventsCalendarLarge($content) {
    if(preg_match('[EventsCalendarLarge]',$content)) {
      class_exists('EC_LCalendar') || require(EVENTSCALENDARCLASSPATH.'/ec_large-calendar.class.php');
      $lcalendar = new EC_LCalendar();
      $ec_match_filter = '[[EventsCalendarLarge]]';
      $before_large_calendar = ec_strstr($content, $ec_match_filter, TRUE);
      if (function_exists('do_shortcode')) $before_large_calendar= do_shortcode($before_large_calendar); // Suggest by James Collins
      $content = ec_strstr($content, $ec_match_filter, FALSE);
      $lcalendar->displayLarge(date('Y'), date('m'), $before_large_calendar);
    }
    return $content;
   }

  /**
  * Insert the Little Calendar in the sidebar.
  * Only needed when the Wordpress theme is NOT widget ready.
  */
  function SidebarEventsCalendar() {
    class_exists('EC_WCalendar') || require(EVENTSCALENDARCLASSPATH.'/ec_widget-calendar.class.php');
    $calendar = new EC_WCalendar();
    $calendar->displayWidget(date('Y'), date('m'));
  }
  /**
   * Insert the Events List in the sidebar
   * Only needed when the Wordpress theme is NOT widget ready
   *
   * @param int $d       number of items to show.
   */
  function SidebarEventsList($d){
    class_exists('EC_EventList') || require(EVENTSCALENDARCLASSPATH.'/ec_event-list.class.php');
    $calendar= new EC_EventList();
    $calendar->displayEventList($d);
  }
} // End of the: if is_admin()

/*----------------------------------------*/
/* Common functions for all the plugin    */
/*----------------------------------------*/
 /**
 * Unserialize with utf8 content get trouble and the code provided here works fine.
 * Thanx to http://www.idealog.us/2009/02/php-unserialize-bug-returns-false-with-single-quote-or-newline.html
 * @param   string    $serial_str         The string to unserialze
 * @return  object or false               The string unserialized of false if unsuccessfull
 */
function mb_unserialize($serial_str) {
  if (DB_CHARSET == 'utf8') $out = preg_replace('!s:(\d+):"(.*?)";!se', "'s:'.strlen('$2').':\"$2\";'", $serial_str );
  else $out = $serial_str;
  return unserialize($out);
}
/**
 * Return a WpEc default option WITHOUT PARSING
 * @param string    $setting            The option block name
 * @param boolean   $enforce            If true and the block allready exist return the option else return false
 */
function wpec_get_defoption($setting, $enforce = false) {
  if(!$enforce && get_option($setting)) return false;
  $btmsg = _c('Click date for more details','events-calendar');
  $yesno = explode(':',_c('Yes:No','events-calendar'));
  $yes = $yesno[0]; $yeslen = strlen($yes);
  $no = $yesno[1]; $nolen = strlen($no);
  $noeventype = _c('No Event Type','events-calendar'); $noeventypelen = strlen($noeventype);
  $none = _c('None','events-calendar'); $nonelen = strlen($none);
  $field = _c('Field','events-calendar'); $fieldlen = (6*strlen($field))+23;
  $swcal = _c('Switch calendar','events-calendar'); $swcallen = strlen($swcal);
  $filter= _c('Filter','events-calendar'); $filterlen = strlen($filter);
  $search= _c('Search','events-calendar'); $searchlen = strlen($search);
  $today_event= _c('Today event','events-calendar'); $today_eventlen = strlen($today_event);
  $add = _c('Add an event','events-calendar'); $addlen = strlen($add);
  switch ($setting) {
    case 'wpecOptionsGenSet' : return unserialize('a:11:{s:3:"mtt";s:11:"ecopt_mttjq";s:3:"mtb";s:11:"ecopt_mtbtb";s:5:"gcssf";s:1:"0";s:4:"acfw";s:0:"";s:4:"acpt";s:0:"";s:4:"acst";s:0:"";s:4:"ttdf";s:19:"ecopt_ac_ttdf=j F Y";s:16:"ttdf_date_format";s:5:"m-j-y";s:4:"tttf";s:17:"ecopt_ac_tttf=g:i";s:16:"tttf_time_format";s:4:"G:ia";s:5:"weopt";s:11:"ecopt_weuni";}');
    case 'wpecOptionsRights' : return unserialize('a:9:{i:0;a:3:{i:0;s:18:"ecopt_rights[0][0]";i:1;s:18:"ecopt_rights[0][1]";i:2;s:18:"ecopt_rights[0][2]";}i:1;a:2:{i:0;s:18:"ecopt_rights[1][0]";i:1;s:18:"ecopt_rights[1][1]";}i:2;a:1:{i:0;s:18:"ecopt_rights[2][0]";}i:3;a:1:{i:0;s:18:"ecopt_rights[3][0]";}i:4;a:2:{i:0;s:18:"ecopt_rights[4][0]";i:1;s:18:"ecopt_rights[4][1]";}i:5;a:2:{i:0;s:18:"ecopt_rights[5][0]";i:1;s:18:"ecopt_rights[5][1]";}i:6;a:3:{i:0;s:18:"ecopt_rights[6][0]";i:1;s:18:"ecopt_rights[6][1]";i:2;s:18:"ecopt_rights[6][2]";}i:8;a:1:{i:0;s:18:"ecopt_rights[8][0]";}i:10;a:1:{i:0;s:19:"ecopt_rights[10][0]";}}');
    case 'wpecOptionsJtts'   : return unserialize('a:40:{s:5:"delay";s:1:"0";s:4:"fade";s:1:"0";s:5:"style";s:14:"ecopt_jtts_cla";s:9:"cla_width";s:3:"225";s:7:"cla_bgc";s:7:"#e1e1e1";s:7:"cla_bdc";s:4:"#000";s:7:"cla_bds";s:5:"solid";s:7:"cla_bdw";s:3:"1px";s:11:"cla_top_bgc";s:7:"#e1e1e1";s:11:"cla_top_col";s:4:"#000";s:11:"cla_top_siz";s:5:"small";s:11:"cla_top_wei";s:4:"bold";s:11:"cla_top_ffa";s:7:"Default";s:11:"cla_top_fst";s:6:"normal";s:11:"cla_mid_col";s:4:"#000";s:11:"cla_mid_siz";s:5:"small";s:11:"cla_mid_ffa";s:7:"Default";s:11:"cla_mid_fst";s:6:"normal";s:11:"cla_bot_bgc";s:0:"";s:11:"cla_bot_col";s:4:"#000";s:11:"cla_bot_siz";s:7:"x-small";s:11:"cla_bot_wei";s:6:"normal";s:11:"cla_bot_ffa";s:7:"Default";s:9:"cla_btmsg";s:'.strlen($btmsg).':"'.$btmsg.'";s:9:"bbl_width";s:6:"normal";s:7:"bbl_col";s:4:"gray";s:7:"bbl_pos";s:5:"right";s:11:"bbl_top_col";s:4:"#000";s:11:"bbl_top_siz";s:5:"small";s:11:"bbl_top_wei";s:4:"bold";s:11:"bbl_top_ffa";s:7:"Default";s:11:"bbl_mid_col";s:4:"#000";s:11:"bbl_mid_siz";s:5:"small";s:11:"bbl_mid_ffa";s:7:"Default";s:7:"bbl_sep";s:0:"";s:11:"bbl_bot_col";s:4:"#000";s:11:"bbl_bot_siz";s:5:"small";s:11:"bbl_bot_wei";s:6:"normal";s:11:"bbl_bot_ffa";s:7:"Default";s:9:"bbl_btmsg";s:'.strlen($btmsg).':"'.$btmsg.'";}');
    case 'wpecOptionsEctt'   : return unserialize('a:22:{s:3:"bgc";s:5:"lgray";s:5:"width";s:3:"250";s:7:"rcorner";s:2:"15";s:6:"hidden";s:0:"";s:7:"top_siz";s:6:"medium";s:7:"top_wei";s:4:"bold";s:7:"top_ffa";s:7:"Default";s:7:"top_tal";s:4:"left";s:7:"top_bgc";s:0:"";s:7:"top_bdc";s:0:"";s:7:"top_col";s:4:"#000";s:7:"top_fst";s:6:"normal";s:7:"mid_col";s:4:"#000";s:7:"mid_siz";s:5:"small";s:7:"mid_ffa";s:7:"Default";s:7:"mid_bdc";s:0:"";s:7:"bot_col";s:4:"#000";s:7:"bot_siz";s:5:"small";s:7:"bot_wei";s:6:"normal";s:7:"bot_ffa";s:7:"Default";s:7:"bot_tal";s:4:"left";s:5:"btmsg";s:'.strlen($btmsg).':"'.$btmsg.'";}');
    case 'wpecOptionsCsstt'  : return unserialize('a:19:{s:9:"bbl_width";s:5:"large";s:7:"bbl_col";s:4:"gray";s:7:"bbl_pos";s:5:"right";s:11:"bbl_top_col";s:7:"#363636";s:11:"bbl_top_siz";s:6:"medium";s:11:"bbl_top_wei";s:4:"bold";s:11:"bbl_top_ffa";s:7:"Default";s:11:"bbl_top_fst";s:6:"italic";s:11:"bbl_mid_col";s:7:"#0c004b";s:11:"bbl_mid_siz";s:5:"small";s:11:"bbl_mid_ffa";s:7:"Default";s:11:"bbl_mid_fst";s:6:"normal";s:7:"bbl_sep";s:0:"";s:11:"bbl_bot_col";s:7:"#5e5ca7";s:11:"bbl_bot_siz";s:5:"small";s:11:"bbl_bot_wei";s:6:"normal";s:11:"bbl_bot_ffa";s:7:"Default";s:11:"bbl_bot_fst";s:6:"normal";s:9:"bbl_btmsg";s:'.strlen($btmsg).':"'.$btmsg.'";}');
    case 'wpecOptionsJtbs'   : return unserialize('a:26:{s:4:"obgc";s:4:"#000";s:4:"opac";s:3:"0.8";s:6:"height";s:3:"400";s:5:"width";s:3:"350";s:3:"bdw";s:3:"3px";s:3:"bds";s:5:"solid";s:4:"bcol";s:4:"#555";s:6:"tb_bgc";s:7:"#707070";s:6:"tb_col";s:7:"#e1e1e1";s:6:"tb_siz";s:6:"medium";s:6:"tb_wei";s:4:"bold";s:6:"tb_ffa";s:7:"Default";s:6:"tb_fst";s:6:"italic";s:6:"ct_bgc";s:4:"#fff";s:6:"ct_col";s:4:"#000";s:6:"ct_siz";s:5:"small";s:6:"ct_wei";s:6:"normal";s:6:"ct_ffa";s:7:"Default";s:6:"fs_bgc";s:4:"#fff";s:6:"fs_siz";s:5:"small";s:6:"fs_wei";s:6:"normal";s:7:"fsl_bgc";s:7:"#e1e1e1";s:7:"fsl_siz";s:5:"small";s:7:"fsl_wei";s:4:"bold";s:7:"fsl_fst";s:6:"italic";s:6:"hidden";s:0:"";}');
    case 'wpecOptionsSbtb'   : return unserialize('a:29:{s:4:"obgc";s:4:"#000";s:4:"opac";s:3:"0.8";s:6:"height";s:3:"450";s:5:"width";s:3:"400";s:3:"bdw";s:3:"3px";s:3:"bds";s:5:"solid";s:4:"bcol";s:7:"#626262";s:6:"tb_bgc";s:7:"#7d7d7d";s:6:"tb_col";s:7:"#e1e1e1";s:6:"tb_siz";s:6:"medium";s:6:"tb_wei";s:4:"bold";s:6:"tb_ffa";s:7:"Default";s:6:"tb_fst";s:6:"italic";s:3:"tbw";s:3:"2px";s:3:"tbs";s:5:"solid";s:3:"tbc";s:7:"#626262";s:6:"ct_bgc";s:4:"#fff";s:6:"ct_col";s:4:"#000";s:6:"ct_siz";s:5:"small";s:6:"ct_wei";s:6:"normal";s:6:"ct_ffa";s:7:"Default";s:6:"fs_bgc";s:4:"#fff";s:6:"fs_siz";s:5:"small";s:6:"fs_wei";s:6:"normal";s:7:"fsl_bgc";s:7:"#d7d7d7";s:7:"fsl_siz";s:5:"small";s:7:"fsl_wei";s:6:"normal";s:7:"fsl_fst";s:6:"italic";s:6:"hidden";s:0:"";}');
    case 'wpecOptionsCsstb'  : return unserialize('a:26:{s:4:"obgc";s:4:"#000";s:4:"opac";s:3:"0.8";s:6:"height";s:3:"400";s:5:"width";s:3:"500";s:3:"bdw";s:3:"5px";s:3:"bds";s:6:"outset";s:4:"bcol";s:4:"#000";s:6:"tb_bgc";s:7:"#626262";s:6:"tb_col";s:7:"#e1e1e1";s:6:"tb_siz";s:5:"large";s:6:"tb_wei";s:4:"bold";s:6:"tb_ffa";s:5:"Arial";s:6:"tb_fst";s:6:"italic";s:6:"ct_bgc";s:7:"#c6df9c";s:6:"ct_col";s:7:"#363636";s:6:"ct_siz";s:6:"medium";s:6:"ct_wei";s:6:"normal";s:6:"ct_ffa";s:7:"Default";s:6:"fs_bgc";s:7:"#a4d49d";s:6:"fs_siz";s:5:"small";s:6:"fs_wei";s:6:"normal";s:7:"fsl_bgc";s:7:"#7dc473";s:7:"fsl_siz";s:5:"small";s:7:"fsl_wei";s:4:"bold";s:7:"fsl_fst";s:6:"italic";s:6:"hidden";s:0:"";}');
    case 'wpecOptionsWc'     : return unserialize('a:33:{s:3:"wdl";s:1:"2";s:4:"ecdc";s:7:"#173b6d";s:4:"pcdc";s:7:"#2583ad";s:9:"todaydcol";s:7:"#173b6d";s:10:"todaybgimg";s:62:"24|24|'.EVENTSCALENDARIMAGESPATH.'/redring.gif";s:10:"todaybgcol";s:0:"";s:4:"tabs";s:0:"";s:8:"bkimgtde";s:64:"190|190|'.EVENTSCALENDARIMAGESPATH.'/postit1.gif";s:4:"tbdf";s:0:"";s:16:"tbdf_date_format";s:5:"m-j-y";s:4:"tbtf";s:0:"";s:16:"tbtf_time_format";s:4:"G:ia";s:4:"dftt";s:0:"";s:16:"dftt_date_format";s:5:"m-j-y";s:7:"tbd_evt";s:1:"2";s:7:"tbd_des";s:1:"1";s:7:"tbd_loc";s:1:"3";s:7:"tbd_lko";s:1:"5";s:7:"tbd_adr";s:2:"fs";s:7:"tbd_man";s:2:"fs";s:7:"tbd_ctc";s:2:"fs";s:7:"tbd_pha";s:1:"4";s:7:"tbd_par";s:1:"0";s:7:"tbd_cst";s:1:"0";s:7:"tbd_lkp";s:1:"6";s:7:"tbd_lkg";s:1:"0";s:7:"tbd_ggm";s:2:"14";s:7:"tbd_csf";s:1:"0";s:4:"ttdf";s:0:"";s:16:"ttdf_date_format";s:5:"m-j-y";s:4:"tttf";s:0:"";s:16:"tttf_time_format";s:4:"G:ia";s:7:"tt_disp";a:5:{i:0;s:17:"ecopt_wc_tt_disp0";i:1;s:17:"ecopt_wc_tt_disp1";i:2;s:17:"ecopt_wc_tt_disp2";i:3;s:17:"ecopt_wc_tt_disp4";i:4;s:17:"ecopt_wc_tt_disp5";}}');
    case 'wpecOptionsTabs'   : return 'a:5:{i:0;a:3:{s:3:"tab";s:'.$swcallen.':"'.$swcal.'";s:3:"col";s:7:"#173b6d";s:3:"enb";s:'.$yeslen.':"'.$yes.'";}i:1;a:3:{s:3:"tab";s:'.$filterlen.':"'.$filter.'";s:3:"col";s:7:"#4e7c9d";s:3:"enb";s:'.$yeslen.':"'.$yes.'";}i:2;a:3:{s:3:"tab";s:'.$searchlen.':"'.$search.'";s:3:"col";s:7:"#719fd1";s:3:"enb";s:'.$yeslen.':"'.$yes.'";}i:3;a:3:{s:3:"tab";s:'.$today_eventlen.':"'.$today_event.'";s:3:"col";s:7:"#c0c0c0";s:3:"enb";s:'.$yeslen.':"'.$yes.'";}i:4;a:3:{s:3:"tab";s:'.$addlen.':"'.$add.'";s:3:"col";s:7:"#000000";s:3:"enb";s:'.$nolen.':"'.$no.'";}}';
    case 'wpecOptionsL1'     : return unserialize('a:30:{s:3:"brs";s:0:"";s:3:"ned";s:1:"5";s:4:"dfil";s:0:"";s:16:"dfil_date_format";s:5:"m-j-y";s:5:"width";s:3:"200";s:4:"ttdf";s:0:"";s:16:"ttdf_date_format";s:5:"m-j-y";s:4:"tttf";s:0:"";s:16:"tttf_time_format";s:4:"G:ia";s:7:"tt_disp";a:5:{i:0;s:17:"ecopt_l1_tt_disp0";i:1;s:17:"ecopt_l1_tt_disp1";i:2;s:17:"ecopt_l1_tt_disp2";i:3;s:17:"ecopt_l1_tt_disp4";i:4;s:17:"ecopt_l1_tt_disp5";}s:4:"tbdf";s:0:"";s:16:"tbdf_date_format";s:5:"m-j-y";s:4:"tbtf";s:0:"";s:16:"tbtf_time_format";s:4:"G:ia";s:4:"dftt";s:0:"";s:16:"dftt_date_format";s:5:"m-j-y";s:7:"tbd_evt";s:1:"2";s:7:"tbd_des";s:1:"1";s:7:"tbd_loc";s:1:"3";s:7:"tbd_lko";s:1:"5";s:7:"tbd_adr";s:2:"fs";s:7:"tbd_man";s:2:"fs";s:7:"tbd_ctc";s:2:"fs";s:7:"tbd_pha";s:1:"4";s:7:"tbd_par";s:1:"0";s:7:"tbd_cst";s:1:"0";s:7:"tbd_lkp";s:1:"6";s:7:"tbd_lkg";s:1:"0";s:7:"tbd_ggm";s:2:"14";s:7:"tbd_csf";s:1:"0";}');
    case 'wpecOptionsL2'     : return unserialize('a:30:{s:6:"height";s:3:"240";s:5:"width";s:3:"200";s:4:"dfil";s:0:"";s:16:"dfil_date_format";s:5:"m-j-y";s:6:"prevts";s:0:"";s:4:"ttdf";s:0:"";s:16:"ttdf_date_format";s:5:"m-j-y";s:4:"tttf";s:0:"";s:16:"tttf_time_format";s:4:"G:ia";s:7:"tt_disp";a:5:{i:0;s:17:"ecopt_l2_tt_disp0";i:1;s:17:"ecopt_l2_tt_disp1";i:2;s:17:"ecopt_l2_tt_disp2";i:3;s:17:"ecopt_l2_tt_disp4";i:4;s:17:"ecopt_l2_tt_disp5";}s:4:"tbdf";s:0:"";s:16:"tbdf_date_format";s:5:"m-j-y";s:4:"tbtf";s:0:"";s:16:"tbtf_time_format";s:4:"G:ia";s:4:"dftt";s:0:"";s:16:"dftt_date_format";s:5:"m-j-y";s:7:"tbd_evt";s:1:"2";s:7:"tbd_des";s:1:"1";s:7:"tbd_loc";s:1:"3";s:7:"tbd_lko";s:1:"5";s:7:"tbd_adr";s:2:"fs";s:7:"tbd_man";s:2:"fs";s:7:"tbd_ctc";s:2:"fs";s:7:"tbd_pha";s:1:"4";s:7:"tbd_par";s:1:"0";s:7:"tbd_cst";s:1:"0";s:7:"tbd_lkp";s:1:"6";s:7:"tbd_lkg";s:1:"0";s:7:"tbd_ggm";s:2:"14";s:7:"tbd_csf";s:1:"0";}');
    case 'wpecOptionsLc'     : return unserialize('a:31:{s:4:"ecdc";s:7:"#173b6d";s:10:"todaybgimg";s:1:"0";s:10:"todaybgcol";s:7:"#9ba9cf";s:7:"datepos";s:15:"ecopt_lc_dpleft";s:4:"ttdf";s:0:"";s:16:"ttdf_date_format";s:5:"m-j-y";s:4:"tttf";s:0:"";s:16:"tttf_time_format";s:4:"G:ia";s:7:"tt_disp";a:5:{i:0;s:17:"ecopt_lc_tt_disp0";i:1;s:17:"ecopt_lc_tt_disp1";i:2;s:17:"ecopt_lc_tt_disp2";i:3;s:17:"ecopt_lc_tt_disp4";i:4;s:17:"ecopt_lc_tt_disp5";}s:7:"clklink";s:15:"ecopt_lc_lknone";s:4:"tbdf";s:0:"";s:16:"tbdf_date_format";s:5:"m-j-y";s:4:"tbtf";s:0:"";s:16:"tbtf_time_format";s:4:"G:ia";s:4:"dftt";s:0:"";s:16:"dftt_date_format";s:5:"m-j-y";s:7:"tbd_evt";s:1:"2";s:7:"tbd_des";s:1:"1";s:7:"tbd_loc";s:1:"3";s:7:"tbd_lko";s:1:"5";s:7:"tbd_adr";s:2:"fs";s:7:"tbd_man";s:2:"fs";s:7:"tbd_ctc";s:2:"fs";s:7:"tbd_pha";s:1:"4";s:7:"tbd_par";s:1:"0";s:7:"tbd_cst";s:1:"0";s:7:"tbd_lkp";s:1:"6";s:7:"tbd_lkg";s:1:"0";s:7:"tbd_ggm";s:2:"14";s:7:"tbd_csf";s:1:"0";s:4:"page";s:1:"2";}');
    case 'wpecOptionsEv'     : return unserialize('a:16:{s:3:"ext";s:0:"";s:5:"types";s:0:"";s:5:"phase";s:0:"";s:4:"part";s:0:"";s:4:"post";s:0:"";s:3:"deo";s:3:"dmy";s:7:"miltime";s:0:"";s:4:"recc";s:0:"";s:5:"exrec";s:0:"";s:4:"rec1";s:7:"#fff100";s:4:"rec2";s:7:"#00a650";s:4:"rec3";s:7:"#00aeef";s:4:"rec4";s:7:"#2f3192";s:4:"rec6";s:7:"#62055f";s:4:"rec7";s:7:"#9d0039";s:4:"rec8";s:7:"#f5999d";}');
    case 'wpecOptionsTypes'  : return 'a:1:{i:0;a:7:{s:3:\"tid\";s:4:\"evt1\";s:3:\"des\";s:'.$noeventypelen.':\"'.$noeventype.'\";s:3:\"col\";s:'.$nonelen.':\"'.$none.'\";s:3:\"def\";s:'.$yeslen.':\"'.$yes.'\";s:3:\"enb\";s:'.$yeslen.':\"'.$yes.'\";s:3:\"rig\";s:6:\"Public\";s:3:\"cus\";s:53:\"'.$field.' #1;'.$field.' #2;'.$field.' #3;'.$field.' #4;'.$field.' #5;'.$field.' #6\";}}';
  default: break;
  }
}
/**
 * Return a WpEc option
 * If option not exist in the database return the default option
 * @param class object    $class              The class object to inject with the option
 * @param string          $setting            The option block name
 * @param boolean         $default            set true to Return the default values
 */
function wpec_get_option($class, $setting, $default = false) {
  if(!get_class($class)) return false;
  $option = get_option($setting);
  if($option == false || $default == true) {
    $option = wpec_get_defoption($setting, $enforce = true);
    update_option($setting,$option);
  }
  if($setting == 'wpecOptionsTabs') { $class->ecopt_sertabs = $option; return true; }
  if($setting == 'wpecOptionsTypes') { $class->ecopt_sertypes = $option; return true; }
  if(!is_array($option)) return false;
  if($setting == 'wpecOptionsRights') {
    foreach($option as $row => $roles)
      $class->ecopt_rights[$row] = $roles;
    return true;
  }
  $optKey = strtolower(str_replace('wpecOptions', '', $setting));
  foreach($option as $key => $value){
    $optVar = 'ecopt_'.(($optKey=='genset')?'':($optKey.'_')).$key;
    $class->$optVar = $value;
  }
  return true;
}
/**
 * Unset a given option collection
 * @param class object      $class             The class object calling
 * @param string            $setting           The option block name
 * @param array or string   $option            The option variable collection
 */
function wpec_unset_option($class, $setting, $option) {
  if(!get_class($class)) return false;
  if($setting == 'wpecOptionsTabs') { unset($class->ecopt_sertabs); return true; }
  if($setting == 'wpecOptionsTypes') { unset($class->ecopt_sertypes); return true; }
  if($setting == 'wpecOptionsRights') { unset($class->ecopt_rights); return true; }
  if(!is_array($option)) return false;
  $optKey = strtolower(str_replace('wpecOptions', '', $setting));
  //if($setting == 'wpecOptionsGenSet')echo 'opt = ',$optKey,'<br/>',var_dump($option),'<br/><hr><br/>';
  foreach($option as $key => $value){
    $optVar = 'ecopt_'.(($optKey=='genset')?'':($optKey.'_')).$key;
    unset($class->$optVar);
  }
  return true;
}
/**
* Retourne les composantes RGB d'une couleur html
*
* @param string $color
* @return mixed array
*/
function html2rgb($color) {
    /*On supprime le # eventuel de la couleur html*/
    if ($color[0] == '#') $color = substr($color, 1);
    $strlen = strlen($color);
    /*Si on utilise la notation de 6 caractres*/
    if ($strlen === 6) $color = array($color[0].$color[1], $color[2].$color[3], $color[4].$color[5]);
    /*Si on utilise la notation html  3 caractres*/
    elseif ($strlen === 3) $color = array($color[0].$color[0], $color[1].$color[1], $color[2].$color[2]);
    else return false;
    foreach ($color as &$c) $c = hexdec($c);
    return $color;
}
/**
* Retourne une couleur HTML  part des composantes RGB
*
* @param array $rgb
* @return string
*/
function rgb2html($rgb) {
  // Vrification des bornes...
  for($i=0;$i<=2;$i++) {
    if ($rgb[$i] < 0) $rgb[$i] = 0;
    if ($rgb[$i] > 255) $rgb[$i] = 255;
  }
  return "#" . str_pad(dechex( ($rgb[0]<<16)|($rgb[1]<<8)|$rgb[2] ), 6, "0", STR_PAD_LEFT);
}
/**
* Retourne une couleur HTML complmentaire
* pour viter le ton sur ton illisible
*
* @param string $color
* @return string
*/
function compColor($color) {
  $rgb = html2rgb($color);
  for($i=0;$i<3;$i++) $rgb[$i] = min((383 - $rgb[$i]),255);
  return rgb2html($rgb);
}
/**
* Retourne une couleur HTML pour du texte contrast en noir ou blanc
* pour viter le ton sur ton illisible
*
* @param string $color
* @return string
*/
function contrastColor($color) {
  $rgb = html2rgb($color);
  if(((($rgb[0]*299)+($rgb[1]*587)+($rgb[2]*114))/1000) < 125) return '#fff';
  return '#000';
}
/**
 * Check the actives widgets if the thme is widgetizable
 * @return  array : $wd_active = widgets active
 *                  $wc_active = Widget Calendar active
 *                  $l1_active = Widget List 1 active
 *                  $l2_active = Widget List 2 active
 *                  $l3_active = Widget List 3 active : Not implemented in this version
 */
function check_widgets() {
  if(function_exists('wp_get_sidebars_widgets')) {
    $wd_active = true;
    $wc_active = false;
    $l1_active = false;
    $l2_active = false;
    // $l3_active = false;
    $sidebars_widgets = wp_get_sidebars_widgets();
    foreach (array_keys($sidebars_widgets) as $wid) {
      if(in_array('events-calendar', $sidebars_widgets[$wid])) $wc_active = true;
      if (in_array('events-list-1', $sidebars_widgets[$wid])) $l1_active = true;
      if (in_array('events-list-2', $sidebars_widgets[$wid])) $l2_active = true;
      //if (in_array('events-list-3', $sidebars_widgets[$wid])) $l3_active = true;
    }
    return array($wd_active, $wc_active, $l1_active, $l2_active);
    //return array($wd_active, $wc_active, $l1_active, $l2_active, $l3_active);
  }
  return array(false);
}
/**
 * Provide a recurrence localized label
 * @param mixed $reccStatus     Recurrence number
 * @return string               The label assocated
 */
function wpec_recLabel($reccStatus) {
  switch ($reccStatus) {
    case '1': case 1: return _c('Date of the month','events-calendar');
    case '2': case 2: return _c('Every X days','events-calendar');
    case '3': case 3: return _c('Weekdays','events-calendar');
    case '4': case 4: return _c('Weeks of month','events-calendar');
    case '6': case 6: return _c('Every X days + Weeks of month','events-calendar');
    case '7': case 7: return _c('Weekdays + Weeks of month','events-calendar');
    case '8': case 8: return _c('Annual','events-calendar');
    default: return '';
  }
}
/**
 * Determine the week number in a given month.
 * (exclusively used by the function : reccurEventokToDisplay)
 *
 * @param string $sqldate       Date during the treatment
 * @param string $startDate     Event start Date
 * @param string $recurrProces  Recurrence settings
 * @param boolean $noduration   Duration NOT taking into account - optional
 *
 * @return string               Either an empty string or 'nope'
 */
function recWMonth($sqldate, $startDate, $recurrProces, $noduration =  false) {
  list($year, $month, $day) = explode('-', $sqldate);
  if($noduration) {
    $sqlwday = date("w", mktime(0, 0, 0, $month, $day, $year));
    if($sqlwday != WPECFDW && $sqldate != $startDate) return 'nope';
  }
  $wdfirstday =  date("w", mktime(0, 0, 0, $month, 1, $year));
  $except = ((1 + $wdfirstday - WPECFDW) == 0) ? 1 : 0 ;
  $weeknum = ceil((($day + $wdfirstday - WPECFDW) / 7) + $except);
  $reccbNWeek = unserialize($recurrProces);
  $c = count($reccbNWeek);
  for($i=0;$i<$c;$i++) $reccbNWeek[$i]++;
  if (in_array($weeknum, $reccbNWeek, false) || $weeknum == 6) {
    if ($weeknum < 5) return '';
    if (in_array(5, $reccbNWeek, false)) {  // Derniere semaine du mois quelque soit la semaine
      $lastday =  date('t', strtotime( $sqldate ));
      $lastweek = ceil( (date( 'j', strtotime( $year.'-'.$month.'-'.$lastday ) ) + (((WPECFDW + $wdfirstday) > 0 ) ? ( 7 - WPECFDW - $wdfirstday) : 0 )) / 7 );
      if ($weeknum == $lastweek ) return '';
    }
  }
  return 'nope';
}
/**
 * Treatment of recursive events, depending on the pace of recursion.
 *
 * @param string $sqldate        Date during the treatment
 * @param string $startDate      Event Date
 * @param int    $recurrStatus   Recurrence status.
 *
 *                               - 0 = No recurrence
 *                               - 1 = Date in the month
 *                               - 2 = Every X days
 *                               - 3 = Weekdays
 *                               - 4 = Weeks in a month
 *                               - 6 = Every X days + week in a month
 *                               - 7 = Weekdays + weeks of the month
 *                               - 8 = Annual event
 *
 * @param string $recurrProces    Recurrence settings
 *                                 - reccStatus = 0 = empty
 *                               - reccStatus = 1 = recDate
 *                               - reccStatus = 2 = recXDay
 *                               - reccStatus = 3 = serialize (recWDay)
 *                               - reccStatus = 4 = serialize (recNWeek)
 *                               - reccStatus = 6 = recXDay | serialize (recNWeek)
 *                               - reccStatus = 7 = serialize (recWDay) | serialize (recNWeek)
 *                               - reccStatus = 8 = Last anniversary (2030)
 *
 * @param boolean $noduration      Duration NOT taking into account - optional
 *
 * @return mixed                   Either an empty string = Ok to diplay the event instance or 'nope' for no display
 */
function reccurEventokToDisplay($sqldate, $startDate, $recurrStatus, $recurrProces, $recurrExcept = null, $noduration =  false) {
  list($year, $month, $day) = explode('-', $sqldate);
  list($styear, $stmonth, $stday) = explode('-', $startDate);
  $sqldts = strtotime($sqldate);
  switch ($recurrStatus) {
  case 1 :
    // Date in the months
    list($recday, $duration) = explode('|', $recurrProces);
    $duration = $noduration ? 1 : $duration;
    $recdate = $year.'-'.$month.'-'.str_pad($recday, 2, '0', STR_PAD_LEFT);
    if ($sqldts >= strtotime($recdate) && $sqldts <= strtotime($recdate." +".($duration-1)." days")) return '';
    return 'nope';
  case 2 :
    // Every X days
    list($recday, $duration) = explode('|', $recurrProces);
    $duration = $noduration ? 1 : $duration;
    $nbjours = floor((strtotime($sqldate) - strtotime($startDate))/86400); // =(60*60*24));
    for($i=0;$i<$duration;$i++) if (($nbjours % $recday+$i) == 0 ) return '';
    return 'nope';
  case 3 :
    // Weekdays
    $numjour = date('w', $sqldts);
    $reccWDay = unserialize($recurrProces);
    if (in_array($numjour, $reccWDay, false)) return '';
    return 'nope';
  case 4 :
    // Weeks in the Months
    return recWMonth($sqldate, $startDate, $recurrProces, $noduration);
  case 6 :
    // Every X days  + Weeks in the Months
    $nbjours = floor((strtotime($startDate) - strtotime($sqldate))/86400); // = (60*60*24));
    list($reccXDay, $duration, $reccWMonth) = explode('|', $recurrProces);
    $duration = $noduration ? 1 : $duration;
    for($i=0;$i<$duration;$i++) if (($nbjours % $reccXDay+$i) == 0 ) return recWMonth($sqldate, $startDate, $reccWMonth);
    return 'nope';
  case 7 :
    // Weekdays + Weeks in the Months
    $numjour = date("w", mktime(0, 0, 0, $month, $day, $year));
    list($reccWDay, $reccWMonth) = explode('|', $recurrProces); $reccWDay = unserialize($reccWDay);
    if (in_array($numjour, $reccWDay, false)) return recWMonth($sqldate, $startDate, $reccWMonth);
    return 'nope';
  case 8 :
    // Annual event (an annual event CANT be over deux years)
    list($byear, $bmonth, $bday) = explode('-', $startDate); $startDate = $year . '-' . $bmonth . '-' . $bday;
    list($eyear, $emonth, $eday) = explode('-', $recurrProces); $recurrProces = $year . '-' . $emonth . '-' . $eday;
    if($noduration) { if($startDate == $sqldate) return ''; else return 'none'; }
    if(strtotime($sqldate) >= strtotime($startDate) && strtotime($sqldate) <= strtotime($recurrProces)) return '';
    return 'nope';
  }
  return 'nope';
}
/*********************************************************************************
 * $class->sqldate
 * $class->duration
 * $class->startTime
 * $class->endTime
 * $class->recday
 * $class->recXday
 * $class->weekdays
 * $class->weeks
 * $class->orgRecDate
 **/
function procWMonth($sqldate, $startDate, $endDate, $recurrProces) {
  list($year, $month, $day) = explode('-', $sqldate);
  //$sqlwday = date("w", mktime(0, 0, 0, $month, $day, $year));
  //if($sqlwday != WPECFDW && $sqldate != $startDate && $sqldate != $endDate) return false;
  $wdfirstday =  date("w", mktime(0, 0, 0, $month, 1, $year));
  $lastday =  date('t', strtotime( $sqldate ));
  $except = ((1 + $wdfirstday - WPECFDW) == 0) ? 1 : 0 ;
  $weeknum = ceil((($day + $wdfirstday - WPECFDW) / 7) + $except);
  //echo $weeknum,'-',$wdfirstday,'<br/>';
  $reccbNWeek = unserialize($recurrProces);
  for($i=0;$i<count($reccbNWeek);$i++) $reccbNWeek[$i]++;
  if (in_array($weeknum, $reccbNWeek, false) || $weeknum == 6 || $lastday <= 28) {
    //echo $sqldate,' - ',$weeknum,'<br/>';
    if ($weeknum < (5 - ($lastday <= 28))) return $weeknum;
    if (in_array(5, $reccbNWeek, false)) {  // Derniere semaine du mois quelque soit la semaine
      $firstday = ($wdfirstday - WPECFDW + 7)%7;
      $lastweek = ceil( ($firstday + $lastday)  / 7 );
      //echo $sqldate,' - ',$weeknum,' - ',$lastweek,' - ',$lastelse,'<br/>';
      if ($weeknum == $lastweek && $lastday <= 28) return $lastweek;
      elseif ($lastweek > 4 && $lastday > 28) return $lastweek;
    }
  }
  return false;
}
function processRecurrence($class, $sqldate, $startDate, $endDate, $recStatus, $recProces, $recExcept) {
  // Si la date  vrifier est antrieure  la date du dbut d'vnement on sort de suite
  if($sqldate < $startDate || $sqldate > $endDate) return false;
  // On initialise les valeurs  retourner  la classe
  $class->sqldate = $class->startTime = $class->endTime = $class->duration = false;
  $class->recIsExcept = $class->recIsCan = $class->orgRecDate = false;
  // On dtecte si la date vrifie est celle de dpart ou de fin d'vvnement
  $class->recIsStart = ($sqldate == $startDate);
  $class->recIsEnd = ($sqldate == $endDate);
  // On verifie que - s'il y a exception - la rcurence n'est pas annule
  // Si ce n'est pas le cas alors on rcupre les exceptions
  // Si l'exception est suffisante pour crer une rcurrence on sort de suite.
  if($recExcept) {
    $recUsExcept = mb_unserialize(html_entity_decode(stripslashes($recExcept)));
    for($i=0;$i<count($recUsExcept);$i++) {
      if($recUsExcept[$i]['hdt'] == $sqldate) {
        $class->recIsExcept = true;
        if($recUsExcept[$i]['can']) {$class->recIsCan = true; break;}
        if($recUsExcept[$i]['ndt']) $class->sqldate = $recUsExcept[$i]['ndt'];
        if($recUsExcept[$i]['dur']) $class->duration = $recUsExcept[$i]['dur'] - 1;
        if($recUsExcept[$i]['nst']) $class->startTime = $recUsExcept[$i]['nst'];
        if($recUsExcept[$i]['net']) $class->endTime = $recUsExcept[$i]['net'];
        if($class->sqldate && $class->duration ) {
          $class->orgRecDate = $sqldate;
          return true;
        }
        break;
      }
    }
  }
  // On analyse les dates courante et dpart d'vnement
  list($year, $month, $day) = explode('-', $sqldate);
  list($styear, $stmonth, $stday) = explode('-', $startDate);
  $realDate = $class->sqldate ? $class->sqldate : $sqldate;
  switch ($recStatus) {
    case 1 :
      // Date in the months : compose d'une date dans le mois et d'une dure
      list($class->recday, $duration) = explode('|', $recProces);
      $recdate = $year.'-'.$month.'-'.str_pad($class->recday, 2, '0', STR_PAD_LEFT);
      $recCondition = ($recdate == $sqldate);
      $duration = max(0, $duration-1);
      if($class->recIsEnd == true) {
        $lastdays = date('Y-m-d',strtotime('-'.$duration.' days',strtotime($sqldate)));
        if($recdate >= $lastdays  && $recdate <= $sqldate) $class->recIsEnd = false;
      }
      if(!$recCondition) break;
      if(strtotime('+'.$duration.' days', strtotime($realDate)) >= strtotime($endDate)) {
        $class->recIsEnd = true;
        $duration = round((strtotime($endDate) - strtotime($realDate))/86400);
      }
      break;
    case 2 :
      // Every X days : compos d'un cart en jours et d'une dure
      list($class->recXday, $duration) = explode('|', $recProces);
      $gapdays = floor((strtotime($sqldate) - strtotime($startDate))/86400);
      $recCondition = (($gapdays % $class->recXday) == 0);
      $duration = max(0, $duration-1);
      if($class->recIsEnd == true && $gapdays % $class->recXday <= $duration) $class->recIsEnd = false;
      if(!$recCondition) break;
      if(strtotime('+'.$duration.' days', strtotime($realDate)) >= strtotime($endDate)) {
        $class->recIsEnd = true;
        $duration = round((strtotime($endDate) - strtotime($realDate))/86400);
      }
      break;
    case 3 :
      // Weekdays : composed by arrays of weekdays
      $duration = 0;
      $class->weekdays = unserialize($recProces);
      $recCondition = in_array((date('w', strtotime($sqldate))), $class->weekdays, false);
      break;
    case 4 :
      // Weeks in the Months : array of weeks in the month
      $class->weeks = unserialize($recProces);
      $sqlday = date("w", mktime(0, 0, 0, $month, $day, $year));
      $recCondition = ($day == 1 || $sqlday == WPECFDW || $class->recIsStart || $class->recIsEnd) && procWMonth($sqldate, $startDate, $endDate, $recProces);
      //if($sqlday == WPECFDW) echo $sqlday,' - ',$sqldate,'-',procWMonth($sqldate, $startDate, $endDate, $recProces),'<br/>';
      if(!$recCondition) break;
      $lastday = date('t', strtotime( $sqldate ));
      if($day == 1) $duration = (6 - $sqlday + WPECFDW)%7;
      elseif(($day + 6) >= $lastday) $duration = $lastday - $day;
      else $duration = 6;
      //echo $sqldate,' dur = ',$duration,'<br/>';
      if($class->recIsStart) $duration = (6 - $sqlday + WPECFDW)%7;
      if($class->recIsEnd) {
        if($sqlday != WPECFDW) {
          if(($day - 6) <= 0 ) $duration = $day - 1;
          else $duration = ($sqlday - WPECFDW + 7 )%7;
          $sqldate =  date('Y-m-d',strtotime('-'.$duration.' days', strtotime($endDate)));
        } else $duration = 0;
      } else {
        if(strtotime('+'.$duration.' days', strtotime($realDate)) >= strtotime($endDate)) $recCondition = false;
      }
      break;
    case 6 :
      // Every X days  + Weeks in the Months
      $gapdays = floor((strtotime($sqldate) - strtotime($startDate))/86400);
      list($class->recXday, $duration, $weeks) = explode('|', $recProces);
      $class->weeks = unserialize($weeks);
      $recCondition = ($gapdays % $class->recXday) == 0 && procWMonth($sqldate, $startDate, $endDate, $weeks);
      $sqlday = date("w", mktime(0, 0, 0, $month, $day, $year));
      if(!procWMonth(date('Y-m-d',strtotime('+'.$duration.' days',strtotime($sqldate))), $startDate, $endDate, $weeks))
        $duration = (6 - $sqlday + WPECFDW)%7;
      else $duration = max(0, $duration-1);
      if($class->recIsEnd == true && $gapdays % $class->recXday <= $duration) $class->recIsEnd = false;
      if(!$recCondition) break;
      if(strtotime('+'.$duration.' days', strtotime($realDate)) >= strtotime($endDate)) {
        $class->recIsEnd = true;
        $duration = round((strtotime($endDate) - strtotime($realDate))/86400);
      }
      break;
    case 7 :
      // Weekdays + Weeks in the Months
      $duration = 0;
      list($weekdays, $weeks) = explode('|', $recProces);
      $class->weekdays = unserialize($weekdays);
      $class->weeks = unserialize($weeks);
      $recCondition = (in_array((date('w', strtotime($sqldate))), $class->weekdays, false) && procWMonth($sqldate, $startDate, $endDate, $weeks));
      break;
    case 8 :
      // Annual event ( CAN NOT be over deux years )
      list($byear, $bmonth, $bday) = explode('-', $startDate); 
      $startDate = $year . '-' . $bmonth . '-' . $bday;
      list($eyear, $emonth, $eday) = explode('-', $recProces); 
      $endDate = $year . '-' . $emonth . '-' . $eday;
      $duration = max(0,floor((strtotime($endDate) - strtotime($startDate))/86400) - 1);
      $recCondition = ($startDate == $sqldate);
      break;
    default : return false;
  }
  // If exception date then we store the original rec date with orgRecDate
  if($class->sqldate) {$class->orgRecDate = $sqldate; $class->duration = $duration; return true;}
  elseif($recCondition) {$class->sqldate = $sqldate; $class->duration = $class->duration ? $class->duration : $duration; return true;}
  elseif($class->recIsStart || $class->recIsEnd) {$class->sqldate = $sqldate; $class->duration = 0 ; return true;}
  else return false;
}
/**
 * In some languages, weekdays display poorly on two or three characters.
 * This function to correct the problem.
 * Thanx to Pepawo
 *
 * @param string    $str
 * @param int         $start       Offset
 * @param int       $end          Lenght
 * @return string
 * @todo Need to understand what this does exactly and document it properly.
 */
function ec_utf8_substr($str,$start,$end)   {
      if (DB_CHARSET == 'utf8') {
         preg_match_all('/./u', $str, $ar);
         return join("",array_slice($ar[0],$start,$end));
      } else {
         return substr($str,$start,$end);
      }
}
/**
 * Format the date to show in thikbox for example
 *
 * @param string $d
 * @param string $m
 * @param string $y
 * @return int
 */
function get_tbdate_show($d,$m,$y) {
  global $ec_WeekdayNames, $ec_MonthNames;
  $m= intval($m); $d = intval($d);
  $option = get_option('optionsEventsCalendar');
  $format = $option['dateFormatLarge'];
  $elemnts_date = explode(' ', $format);
  if ($format == $elemnts_date[0])
    $elemnts_date = explode('-', $format);
    if ($format == $elemnts_date[0])
      $elemnts_date = explode('/', $format);
      if ($format == $elemnts_date[0])
        $elemnts_date = explode("\\", $format);
        if ($format == $elemnts_date[0])
          $elemnts_date = explode(',', $format);
          if ($format == $elemnts_date[0])        //added by pepawo
            $elemnts_date = explode('.', $format);  //addeed by pepawo
//            if (($format == $elemnts_date[0]) | ($elemnts_date[2] == Null )) : echo "<script LANGUAGE='JavaScript'>alert('" . __("Review your Large Calendar Date Format in the Events-Calendars options","events-calendar") . "');</SCRIPT>"; exit;
//  endif;
  $date_show = '';
  foreach ( $elemnts_date as $elem_dt ) {
    // Find the DAY in the format string
    if (substr_count('dDjlNSwz', $elem_dt) && ($d != 0))
      $date_show .= $ec_WeekdayNames[date('w', mktime(0,0,0,$m,$d,$y))] . ' ' . $d . ' ';
   // Find the MONTH in the format string
    if (substr_count('FmMnt', $elem_dt) && ($m != 0))
      $date_show .= $ec_MonthNames[$m] . ' ';
   // Attrib the YEAR
    if (substr_count('0Yy', $elem_dt) && ($y != 0))
      $date_show .= $y;
  }
  return $date_show;
}
/**
 * Retrieve the date in localized format, based on timestamp.
 *
 * If the locale specifies the locale month and weekday, then the locale will
 * take over the format for the date. If it isn't, then the date format string
 * will be used instead.
 *
 * @param string $dateformatstring Format to display the date.
 * @param int $unixtimestamp Optional. Unix timestamp.
 * @param bool $gmt Optional, default is false. Whether to convert to GMT for time.
 * @return string The date, translated if locale specifies it.
 */
function wpec_date_i18n($dateformatstring, $unixtimestamp = false, $gmt = false ) {
	$wp_locale = new WP_Locale();
	$i = $unixtimestamp;
	// Sanity check for PHP 5.1.0-
	if ( false === $i || intval($i) < 0 ) {
		if ( ! $gmt )
			$i = current_time( 'timestamp' );
		else
			$i = time();
		// we should not let date() interfere with our
		// specially computed timestamp
		$gmt = true;
	}

	// store original value for language with untypical grammars
	// see http://core.trac.wordpress.org/ticket/9396
	$req_format = $dateformatstring;

	$datefunc = $gmt? 'gmdate' : 'date';

	if ( ( !empty( $wp_locale->month ) ) && ( !empty( $wp_locale->weekday ) ) ) {
		$datemonth = $wp_locale->get_month( $datefunc( 'm', $i ) );
		$datemonth_abbrev = $wp_locale->get_month_abbrev( $datemonth );
		$dateweekday = $wp_locale->get_weekday( $datefunc( 'w', $i ) );
		$dateweekday_abbrev = $wp_locale->get_weekday_abbrev( $dateweekday );
		$datemeridiem = $wp_locale->get_meridiem( $datefunc( 'a', $i ) );
		$datemeridiem_capital = $wp_locale->get_meridiem( $datefunc( 'A', $i ) );
		$dateformatstring = ' '.$dateformatstring;
		$dateformatstring = preg_replace( "/([^\\\])D/", "\\1" . backslashit( $dateweekday_abbrev ), $dateformatstring );
		$dateformatstring = preg_replace( "/([^\\\])F/", "\\1" . backslashit( $datemonth ), $dateformatstring );
		$dateformatstring = preg_replace( "/([^\\\])l/", "\\1" . backslashit( $dateweekday ), $dateformatstring );
		$dateformatstring = preg_replace( "/([^\\\])M/", "\\1" . backslashit( $datemonth_abbrev ), $dateformatstring );
		$dateformatstring = preg_replace( "/([^\\\])a/", "\\1" . backslashit( $datemeridiem ), $dateformatstring );
		$dateformatstring = preg_replace( "/([^\\\])A/", "\\1" . backslashit( $datemeridiem_capital ), $dateformatstring );

		$dateformatstring = substr( $dateformatstring, 1, strlen( $dateformatstring ) -1 );
	}
	$j = @$datefunc( $dateformatstring, $i );
	// allow plugins to redo this entirely for languages with untypical grammars
	$j = apply_filters('date_i18n', $j, $req_format, $i, $gmt);
	return $j;
}
 /**
 * Manage the transition year-end in the calendars
 *
 * @param int $m       The month
 * @param int $name    If 0 (zero), then the function will return the month number.
 *                     Otherwise, it will return the month name
 * @return mixed       Either the month number or name depending on the $name parameter
 */
function get_incrMonth($m, $name = 0) {
  if ($m > 12) $m=1;
  if ($m < 1) $m=12;
  if ($name) {
    global $ec_MonthNames;
    return $ec_MonthNames[intval($m)];
  }
  return $m;
}
 /**
 * Provide a stylish url string with limited lenght
 * Optional provided the clikable link
 *
 * @param string    $urlin       the url string to format
 * @param int       $limit       the limit lenght
 * @param boolean   $linked      the linked option
 * @param string    $urlclass       the linked class : optional
 * @return string   $urlout      the formated url
 */

function shorten_url($urlin, $limit, $linked = false, $urlclass = ''){
  if(strlen($urlin) > $limit + 3) {
    $cut = round($limit / 2);
    $urlout = substr($urlin, 0, $cut ).'...'.substr($urlin, strlen($urlin)-$cut, $cut );
  } else $urlout = $urlin;
  if($linked)
    $urlout = '<a href="'.$urlin.'"'.($urlclass != '' ? (' class="'.$urlclass.'"'):'').'>'.$urlout.'</a>';
  return $urlout;
}
/**
 * Create a class
 * Return the option rights when calling outside of a class
 */
function getOptionsRights() {
  if(!class_exists("EC_optionsRights")) {
    class EC_optionsRights {
      function EC_optionsRights() {
        wpec_get_option($this, 'wpecOptionsRights');
      }
    }
  }
}
/**
* Return curent user login and autorisations following options rights
*
* @param class object  optional   $class    The class object calling
* If class is not defined then an associative array is returned
* [
*   'user_login' =>   string            : user login
*   'user_level' =>   int               : WPEC user lever
*   'user_rights' =>  array of boolean  : the autorisations
* ]
* else :
* @return string                  $class->user_login : current user login
* @return int                     $class->user_level : current user level FOR WPEC !
* @return array of booleans       $class->user_rights :  The autorisation(s)
*   0 => Access to the management of Events-Calendar
*   1 => Creation of events
*   2 => Updating events
*   3 => Deleting events
*   4 => Updating owners events
*   5 => Deleting owners events
*   6 => Creation of events in the sidebar
*   7 => Access to all the options
*   8 => Access to options without rights management
*   9 => Access to options without evts types managmnt
*   10 => Access to the import/export of events
*/
function wpec_usercan($class = '') {
  global $user_login, $user_level;
  if(!function_exists(get_currentuserinfo)) require_once(ABSWPINCLUDE.'/pluggable.php');
  get_currentuserinfo();
  /**
  * Number of rights in actual version :
  */
  $number_of_rights = 11;
  /***********************************/
  if(is_object($class)) {
    $class->user_login = $user_login;
    //$class->user_role = ec_convAccessLevel('level_'.$user_level);
    switch ($user_level) {
    case '10' : case '8' : case '9' : // if admin
      $class->user_level = 10;
      $class->user_rights = array_fill(0, $number_of_rights, true);
      return;
    case '0' : $class->user_level = 3; break; // is Subscriber
    case '1' : $class->user_level = 2; break; // is Contributor
    case '2' : $class->user_level = 1; break; // is Author
    case '3' : case '4' : case '5' : case '6' : case '7' : // is Editor
      $class->user_level = 0; break;
    default: // is .. nothing
      $class->user_level = 0;
      $class->user_rights = array_fill(0, $number_of_rights, false);
      return;
    }
    wpec_get_option($class, 'wpecOptionsRights');
    for($i=0; $i<$number_of_rights; $i++)
      $class->user_rights[$i] = isset($class->ecopt_rights[$i][$class->user_level]);
  } else {
    $response = array();
    $response['user_login'] = $user_login;
    $response['wp_user_level'] = $user_level;
    switch ($user_level) {
    case '10' : case '8' : case '9' : // if admin
      $response['user_level'] = 10;
      $response['user_rights'] = array_fill(0, $number_of_rights, true);
      return $response;
    case '0' : $response['user_level'] = 3; break; // is Subscriber
    case '1' : $response['user_level'] = 2; break; // is Contributor
    case '2' : $response['user_level'] = 1; break; // is Author
    case '3' : case '4' : case '5' : case '6' : case '7' : // is Editor
      $response['user_level'] = 0; break;
    default: // is .. nothing
      $response['user_level'] = 0;
      $response['user_rights'] = array_fill(0, $number_of_rights, false);
      return $response;
    }
    getOptionsRights();
    $class = new EC_optionsRights();
    for($i=0; $i<$number_of_rights; $i++)
      $response['user_rights'][$i] = isset($class->ecopt_rights[$i][$response['user_level']]);
    return $response;
  }
}

  /**
  * Traitment to Storage tables names of the months and weekdays :
  * long chains of abstracts and the first letter.
  *
  * Parameters recieved by this function are globals used elsewhere by the plugin.
  *
  * @param array    $ec_WeekdayNames
  * @param string $ec_WeekdayString
  * @param array    $ec_MonthNames
  * @param string $ec_MonthNamesAbbrev
  *
  * @todo I need to rewrite this doc.
  */
function ec_getlocalnames(&$ec_WeekdayNames, &$ec_WeekdayNamesAbbrev, &$ec_WeekdayString, &$ec_MonthNames, &$ec_MonthNamesAbbrev) {
  $wp_locale = new WP_Locale();
  for ($i=0;$i<7;$i++) {
    $ec_WeekdayNames[$i] = ucfirst($wp_locale->get_weekday($i));
    $ec_WeekdayNamesAbbrev[$i] = ec_utf8_substr($ec_WeekdayNames[$i], 0, 3);
    $ec_WeekdayString .= substr($ec_WeekdayNames[$i], 0, 1);
  }
  for ($i=1;$i<13;$i++) {
    $ec_MonthNames[$i] = $wp_locale->get_month($i);
    $ec_MonthNamesAbbrev[$i] = ucfirst($wp_locale->get_month_abbrev($ec_MonthNames[$i]));
    $ec_MonthNames[$i] = ucfirst($ec_MonthNames[$i]);
  }
}
/* Init Public Var & Localization ----------------------------------------------------------------------**/
 /**
 * Detecting the language used in Wordpress and choose the language file corresponding
 */
load_default_textdomain();
require_once(ABSWPINCLUDE.'/locale.php');
load_plugin_textdomain('events-calendar',PLUGINDIR.'/'.dirname(plugin_basename(__FILE__)).'/lang');

/**#@+
 * @todo Write a better doc for these globals. Where are they used and what for?
 *       Describe the arrays.
 */
/**
 * Storage table fr the week day names: long chains of abstracts and the first letter.
 * @global array $ec_WeekdayNames
 */
$ec_WeekdayNames = array();
$ec_WeekdayNamesAbbrev = array();
/**
 * Storage table for the names of the months: long chains of abstracts and the first letter
 * @global array $ec_WeekdayNames
 */
$ec_MonthNames = array();

/**
 * Storage table for the months abreviations.
 * @global array $ec_MonthNamesAbbrev
 */
$ec_MonthNamesAbbrev = array();

/**
 * Storage string for the weekday names.
 * @global string $ec_WeekdayString
 * @todo Find what goes in there. This is not an array like the preceding ones.
 */
$ec_WeekdayString = '';

/**#@-*/

ec_getlocalnames($ec_WeekdayNames , $ec_WeekdayNamesAbbrev, $ec_WeekdayString ,$ec_MonthNames, $ec_MonthNamesAbbrev);
?>