<?php
/*
--------------------------------------------------------------------------
This file is part of the WP Events Calendar project.

For questions, help, comments, discussion, etc., please join our
forum at {@link http://www.wp-eventscalendar.com/forum}. You can
also go to Luke's ({@link http://www.lukehowelll.com}) and
Heirem's ({@link http://heirem.fr}) blogs.

WP Events Calendar is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.   See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
--------------------------------------------------------------------------
*/

/**
 * This file contains the WP Events Calendar EC_Options class.
 *
 * @internal      Long description to be done.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @author
 *                - Luke Howell <luke@wp-eventscalendar.com>
 *                - Brad Bodine <brad@wp-eventscalendar.com>
 *                - Ren MALKA <heirem@wp-eventscalendar.com>
 * @link
 *                - http://wp-eventscalendar.com/
 *                - http://www.lukehowell.com
 *                - http://myboxtool.com/
 *                - http://heirem.fr
 *                - http://laplix.com
 *                - http://www.gwathneydesign.com/
 * @since         7.0.0
 * @copyright
 *                - Copyright (c) 2007-2009 Luke Howell
 *                - Copyright (c) 2007-2009 Brad Bodine
 *                - Copyright (c) 2008-2009 Ren Malka
 *                - Copyright (c)      2009 Louis Lapointe
 *                - Copyright (c)      2009 Coe Gwathney
 * @license       GPLv3 {@link http://www.gnu.org/licenses/gpl}
 * @filesource
 *
 */
if(!class_exists('EC_Options')):

/**
 * This class is used by WPEC to setup and display the calendar options.
 *
 * @internal Long description to be done.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @since         7.0.0
 *
 * @todo Flesh out all the comments. Right now, I can do some educated guests
 *       but that's about it. --laplix
 */
class EC_Options {

   /**
    * Holds the calendar options.
    * @var array
    */
   var $optionsGenSet = array(), // General
       $optionsRights = array(), // Rights
       $optionsJtts   = array(), // jQuery AND Css Tooltips
       $optionsEctt   = array(), // EC Tooltips
       $optionsCsstt  = array(), // Css Tooltips
       $optionsJtbs   = array(), // jQuery Thickbox
       $optionsSbtb   = array(), // Shadowbox
       $optionsCsstb  = array(), // Css Thickbox
       $optionsWc     = array(), // Widget Calendar
       $optionsTabs            , // Tabs list serialized
       $optionsL1     = array(), // List 1
       $optionsL2     = array(), // List 2
       $optionsLc     = array(), // Large Calendar
       $optionsEv     = array(), // Events choises
       $optionsTypes           , // Types list serialized
       $ecopt_rights  = array()  // Rights array of arrays
   ;
   /**
    * Holds the Ec Form object.
    * @var object
    */
   var $ecFormEvent;
   /**
    * Holds the Ec Form object.
    * @var boolean      = true if the form was previously submitted
    */
   var $OptionsSubmitted = '';
   /**
    * Holds default values (in case error reading options)
    * @var string      = method tooltips or thickbox
    */
   var $ecopt_mtt = 'ecopt_mttjq';
   var $ecopt_mtb = 'ecopt_mtbtb';
   var $ecopt_jtts_style = 'ecopt_jtts_cla';
   /**
    * Initialize the class.
    * It lads and instanciates the EC_Form class, this loads the
    * calendar options.
    */
  function EC_Options() {
    // Loading the form class
    class_exists('ec_form') || require(EVENTSCALENDARCLASSPATH.'/ec_form.class.php');
    $this->ecformEvent = new ec_form(EVENTSCALENDARIMAGESURL,'false',true);
    $this->ecformEvent->info_img = EVENTSCALENDARIMAGESURL.'/ques_mark.png';
    // Get the current user rights
    wpec_usercan($this);
    // $this->user_rights[7]; access to all options
    // $this->user_rights[8]; access to rights
    // $this->user_rights[9]; access to types   
    /**
     Verify if the theme is widgetizable and what are the active widgets
     $wd_active = Widgets actives
     $wc_active = Widgets Calendar is active
     $l1_active = Widgets List 1 is active etc..
    */
    list($this->wd_active, $this->wc_active, $this->l1_active, $this->l2_active) = check_widgets();
    // If the form have been submitted
    if(isset($_POST['optionsEventsCalendar_submitted'])) {
      // OptionsSubmitted = 'true' : normal update
      //                  = 'reloadDefault' : reload the default options from the curTab value 
      $this->OptionsSubmitted = $_POST['optionsEventsCalendar_submitted'];
      // debug :echo var_dump($_POST);
      // Parse the $_POST array and extract the options and values
      foreach($_POST as $key => $value){
        list($pfx, $tab, $stab, $gid, $set) = explode('_', $key);
        $sOpt = $stab.($gid?('_'.$gid):'').($set?('_'.$set):'');
        //echo $tab.' ,'.$stab.' ,'.$gid.'<br/>';
        switch ($tab) {
          // Admin calendar date & times
          case 'ac': $this->optionsGenSet[$sOpt] = $value; break;
          // jQuery and Css Tooltips
          case 'jtts': $this->optionsJtts[$sOpt] = $value; break;
          // EC Tooltips
          case 'ectt': $this->optionsEctt[$sOpt] = $value; break;
          // Css Tooltips
          case 'csstt': $this->optionsCsstt[$sOpt] = $value; break;
          // jQuery Thickbox
          case 'jtbs': $this->optionsJtbs[$sOpt] = $value; break;
          // Shadowbox
          case 'sbtb': $this->optionsSbtb[$sOpt] = $value; break;
          // Css Thickbox
          case 'csstb': $this->optionsCsstb[$sOpt] = $value; break;
          // Widget Calendar
          case 'wc': $this->optionsWc[$sOpt] = $value; break;
          //List 1
          case 'l1': $this->optionsL1[$sOpt] = $value; break;
          //List 2
          case 'l2': $this->optionsL2[$sOpt] = $value; break;
          //Large Calendar
          case 'lc': $this->optionsLc[$sOpt] = $value; break;
          //Events managmnt
          case 'ev': $this->optionsEv[$sOpt] = $value; break;
          // Rights
          case 'rights': $this->optionsRights = $value; break;
          //Tabs list serialized
          case 'sertabs': $this->optionsTabs = $value; break;
          // Events types serialized
          case 'sertypes': $this->optionsTypes = $value; break;
          // Tooltips method, Thickbox method, jQuery extrem protection, General personal CSS file, Tooltip Message Bottom
          case 'mtt': case 'mtb': case 'jqep': case 'gcssf': case 'acfw': case 'acpt': 
          case 'acst': case 'weopt': case 'cwe':
            $this->optionsGenSet[$tab] = $value;
            break;
        default:break;
        }
        $this->$key = $value;
      }
      // Load the defaults options folowing a tab
      if($this->OptionsSubmitted == 'reloadDefault') {
        switch ($this->returnCurTab) {
          case 's00' : // General settings
            wpec_unset_option($this,'wpecOptionsGenSet',$this->optionsGenSet); 
            wpec_get_option($this,'wpecOptionsGenSet',true);
            $this->init_default_date('wpecOptionsGenSet');
            wpec_get_option($this, 'wpecOptionsJtts');
            wpec_get_option($this, 'wpecOptionsJtbs');
            break;
          case 's01' : // Tooltips settings
            if($this->ecopt_mtt == 'ecopt_mttjq') { 
                wpec_unset_option($this,'wpecOptionsJtts',$this->optionsJtts); 
                wpec_get_option($this,'wpecOptionsJtts',true);
                break;
            } elseif($this->ecopt_mtt == 'ecopt_mtcss') {
                wpec_unset_option($this,'wpecOptionsCsstt',$this->optionsCsstt); 
                wpec_get_option($this,'wpecOptionsCsstt',true);
                break;
            } elseif($this->ecopt_mtt == 'ecopt_mttec') {
                wpec_unset_option($this,'wpecOptionsEctt',$this->optionsEctt); 
                wpec_get_option($this,'wpecOptionsEctt',true);
                break;
            } else break;
          case 's02' : // Thickbox settings
            if($this->ecopt_mtb == 'ecopt_mtbtb') {
                wpec_unset_option($this,'wpecOptionsJtbs',$this->optionsJtbs); 
                wpec_get_option($this,'wpecOptionsJtbs',true);
                break;
            } elseif($this->ecopt_mtb == 'ecopt_mtbsb') {
                wpec_unset_option($this,'wpecOptionsSbtb',$this->optionsSbtb); 
                wpec_get_option($this,'wpecOptionsSbtb',true);
                break;
            } elseif($this->ecopt_mtb == 'ecopt_mtbcss') {
                wpec_unset_option($this,'wpecOptionsCsstb',$this->optionsCsstb); 
                wpec_get_option($this,'wpecOptionsCsstb',true);
                break;
            } else break;
          case 's03' : // Rights
            wpec_unset_option($this,'wpecOptionsRights',$this->optionsRights); 
            wpec_get_option($this,'wpecOptionsRights',true);
            break;
          case 's10' : // Widget calendar settings
            wpec_unset_option($this,'wpecOptionsWc',$this->optionsWc); 
            wpec_get_option($this,'wpecOptionsWc',true);
            wpec_get_option($this,'wpecOptionsTabs',true);
            $this->init_default_date('wpecOptionsWc');
            break;
          case 's11' : // Widget List 1
            wpec_unset_option($this,'wpecOptionsL1',$this->optionsL1); 
            wpec_get_option($this,'wpecOptionsL1',true);
            $this->init_default_date('wpecOptionsL1');
            break;
          case 's12' : // Widget List 2
            wpec_unset_option($this,'wpecOptionsL2',$this->optionsL2); 
            wpec_get_option($this,'wpecOptionsL2',true);
            $this->init_default_date('wpecOptionsL2');
            break;
          case 'item2' : // Large calendar settings 
            wpec_unset_option($this,'wpecOptionsLc',$this->optionsLc); 
            wpec_get_option($this,'wpecOptionsLc',true);
            $this->init_default_date('wpecOptionsLc');
            break;
          case 's20' : // Events Managemnt settings
            wpec_unset_option($this,'wpecOptionsEv',$this->optionsEv); 
            wpec_get_option($this,'wpecOptionsEv',true);
            break;
          default: break;
        }

      } else {  // Normal update after submit
        update_option('wpecOptionsGenSet', $this->optionsGenSet);
        if($this->user_rights[7] || !$this->user_rights[8]) update_option('wpecOptionsRights', $this->optionsRights);

        if(!empty($this->optionsJtts)) update_option('wpecOptionsJtts', $this->optionsJtts);
        elseif($this->ecopt_mtt == 'ecopt_mttjq') wpec_get_option($this, 'wpecOptionsJtts');
        
        if(!empty($this->optionsEctt)) update_option('wpecOptionsEctt', $this->optionsEctt);
        elseif($this->ecopt_mtt == 'ecopt_mttec') wpec_get_option($this, 'wpecOptionsEctt');
        
        if(!empty($this->optionsCsstt)) update_option('wpecOptionsCsstt', $this->optionsCsstt);
        elseif($this->ecopt_mtt == 'ecopt_mtcss') wpec_get_option($this, 'wpecOptionsCsstt');

        if(!empty($this->optionsJtbs)) update_option('wpecOptionsJtbs', $this->optionsJtbs);
        elseif($this->ecopt_mtb == 'ecopt_mtbtb') wpec_get_option($this, 'wpecOptionsJtbs');
        
        if(!empty($this->optionsSbtb)) update_option('wpecOptionsSbtb', $this->optionsSbtb);
        elseif($this->ecopt_mtb == 'ecopt_mtbsb') wpec_get_option($this, 'wpecOptionsSbtb');
        
        if(!empty($this->optionsCsstb)) update_option('wpecOptionsCsstb', $this->optionsCsstb);
        elseif($this->ecopt_mtb == 'ecopt_mtbcss') wpec_get_option($this, 'wpecOptionsCsstb');
        
        if(!empty($this->optionsWc)) {
          update_option('wpecOptionsWc', $this->optionsWc);
          update_option('wpecOptionsTabs', $this->optionsTabs);
        } elseif(!$this->wd_active || $this->wc_active) {
          wpec_get_option($this, 'wpecOptionsWc');
          wpec_get_option($this, 'wpecOptionsTabs');
        } 
  
        if(!empty($this->optionsL1)) update_option('wpecOptionsL1', $this->optionsL1);
        elseif(!$this->wd_active || $this->l1_active) wpec_get_option($this, 'wpecOptionsL1');
        
        if(!empty($this->optionsL2)) update_option('wpecOptionsL2', $this->optionsL2);
        elseif(!$this->wd_active || $this->l2_active) wpec_get_option($this, 'wpecOptionsL2');
  
        update_option('wpecOptionsLc', $this->optionsLc);
        update_option('wpecOptionsEv', $this->optionsEv);
        if($this->user_rights[7] || !$this->user_rights[9]) update_option('wpecOptionsTypes', $this->optionsTypes);
      }
    } else { // If the form was NOT previously submitted

      // Get the General basic settings
      wpec_get_option($this, 'wpecOptionsGenSet');
      $strOptions = (($this->user_rights[7] || !$this->user_rights[8]) ? 'Rights|':''). //Rights
                    (($this->ecopt_mtt=='ecopt_mttjq')?'Jtts|':'').   //jQuery Tooltips
                    (($this->ecopt_mtt=='ecopt_mttec')?'Ectt|':'').   //EC Tooltips
                    (($this->ecopt_mtt=='ecopt_mtcss')?'Csstt|':'').  //Css Tooltips                    
                    (($this->ecopt_mtb=='ecopt_mtbtb')?'Jtbs|':'').   //jQuery Thickbox
                    (($this->ecopt_mtb=='ecopt_mtbsb')?'Sbtb|':'').   //Shadowbox
                    (($this->ecopt_mtb=='ecopt_mtbcss')?'Csstb|':''). //Css Thickbox
                    (($this->wc_active==true)?'Wc|Tabs|':'').         //Widget Calendar and its Tabs
                    (($this->l1_active==true)?'L1|':'').              //List 1
                    (($this->l2_active==true)?'L2|':'').              //List 2
                    'Lc|'.     //Large Calendar
                    'Ev|'.     //Events Managemnt
                    (($this->user_rights[7] || !$this->user_rights[9]) ? 'Types':'')  // its Types
                    ;
      $options = explode('|', $strOptions);
      foreach($options as $setting) wpec_get_option($this, 'wpecOptions'.$setting);
    }
    // Common Form vars
    $this->tbDispOrder_arr = array('0'=>'0','1'=>'1','2'=>'2','3'=>'3','4'=>'4','5'=>'5','6'=>'6','7'=>'7','8'=>'8','9'=>'9','10'=>'10','11'=>'11','12'=>'12','13'=>'13','14'=>'14');
    $this->tbDispOrderWfs_arr = array('0'=>'0','fs'=>'fs','1'=>'1','2'=>'2','3'=>'3','4'=>'4','5'=>'5','6'=>'6','7'=>'7','8'=>'8','9'=>'9','10'=>'10','11'=>'11','12'=>'12','13'=>'13','14'=>'14');
    $this->font_size = array('xx-small'=>'xx-small','x-small'=>'x-small','small'=>'small','medium'=>'medium','large'=>'large','x-large'=>'x-large','xx-large'=>'xx-large');
    $this->font_weight = array('normal'=>'normal','bold'=>'bold','bolder'=>'bolder','lighter'=>'lighter','100'=>'100','200'=>'200','300'=>'300','400'=>'400','500'=>'500','600'=>'600','700'=>'700','800'=>'800','900'=>'900');
    $this->font_family = array('Default'=>'Default','Arial'=>'Arial','Arial Black'=>'Arial Black','Arial Narrow'=>'Arial Narrow','Book Antiqua'=>'Book Antiqua','Bookman Old Style'=>'Bookman Old Style','Century Gothic'=>'Century Gothic','Comic Sans MS'=>'Comic Sans MS','Courier'=>'Courier','Fixedsys'=>'Fixedsys','Garamond'=>'Garamond','Georgia'=>'Georgia','Impact'=>'Impact','Lucida Console'=>'Lucida Console','Modern'=>'Modern','Script'=>'Script','System'=>'System','Tahoma'=>'Tahoma','Times New Roman'=>'Times New Roman','Verdana'=>'Verdana');
    $this->font_style = array('normal'=>'normal','italic'=>'italic','oblique'=>'oblique');
    $this->bord_style = array('solid'=>'solid','dashed'=>'dashed','dotted'=>'dotted','double'=>'double','inset'=>'inset','outset'=>'outset','none'=>'none');
    $this->bord_width = array('1px'=>'1px','2px'=>'2px','3px'=>'3px','4px'=>'4px','5px'=>'5px','0px'=>'0px','thin'=>'thin','medium'=>'medium','thick'=>'thick');
  }
   /**
    * Add or update a Event Form.
    */
  function calendarOptions() {
	  // Loading the layout
    function_exists('ecly_manform_head_menu') || require(EVENTSCALENDARCLASSPATH.'/ec_options.layout.php');
    // Populate the tabs and sub-tabs of the box menu
    $strItems = array(
      'label' => array('General','Sidebar','LargeCal','Events','About'),
      'local' => array(substr(_c('General','events-calendar'),0,10),
                       substr(_c('Sidebar','events-calendar'),0,10),
                       substr(_c('Large Cal','events-calendar'),0,10),
                       substr(_c('Events','events-calendar'),0,10),
                       substr(_c('About','events-calendar'),0,10))
                       );
    $strSMItems = array(
      'General' => array(
        'slabel' => array('Settings','Tooltips','Thickbox','Rights'),
        'slocal' => array(substr(_c('Settings','events-calendar'),0,10),
                          substr(_c('Tooltips','events-calendar'),0,10),
                          substr(_c('Thickbox','events-calendar'),0,10),
                          substr(_c('Rights','events-calendar'),0,10))),
      'Sidebar' => array(
        'slabel' => array(),
        'slocal' => array()),
      'Events' => array(
        'slabel' => array('Choices','Types'),
        'slocal' => array(substr(_c('Settings','events-calendar'),0,10),
                          substr(_c('Types','events-calendar'),0,10))),
      'About' => array(
        'slabel' => array('Help','Uninstall','Credits'),
        'slocal' => array(substr(_c('Help','events-calendar'),0,10),
                          substr(_c('Uninstall','events-calendar'),0,10),
                          substr(_c('Credits','events-calendar'),0,10))));
    // Profile the sidebar sub tabs following the currents active widget
    // If the theme is not widgetizable, show all the sidebar sub tabs
    if ($this->wd_active == true) {
      if ($this->wc_active == true) {
        array_push($strSMItems['Sidebar']['slabel'], 'WCalendar');
        array_push($strSMItems['Sidebar']['slocal'], substr(_c('Calendar','events-calendar'),0,10));
      }
      if ($this->l1_active == true) {
        array_push($strSMItems['Sidebar']['slabel'], 'List1');
        array_push($strSMItems['Sidebar']['slocal'], substr(_c('EC List 1','events-calendar'),0,10));
      }
      if ($this->l2_active == true) {
        array_push($strSMItems['Sidebar']['slabel'], 'List2');
        array_push($strSMItems['Sidebar']['slocal'], substr(_c('EC List 2','events-calendar'),0,10));
      }
      /*
      if ($l3_active == true) {
        array_push($strSMItems['Sidebar']['slabel'], 'List3');
        array_push($strSMItems['Sidebar']['slocal'], substr(_c('EC List 3','events-calendar'),0,10));
      }
      */
      if ($this->wc_active == false && $this->l1_active == false && $this->l2_active == false) {
        array_push($strSMItems['Sidebar']['slabel'], 'NoWidget');
        array_push($strSMItems['Sidebar']['slocal'], substr(_c('No Widget','events-calendar'),0,10));
      }
    } else {
      array_push($strSMItems['Sidebar']['slabel'], 'WCalendar');
      array_push($strSMItems['Sidebar']['slocal'], substr(_c('Calendar','events-calendar'),0,10));
      array_push($strSMItems['Sidebar']['slabel'], 'List1');
      array_push($strSMItems['Sidebar']['slocal'], substr(_c('EC List 1','events-calendar'),0,10));
      array_push($strSMItems['Sidebar']['slabel'], 'List2');
      array_push($strSMItems['Sidebar']['slocal'], substr(_c('EC List 2','events-calendar'),0,10));
//     array_push($strSMItems['Sidebar']['slabel'], 'List3');
//     array_push($strSMItems['Sidebar']['slocal'], substr(_c('EC List 3','events-calendar'),0,10));
    }
    // If no Tooltips method then hide the tab involved
    if ($this->ecopt_mtt == 'ecopt_mttnone') {
      array_splice($strSMItems['General']['slabel'], 1, 1);
      array_splice($strSMItems['General']['slocal'], 1, 1);
    }
    // If no Thickbox  method then hide the tab involved
    if ($this->ecopt_mtb == 'ecopt_mtbnone') {
      $i = ($this->ecopt_mtt == 'ecopt_mttnone') ?  1 : 2;
      array_splice($strSMItems['General']['slabel'], $i, 1);
      array_splice($strSMItems['General']['slocal'], $i, 1);
    }
    // If user have no access to the rights management
    if(!$this->user_rights[7] && $this->user_rights[8]) {
      array_splice($strSMItems['General']['slabel'], 3, 1);
      array_splice($strSMItems['General']['slocal'], 3, 1);
    }
    // If user have no access to the types management
    if(!$this->user_rights[7] && $this->user_rights[9]) {
      array_splice($strSMItems['Events']['slabel'], 1, 1);
      array_splice($strSMItems['Events']['slocal'], 1, 1);
    }
    // Head box menu injection
    echo $this->InsertHeadMenu(_c('Events Calendar Options','events-calendar'),$strItems);
    // Open the main form
    echo $this->ecformEvent->ecform_start('?page=events-calendar-options','optionsEventsCalendar','post',true);
    $this->ecformEvent->tabindex('1');
    echo $this->InsertContent($strItems, $strSMItems);
    $this->ecformEvent->tabindex('stop');
    $this->ecformEvent->hidden('popupImg',$this->ecly_ecpopup);
    $this->ecformEvent->hidden('returnCurTab');
    echo $this->ecformEvent->display('body');
    echo $this->ecformEvent->display('foot');
    echo $this->ecformEvent->JSHeader($this->custJsHeader);
    echo $this->ecformEvent->js_validate_code();
    echo ecly_options_foot_menu($this->OptionsSubmitted);
    echo ecly_options_js_sm_script();
  }
  /**
  * Insert Content Form Box
  */
  function InsertContent($strItems,$strSMItems) {
    $sidx = 0; $wrap = 0;
    $ci = count($strItems['label']);
    for($i=0; $i<$ci; $i++) {
      $hmenu = $strItems['label'][$i];
      $strFunc = 'funcinsMenu_'.$hmenu;
      $output .= ' <div id="menu_item'.$i.'" class="'.(($i == 0) ? 'on':'off').' content">
              ';
      if(is_array($strSMItems) && array_key_exists($hmenu,$strSMItems)) { // Insert Sub Menu if exist
        $output .= $this->InsertSmenu($hmenu,$strSMItems);
        $cj = count($strSMItems[$hmenu]['slabel']);
        for($j=0; $j<$cj; $j++) {
          $strSMFunc = 'funcinsSubMenu_'.$strSMItems[$hmenu]['slabel'][$j];
          $output .= '<div id="smenu_s'.$sidx.$j.'" class="'.(($j == 0) ? 'son':'soff').' scontent">
                  '.((method_exists($this,$strSMFunc)) ? $this->$strSMFunc() : '').'
    </div>
      ';
        }
        $sidx++;
      } else {
        $output .= '<div id="wrap'.$wrap++.'" class="wrap">
                '.((method_exists($this,$strFunc)) ? $this->$strFunc() : '').'
              </div>
          ';
      }
      $output .= '</div>
      ';
    }
    return $output;
  }
  /**
  * Provides the head menu.
  *
  * @internal  Long description to be done.
  *
  * @param string    $title         the menu title
  * @param array     $strItems      {@internal What does it contain??. I see "label" and "local" }}
  * @return string                  The HTML for the Head Menu
  */
  function InsertHeadMenu($title,$strItems = array()) {
    $output = ecly_options_head_menu ($title);
    $c = count($strItems['label']);
    for($i=0; $i<$c; $i++) {
      $output .=
    		'<li class="menu_item'.$i.'">
    			<a id="item'.$i.'" class="'.(($i == 0) ? 'current':'ghost').'" onclick="multiMenu(this.id,'.count($strItems["label"]).',\'func_\'+this.id)" alt="menu'.$i.'"><span>'.$strItems["local"][$i].'</span></a>
    		</li>
        ';}
    $output .= $this->ecly_options_tbar_menu;
    return $output;
  }
  /**
   * Provides sub menu items.
   *
   * @internal Long description to be done.
   *
   * @param string   $hmenu      Menu name. Used as index in the $strSMItems array.
   * @param array    $strSmItems
   * @return string              The HTML for the sub menu.
   */
  function InsertSmenu($hmenu,$strSMItems = array()) {
    static $smidx = 0;
    $output = $this->ecly_options_head_ism;
    $c = count($strSMItems[$hmenu]['slabel']);
    for($i=0; $i<$c ; $i++) {
      $output .= '
          <li class="smenu'.$i.'">
            <a id="s'.$smidx.$i.'" class="'.(($i == 0) ? 'scurrent':'sghost').'" onclick="multiSMenu(this.id,'.$smidx.','.count($strSMItems[$hmenu]["slabel"]).',\'func_\'+this.id)" alt="smenu_'.$smidx.$i.'"><span>'.$strSMItems[$hmenu]["slocal"][$i].'</span></a>
          </li>
          ';
    }
    $output .= $this->ecly_options_foot_ism;
    $smidx++;
    return $output;
  }
  /**
   * Provides a lits of user CSS file.
   *
   * @return array
   */
  function ec_cssDirList() {
    $output = array();
    $cssfiles = glob(EVENTSCALENDARGLOBPATH.'/css/*.css');
    foreach ($cssfiles as $filename) {
      $fileinfo=pathinfo($filename);
      $result = $fileinfo['filename'].'.'.$fileinfo['extension'];
      $output[$filename] = $result;
    }
    array_unshift($output,_c('Select a file','events-calendar')); return $output;
  }
  /**
   * Provides a list of user images.
   *
   * @return array
   */
  function ec_imgDirList() {
    $output = array();
    $imgfiles = array_merge(glob(EVENTSCALENDARGLOBPATH.'/images/*.jpg'),glob(EVENTSCALENDARGLOBPATH.'/images/*.png'),glob(EVENTSCALENDARGLOBPATH.'/images/*.gif'));
    foreach ($imgfiles as $filename) {
      list($width, $height, $type, $attr) = getimagesize($filename);
      $fileinfo=pathinfo($filename);
      $result = $fileinfo['filename'].'.'.$fileinfo['extension'];
      $output[$width.'|'.$height.'|'.$filename] = $result;
    }
    $output['190|190|'.EVENTSCALENDARIMAGESPATH.'/postit1.gif'] = 'postit1.gif';
    $output['190|190|'.EVENTSCALENDARIMAGESPATH.'/postit2.png'] = 'postit2.png';
    $output['190|190|'.EVENTSCALENDARIMAGESPATH.'/postit3.png'] = 'postit3.png';
    $output['24|24|'.EVENTSCALENDARIMAGESPATH.'/redring.gif'] = 'redring.gif';
    $output['30|24|'.EVENTSCALENDARIMAGESPATH.'/bluering.gif'] = 'bluering.gif';
    array_unshift($output,_c('Select a file','events-calendar'));     
    return $output;
  }
  /**
   * Enables the user to select the date format.
   *    
   * @param string  $type     format type : 
   *                             date   : normal date
   *                             title  : title date (with the weekday name)
   *                             list   : date into item an events list
   *                             time   : normal time           
   * @param string  $prefix   prefix element calling
   * @return array            fill a select input
   */
  function show_date_formats($type, $prefix){
    global $wp_version;
    switch ($type) {
      case 'date'  : $date_formats = array(
                      __('F j, Y'),
                      _c('M j, y','events-calendar'),
                      _c('m/d/Y','events-calendar'),
                      _c('m/d/y','events-calendar'),
                      _c('d/m/Y','events-calendar'),
                      _c('d/m/y','events-calendar'),
                     ); break;
      case 'title' : $date_formats = array(
                      _c('l F j, Y','events-calendar'),
                      _c('l M j, y','events-calendar'),
                      _c('l m/d/Y','events-calendar'),
                      _c('l m/d/y','events-calendar'),
                      _c('l d/m/Y','events-calendar'),
                      _c('l d/m/y','events-calendar'),
                     ); break;
      case 'list'  : $date_formats = array(
                      _c('D m-j-y','events-calendar'),
                      _c('M j-y','events-calendar'),
                      _c('D M j y','events-calendar'),
                      _c('m-d-y D','events-calendar'),
                      _c('m-d-y','events-calendar'),
                      _c('j D m-y','events-calendar'),
                     ); break;
      case 'time'  : $date_formats = array(
                      _c('g:i a','events-calendar'),
                      _c('g:i A','events-calendar'),
                      _c('G:i a','events-calendar'),
                      _c('G:i A','events-calendar'),
                      _c('h:i','events-calendar'),
                      _c('H:i','events-calendar'),
                     ); break;
      default: return array();
    }
  	$return_date_formats = array();
  	// '=' as separator between the var name and le value
  	$prefix .= '=';
	  foreach ($date_formats as $format) {
	    $dk = attribute_escape($format);
	    $return_date_formats[$prefix.$dk] = date_i18n($format, current_time('timestamp',$gmt = ($wp_version < 2.7)),'gmt');
    }
    $return_date_formats[$prefix.'custom'] =  _c('Custom:','events-calendar');
    // return an array without doublons due to localisation
    //$return_date_formats = array_unique($return_date_formats);
    return $return_date_formats;
  }
  /**
   * Set dates and time during default loadings  
   * Due to localization default dates and times are empty 
   * This function to get the localized settings    
   * @param string   $setting   block name of options 
   * @return array              depend of the block of options
   */
  function init_default_date($setting) {    
    switch ($setting) {
      case 'wpecOptionsGenSet' : //break; // Bug with admin calendar dates times and I dont know why !
        $ttdf_arr = array_keys($this->show_date_formats('date','ecopt_ac_ttdf')); $ttdf = $ttdf_arr[0]; $this->optionsGenSet['ttdf'] = $this->ecopt_ac_ttdf = $ttdf;  
        $tttf_arr = array_keys($this->show_date_formats('time','ecopt_ac_tttf')); $tttf = $tttf_arr[0]; $this->optionsGenSet['tttf'] = $this->ecopt_ac_tttf = $tttf;
        update_option('wpecOptionsGenSet',$this->optionsGenSet);         
        break;
      case 'wpecOptionsWc' :
        $tbdf_arr = array_keys($this->show_date_formats('date','ecopt_wc_tbdf')); $tbdf = $tbdf_arr[0]; $this->optionsWc['tbdf'] = $this->ecopt_wc_tbdf = $tbdf;  
        $tbtf_arr = array_keys($this->show_date_formats('time','ecopt_wc_tbtf')); $tbtf = $tbtf_arr[0]; $this->optionsWc['tbtf'] = $this->ecopt_wc_tbtf = $tbtf;
        $dftt_arr = array_keys($this->show_date_formats('title','ecopt_wc_dftt')); $dftt = $dftt_arr[0]; $this->optionsWc['dftt'] = $this->ecopt_wc_dftt = $dftt;
        $ttdf_arr = array_keys($this->show_date_formats('date','ecopt_wc_ttdf')); $ttdf = $ttdf_arr[0]; $this->optionsWc['ttdf'] = $this->ecopt_wc_ttdf = $ttdf;  
        $tttf_arr = array_keys($this->show_date_formats('time','ecopt_wc_tttf')); $tttf = $tttf_arr[0]; $this->optionsWc['tttf'] = $this->ecopt_wc_tttf = $tttf;
        update_option('wpecOptionsWc',$this->optionsWc);         
        break;
      case 'wpecOptionsL1' :
        $dfil_arr = array_keys($this->show_date_formats('list','ecopt_l1_dfil')); $dfil = $dfil_arr[0]; $this->optionsL1['dfil'] = $this->ecopt_l1_dfil = $dfil;  
        $ttdf_arr = array_keys($this->show_date_formats('date','ecopt_l1_ttdf')); $ttdf = $ttdf_arr[0]; $this->optionsL1['ttdf'] = $this->ecopt_l1_ttdf = $ttdf;  
        $tttf_arr = array_keys($this->show_date_formats('time','ecopt_l1_tttf')); $tttf = $tttf_arr[0]; $this->optionsL1['tttf'] = $this->ecopt_l1_tttf = $tttf;
        $tbdf_arr = array_keys($this->show_date_formats('date','ecopt_l1_tbtf')); $tbdf = $tbdf_arr[0]; $this->optionsL1['tbdf'] = $this->ecopt_l1_tbdf = $tbdf;
        $tbtf_arr = array_keys($this->show_date_formats('time','ecopt_l1_tbtf')); $tbtf = $tbtf_arr[0]; $this->optionsL1['tbtf'] = $this->ecopt_l1_tbtf = $tbtf;
        $dftt_arr = array_keys($this->show_date_formats('title','ecopt_l1_dftt')); $dftt = $dftt_arr[0]; $this->optionsL1['dftt'] = $this->ecopt_l1_dftt = $dftt;
        update_option('wpecOptionsL1',$this->optionsL1);         
        break;
      case 'wpecOptionsL2' :
        $dfil_arr = array_keys($this->show_date_formats('list','ecopt_l2_dfil')); $dfil = $dfil_arr[0]; $this->optionsL2['dfil'] = $this->ecopt_l2_dfil = $dfil;  
        $ttdf_arr = array_keys($this->show_date_formats('date','ecopt_l2_ttdf')); $ttdf = $ttdf_arr[0]; $this->optionsL2['ttdf'] = $this->ecopt_l2_ttdf = $ttdf;  
        $tttf_arr = array_keys($this->show_date_formats('time','ecopt_l2_tttf')); $tttf = $tttf_arr[0]; $this->optionsL2['tttf'] = $this->ecopt_l2_tttf = $tttf;
        $tbdf_arr = array_keys($this->show_date_formats('date','ecopt_l2_tbtf')); $tbdf = $tbdf_arr[0]; $this->optionsL2['tbdf'] = $this->ecopt_l2_tbdf = $tbdf;
        $tbtf_arr = array_keys($this->show_date_formats('time','ecopt_l2_tbtf')); $tbtf = $tbtf_arr[0]; $this->optionsL2['tbtf'] = $this->ecopt_l2_tbtf = $tbtf;
        $dftt_arr = array_keys($this->show_date_formats('title','ecopt_l2_dftt')); $dftt = $dftt_arr[0]; $this->optionsL2['dftt'] = $this->ecopt_l2_dftt = $dftt;
        update_option('wpecOptionsL2',$this->optionsL2);         
        break;
      case 'wpecOptionsLc' :
        $ttdf_arr = array_keys($this->show_date_formats('date','ecopt_lc_ttdf')); $ttdf = $ttdf_arr[0]; $this->optionsLc['ttdf'] = $this->ecopt_lc_ttdf = $ttdf;  
        $tttf_arr = array_keys($this->show_date_formats('time','ecopt_lc_tttf')); $tttf = $tttf_arr[0]; $this->optionsLc['tttf'] = $this->ecopt_lc_tttf = $tttf;
        $tbdf_arr = array_keys($this->show_date_formats('date','ecopt_lc_tbtf')); $tbdf = $tbdf_arr[0]; $this->optionsLc['tbdf'] = $this->ecopt_lc_tbdf = $tbdf;
        $tbtf_arr = array_keys($this->show_date_formats('time','ecopt_lc_tbtf')); $tbtf = $tbtf_arr[0]; $this->optionsLc['tbtf'] = $this->ecopt_lc_tbtf = $tbtf;
        $dftt_arr = array_keys($this->show_date_formats('title','ecopt_lc_dftt')); $dftt = $dftt_arr[0]; $this->optionsLc['dftt'] = $this->ecopt_lc_dftt = $dftt;
        update_option('wpecOptionsLc',$this->optionsLc);         
        break;
      default: return;
    }
  }
  /**
   * Enables the user to enter his custom date/time format.
   *
   * @param string   $type
   * @param string   $pfx
   * @return string           HTML for the input block.
   */
  function dtPostExt($type, $pfx) {
    $imputName = 'ecopt_'.$pfx.'_'.$type.'_format_custom';
    if(!$this->$imputName) $this->$imputName = ($type=='date')? 'm-j-y':'G:ia';
    $post_text = '&nbsp;<span id="'.$pfx.'_pstext" class="dtPostExt"><input type="text" name="'.$imputName.'" size="5" value="'.$this->$imputName.'" class="small-text" />&nbsp;'.substr(date_i18n($this->$imputName,current_time('timestamp'),'gmt'),0,11).'</span>';
    $post_text .=  '&nbsp;<img id="ecopt_'.$pfx.'_img" class="ecf-info_img" border="0" src="'.EVENTSCALENDARIMAGESURL.'/ques_mark.png" tooltiptext="'._c('Choose one of the pre-selected formats, or Custom: to enter your own.','events-calendar').'" style="width: 13px; height: 14px;"/>';
    return $post_text;
  }
  /**
   * Provide the custom weekend days list
   *
   * @return array           the custom weekend days list
   */
  function ec_cwelist(){
    global $ec_WeekdayNamesAbbrev, $ec_WeekdayNames;
    $customWeDays = array();
    for($i=0; $i<count($ec_WeekdayNames); $i++) $customWeDays[$ec_WeekdayNamesAbbrev[$i]] = $ec_WeekdayNames[$i];
    for($i=0; $i<count($ec_WeekdayNames)-2; $i++) $customWeDays[$ec_WeekdayNamesAbbrev[$i].'-'.$ec_WeekdayNamesAbbrev[$i+1]] = $ec_WeekdayNames[$i].' + '.$ec_WeekdayNames[$i+1];
    return $customWeDays; 
  }
  /**
   * General : Settings Form Tab
   *
   * @return string    The form HTML for the date format selection
  */
  function funcinsSubMenu_Settings() {
    $noneLab = _c('None','events-calendar');
    $this->ecformEvent->curtab('item0'); //Current Tab : General
    $this->ecformEvent->cursubtab('s00'); //Current Sub Tab : Settings
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
      $this->ecformEvent->fieldset('start',_c('Events details display methods','events-calendar'),'id="ecf-fs_meth" class="ecf-fieldset"','class="ecf-legend_fieldset"',_c('Having chosen your display methods, please submit the form to see the tabs of the options involved.','events-calendar'));
        $this->ecformEvent->radio(_c('Tooltips','events-calendar'), 'ecopt_mtt',$this->ecopt_mtt,array('ecopt_mttjq'=>'jQuery Tooltips','ecopt_mttec'=>'EC-ToolTips (JavaScript)','ecopt_mtcss'=>'Css ToolTips','ecopt_mttnone'=>$noneLab),'','vertical');
        $this->ecformEvent->radio(_c('Thickboxes','events-calendar'), 'ecopt_mtb',$this->ecopt_mtb,array('ecopt_mtbtb'=>'jQuery Thickbox ('._c('WordPress\'s built in','events-calendar').')','ecopt_mtbsb'=>'Shadowbox (JavaScript)','ecopt_mtbcss'=>'CSS Thickbox','ecopt_mtbnone'=>$noneLab),'','vertical');
      $this->ecformEvent->fieldset('end'); // Enf of Event details display methods fieldset
      $this->ecformEvent->fieldset('start',_c('jQquery Extrem Protection','events-calendar'),'id="ecf-fs_jqep" class="ecf-fieldset"','class="ecf-legend_fieldset"');
        $this->ecformEvent->checkbox_trigger(_c('Check the box for yes','events-calendar'),'ecopt_jqep','',isset($this->ecopt_jqep));
      $this->ecformEvent->fieldset('end'); // Enf of jQquery Extrem Protection fieldset
      $this->ecformEvent->fieldset('start',_c('General personal CSS file','events-calendar'),'id="ecf-fs_pcss" class="ecf-fieldset"','class="ecf-legend_fieldset"');
        $this->ecformEvent->select(_c('Your own general CSS file','events-calendar'), 'ecopt_gcssf',$this->ecopt_gcssf,$this->ec_cssDirList(),'', _c('This file must be into the &quot;user/css&quot; plugin directory','events-calendar'),'', '', 'single', 12);
      $this->ecformEvent->fieldset('end'); // Enf of General personal CSS file fieldset
      $this->ecformEvent->fieldset('start',_c('Dashboard calendar options','events-calendar'),'id="ecf-fs_ac" class="ecf-fieldset"','class="ecf-legend_fieldset"');
        $this->ecformEvent->fieldset('start','','class="ecf-sfs_ac"');
          $this->ecformEvent->checkbox_trigger(_c('Fixed weeks'),'ecopt_acfw','',isset($this->ecopt_acfw),_c('If checked, the calendar will always be 6 weeks tall. If not, the calendar\'s height will vary per month','events-calendar'));
          $this->ecformEvent->checkbox_trigger(_c('Priority for events types color'),'ecopt_acpt','',isset($this->ecopt_acpt),_c('If checked, the events background color will be the type color. If not, it will be the recurrence color','events-calendar'));
          $this->ecformEvent->checkbox_trigger(_c('Show start time'),'ecopt_acst','',isset($this->ecopt_acst),_c('If checked, the events title will be preceded by the start time','events-calendar'));
        $this->ecformEvent->fieldset('end');
        $this->ecformEvent->fieldset('start','','class="ecf-sfs_ac"');
          $this->ecformEvent->select(_c('Dates Format'),'ecopt_ac_ttdf',$this->ecopt_ac_ttdf,$this->show_date_formats('date','ecopt_ac_ttdf'),'', '','', $this->dtPostExt('date', 'ac_ttdf'), 'single', 6);
          $this->ecformEvent->select(_c('Times Format'),'ecopt_ac_tttf',$this->ecopt_ac_tttf,$this->show_date_formats('time','ecopt_ac_tttf'),'', '','', $this->dtPostExt('time', 'ac_tttf'), 'single', 6);
        $this->ecformEvent->fieldset('end');
      $this->ecformEvent->fieldset('end'); // Enf of Dashboard calendar options fieldset
      $this->ecformEvent->fieldset('start',_c('Weekend days options','events-calendar'),'id="ecf-fs_we" class="ecf-fieldset"','class="ecf-legend_fieldset"');
        $this->ecformEvent->radio('', 'ecopt_weopt',$this->ecopt_weopt,array('ecopt_weuni'=>'Universal (saturday + sunday)','ecopt_wesun'=>'Semi-Universal (friday + saturday)','ecopt_wecust'=>'Custom:'),'','horizontal');
        $this->ecformEvent->select('', 'ecopt_cwe',$this->ecopt_cwe,$this->ec_cwelist(),'', _c('Chose your custom weekend days','events-calendar'),'', '', 'single', 12);              
      $this->ecformEvent->fieldset('end'); // Enf of Weekend days options fieldset      
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');
    return $output;
  }
  /**
   * General : Rights Form Tab
   *
   * @return string     The form HTML for rights management.
   */
  function funcinsSubMenu_Rights() {
    $spacer = '.'; $nit = 46;
    $this->ecformEvent->curtab('item0'); //Current Tab : General
    $this->ecformEvent->cursubtab('s01'); //Current Sub Tab : Rights
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
      $this->ecformEvent->fieldset('start',_c('Capability vs. Role Table','events-calendar'),'class="ecf-fieldset" id="ecf-fs_rights"','class="ecf-legend_fieldset"');
        $this->ecformEvent->custom_code('&nbsp;','none','<table id="widefat"><tbody><tr><th id="capab">'._c('Capabilities','events-calendar').'</th><th class="roles">'._c('Editor','events-calendar').'</th><th class="roles">'._c('Author','events-calendar').'</th><th class="roles">'._c('Contributor','events-calendar').'</th><th class="roles">'._c('Subscriber','events-calendar').'</th></tr></tbody></table>');
        $this->ecformEvent->checkbox(str_pad(substr(_c('Access to the management of Events-Calendar','events-calendar'),0,$nit),$nit,$spacer),'ecopt_rights[0]',$this->ecopt_rights[0],array('ecopt_rights[0][0]'=>'&nbsp;','ecopt_rights[0][1]'=>'&nbsp;','ecopt_rights[0][2]'=>'&nbsp;','ecopt_rights[0][3]'=>'&nbsp;'),'', 'horizontal','', '</br>', '4');
        $this->ecformEvent->checkbox(str_pad(substr(_c('Creation of events','events-calendar'),0,$nit),$nit,$spacer),'ecopt_rights[1]',$this->ecopt_rights[1],array('ecopt_rights[1][0]'=>'&nbsp;','ecopt_rights[1][1]'=>'&nbsp;','ecopt_rights[1][2]'=>'&nbsp;','ecopt_rights[1][3]'=>'&nbsp;'),'', 'horizontal','', '', '4');
        $this->ecformEvent->checkbox(str_pad(substr(_c('Updating events','events-calendar'),0,$nit),$nit,$spacer),'ecopt_rights[2]',$this->ecopt_rights[2],array('ecopt_rights[2][0]'=>'&nbsp;','ecopt_rights[2][1]'=>'&nbsp;','ecopt_rights[2][2]'=>'&nbsp;','ecopt_rights[2][3]'=>'&nbsp;'),'', 'horizontal','', '', '4');
        $this->ecformEvent->checkbox(str_pad(substr(_c('Deleting events','events-calendar'),0,$nit),$nit,$spacer),'ecopt_rights[3]',$this->ecopt_rights[3],array('ecopt_rights[3][0]'=>'&nbsp;','ecopt_rights[3][1]'=>'&nbsp;','ecopt_rights[3][2]'=>'&nbsp;','ecopt_rights[3][3]'=>'&nbsp;'),'', 'horizontal','', '', '4');
        $this->ecformEvent->checkbox(str_pad(substr(_c('Updating owners events','events-calendar'),0,$nit),$nit,$spacer),'ecopt_rights[4]',$this->ecopt_rights[4],array('ecopt_rights[4][0]'=>'&nbsp;','ecopt_rights[4][1]'=>'&nbsp;','ecopt_rights[4][2]'=>'&nbsp;','ecopt_rights[4][3]'=>'&nbsp;'),'', 'horizontal','', '', '4');
        $this->ecformEvent->checkbox(str_pad(substr(_c('Deleting owners events','events-calendar'),0,$nit),$nit,$spacer),'ecopt_rights[5]',$this->ecopt_rights[5],array('ecopt_rights[5][0]'=>'&nbsp;','ecopt_rights[5][1]'=>'&nbsp;','ecopt_rights[5][2]'=>'&nbsp;','ecopt_rights[5][3]'=>'&nbsp;'),'', 'horizontal','', '', '4');
        $this->ecformEvent->checkbox(str_pad(substr(_c('Creation of events in the sidebar','events-calendar'),0,$nit),$nit,$spacer),'ecopt_rights[6]',$this->ecopt_rights[6],array('ecopt_rights[6][0]'=>'&nbsp;','ecopt_rights[6][1]'=>'&nbsp;','ecopt_rights[6][2]'=>'&nbsp;','ecopt_rights[6][3]'=>'&nbsp;'),'', 'horizontal','', '', '4');
        $this->ecformEvent->checkbox(str_pad(substr(_c('Access to all the options','events-calendar'),0,$nit),$nit,$spacer),'ecopt_rights[7]',$this->ecopt_rights[7],array('ecopt_rights[7][0]'=>'&nbsp;','ecopt_rights[7][1]'=>'&nbsp;','ecopt_rights[7][2]'=>'&nbsp;','ecopt_rights[7][3]'=>'&nbsp;'),'', 'horizontal','', '', '4');
        $this->ecformEvent->checkbox(str_pad(substr(_c('Access to options without rights management','events-calendar'),0,$nit),$nit,$spacer),'ecopt_rights[8]',$this->ecopt_rights[8],array('ecopt_rights[8][0]'=>'&nbsp;','ecopt_rights[8][1]'=>'&nbsp;','ecopt_rights[8][2]'=>'&nbsp;','ecopt_rights[8][3]'=>'&nbsp;'),'', 'horizontal','', '', '4');
        $this->ecformEvent->checkbox(str_pad(substr(_c('Access to options without evts types managmnt','events-calendar'),0,$nit),$nit,$spacer),'ecopt_rights[9]',$this->ecopt_rights[9],array('ecopt_rights[9][0]'=>'&nbsp;','ecopt_rights[9][1]'=>'&nbsp;','ecopt_rights[9][2]'=>'&nbsp;','ecopt_rights[9][3]'=>'&nbsp;'),'', 'horizontal','', '', '4');
        $this->ecformEvent->checkbox(str_pad(substr(_c('Access to the import/export of events','events-calendar'),0,$nit),$nit,$spacer),'ecopt_rights[10]',$this->ecopt_rights[10],array('ecopt_rights[10][0]'=>'&nbsp;','ecopt_rights[10][1]'=>'&nbsp;','ecopt_rights[10][2]'=>'&nbsp;','ecopt_rights[10][3]'=>'&nbsp;'),'', 'horizontal','', '', '4');
      $this->ecformEvent->fieldset('end'); // Enf of fieldset right
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');
    return $output;
  }
  /**
   * About : Tooltips tab
   *
   * @return string     HTML
   */
  function funcinsSubMenu_Tooltips() {
    $bubble_width = array('normal'=>'normal (200px)','large'=>'large (250px)','x-large'=>'x-large (300px)');
    $bubble_color =  array('blue'=>'blue','cyan'=>'cyan','gray'=>'gray','green'=>'green','lblue'=>'light blue','red'=>'red','thistle'=>'thistle','yellow'=>'yellow');
    $this->ecformEvent->curtab('item0'); //Current Tab : About
    $this->ecformEvent->cursubtab('s02'); //Current Sub Tab : Credits
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
//$this->ecopt_btmsg = _c('Click date for more details','events-calendar');
    switch ($this->ecopt_mtt) {
      case 'ecopt_mttjq': // jQuery Tootips settings
        $this->ecformEvent->fieldset('start',_c('jQuery Tootips settings','events-calendar'),'class="ecf-fsline" id="ecf-fs_ttset"','class="ecf-legend_fieldset"');
          $this->ecformEvent->fieldset('start',_c('Common settings','events-calendar'),'class="ecf-fieldset" id="ecf-fs_ttscs"','class="ecf-legend_fieldset"');
            $this->ecformEvent->text('Delay','ecopt_jtts_delay',$this->ecopt_jtts_delay,'',2,2,'','','','id="ecf-jtts_delay"');
            $this->ecformEvent->checkbox_trigger(_c(" - Track?",'events-calendar'),'ecopt_jtts_track','',isset($this->ecopt_jtts_track),'','','','id="ecf-jtts_track"');
            $this->ecformEvent->text(' - Fade','ecopt_jtts_fade',$this->ecopt_jtts_fade,'',3,3,'','','','id="ecf-jtts_fade"');
            $this->ecformEvent->radio(_c('Tooltips style','events-calendar'), 'ecopt_jtts_style',$this->ecopt_jtts_style,array('ecopt_jtts_cla'=>_c('Classical','events-calendar'),'ecopt_jtts_bbl'=>_c('Bubble','events-calendar')),'','','');
          $this->ecformEvent->fieldset('end'); // Enf of Common settings fieldset
          $this->ecformEvent->fieldset('start',_c('Classical style','events-calendar'),'class="ecf-fieldset" id="ecf-fs_jtts_cla"','class="ecf-legend_fieldset"');
            $this->ecformEvent->text('Width','ecopt_jtts_cla_width',$this->ecopt_jtts_cla_width,'',3,3);
            $this->ecformEvent->text('Backgrd color','ecopt_jtts_cla_bgc',$this->ecopt_jtts_cla_bgc,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->text('Border, color','ecopt_jtts_cla_bdc',$this->ecopt_jtts_cla_bdc,'',7,7,'','class="iColorPicker"','','id="ecf-jtts_cla_bdc"');
            $this->ecformEvent->select('style', 'ecopt_jtts_cla_bds',$this->ecopt_jtts_cla_bds,$this->bord_style,'','','', '', 'single', 7,'id="ecf-jtts_cla_bds"');
            $this->ecformEvent->select('width', 'ecopt_jtts_cla_bdw',$this->ecopt_jtts_cla_bdw,$this->bord_width,'','','', '', 'single', 7,'id="ecf-jtts_cla_bdw"');
            $this->ecformEvent->fieldset('start',_c('Events titles style','events-calendar'),'class="ecf-fsline" id="ecf-fs_jtts_cla_top"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Backgrd color','ecopt_jtts_cla_top_bgc',$this->ecopt_jtts_cla_top_bgc,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->text('Text color','ecopt_jtts_cla_top_col',$this->ecopt_jtts_cla_top_col,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Text size', 'ecopt_jtts_cla_top_siz',$this->ecopt_jtts_cla_top_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font weight', 'ecopt_jtts_cla_top_wei',$this->ecopt_jtts_cla_top_wei,$this->font_weight,'','','', '', 'single',13);
              $this->ecformEvent->select('Font family', 'ecopt_jtts_cla_top_ffa',$this->ecopt_jtts_cla_top_ffa,$this->font_family,'','','', '', 'single', 7,'id="ecf-jtts_cla_top_ffa"');
              $this->ecformEvent->select('Font style', 'ecopt_jtts_cla_top_fst',$this->ecopt_jtts_cla_top_fst,$this->font_style,'','','', '', 'single', 7,'id="ecf-jtts_cla_top_fst"');
            $this->ecformEvent->fieldset('end'); // Enf of Events titles style fieldset
            $this->ecformEvent->fieldset('start',_c('Events Body style','events-calendar'),'class="ecf-fsline" id="ecf-fs_jtts_cla_mid"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Text color','ecopt_jtts_cla_mid_col',$this->ecopt_jtts_cla_mid_col,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Text size', 'ecopt_jtts_cla_mid_siz',$this->ecopt_jtts_cla_mid_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font family', 'ecopt_jtts_cla_mid_ffa',$this->ecopt_jtts_cla_mid_ffa,$this->font_family,'','','', '', 'single', 7,'id="ecf-jtts_cla_mid_ffa"');
              $this->ecformEvent->select('Font style', 'ecopt_jtts_cla_mid_fst',$this->ecopt_jtts_cla_mid_fst,$this->font_style,'','','', '', 'single', 7,'id="ecf-jtts_cla_mid_fst"');
            $this->ecformEvent->fieldset('end'); // Enf of Events Body style fieldset
            $this->ecformEvent->fieldset('start',_c('Bottom style','events-calendar'),'class="ecf-fsline" id="ecf-fs_jtts_cla_bot"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Backgrd color','ecopt_jtts_cla_bot_bgc',$this->ecopt_jtts_cla_bot_bgc,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->text('Text color','ecopt_jtts_cla_bot_col',$this->ecopt_jtts_cla_bot_col,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Text size', 'ecopt_jtts_cla_bot_siz',$this->ecopt_jtts_cla_bot_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font weight', 'ecopt_jtts_cla_bot_wei',$this->ecopt_jtts_cla_bot_wei,$this->font_weight,'','','', '', 'single',13);
              $this->ecformEvent->select('Font family', 'ecopt_jtts_cla_bot_ffa',$this->ecopt_jtts_cla_bot_ffa,$this->font_family,'','','', '', 'single', 7,'id="ecf-jtts_cla_bot_ffa"');
              $this->ecformEvent->text('Bottom msg','ecopt_jtts_cla_btmsg',$this->ecopt_jtts_cla_btmsg,'',16,40,'','','','id="ecf-jtts_clabtmsg"');
            $this->ecformEvent->fieldset('end'); // Enf of Bottom style fieldset
          $this->ecformEvent->fieldset('end'); // Enf of Classical style fieldset
          $this->ecformEvent->fieldset('start',_c('Bubble style','events-calendar'),'class="ecf-fieldset" id="ecf-fs_jtts_bbl"','class="ecf-legend_fieldset"');
            $this->ecformEvent->select('Width', 'ecopt_jtts_bbl_width',$this->ecopt_jtts_bbl_width,$bubble_width,'','','', '', 'single', 3,'id="ecf-jtts_bbl_width"');
            $this->ecformEvent->select('Color', 'ecopt_jtts_bbl_col',$this->ecopt_jtts_bbl_col,$bubble_color,'','','', '', 'single', 8);
            $this->ecformEvent->select('Position', 'ecopt_jtts_bbl_pos',$this->ecopt_jtts_bbl_pos,array('right'=>'right','left'=>'left'),'','','', '', 'single', 2);
            $this->ecformEvent->fieldset('start',_c('Events titles style','events-calendar'),'class="ecf-fsline" id="ecf-fs_jtts_bbl_top"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Text color','ecopt_jtts_bbl_top_col',$this->ecopt_jtts_bbl_top_col,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Font size', 'ecopt_jtts_bbl_top_siz',$this->ecopt_jtts_bbl_top_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font weight', 'ecopt_jtts_bbl_top_wei',$this->ecopt_jtts_bbl_top_wei,$this->font_weight,'','','', '', 'single',13);
              $this->ecformEvent->select('Font family', 'ecopt_jtts_bbl_top_ffa',$this->ecopt_jtts_bbl_top_ffa,$this->font_family,'','','', '', 'single', 7,'id="ecf-jtts_bbl_top_ffa"');
            $this->ecformEvent->fieldset('end'); // Enf of Events titles style fieldset
            $this->ecformEvent->fieldset('start',_c('Events Body style','events-calendar'),'class="ecf-fsline" id="ecf-fs_jtts_bbl_mid"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Text color','ecopt_jtts_bbl_mid_col',$this->ecopt_jtts_bbl_mid_col,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Font size', 'ecopt_jtts_bbl_mid_siz',$this->ecopt_jtts_bbl_mid_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font family', 'ecopt_jtts_bbl_mid_ffa',$this->ecopt_jtts_bbl_mid_ffa,$this->font_family,'','','', '', 'single', 7,'id="ecf-jtts_bbl_mid_ffa"');
              $this->ecformEvent->checkbox_trigger(_c("Separator",'events-calendar'),'ecopt_jtts_bbl_sep','',isset($this->ecopt_jtts_bbl_sep),'','','','id="ecf-jtts_bbl_sep"');
            $this->ecformEvent->fieldset('end'); // Enf of Events Body style fieldset
            $this->ecformEvent->fieldset('start',_c('Bottom style','events-calendar'),'class="ecf-fsline" id="ecf-fs_jtts_bbl_bot"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Text color','ecopt_jtts_bbl_bot_col',$this->ecopt_jtts_bbl_bot_col,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Font size', 'ecopt_jtts_bbl_bot_siz',$this->ecopt_jtts_bbl_bot_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font weight', 'ecopt_jtts_bbl_bot_wei',$this->ecopt_jtts_bbl_bot_wei,$this->font_weight,'','','', '', 'single',13);
              $this->ecformEvent->select('Font family', 'ecopt_jtts_bbl_bot_ffa',$this->ecopt_jtts_bbl_bot_ffa,$this->font_family,'','','', '', 'single', 7,'id="ecf-jtts_bbl_bot_ffa"');
              $this->ecformEvent->text('Bottom message','ecopt_jtts_bbl_btmsg',$this->ecopt_jtts_bbl_btmsg,'',40,40,'','','','id="ecf-jtts_bblbtmsg"');
            $this->ecformEvent->fieldset('end'); // Enf of Bottom style fieldset
          $this->ecformEvent->fieldset('end'); // Enf of Bubble style fieldset
          $this->ecformEvent->fieldset('start','','class="ecf-fieldset" id="ecf-fs_jtts_samcla"'); // Invisible Sample fieldset
            $this->ecformEvent->custom_code('&nbsp;','ecf-jtts_samplecla',$this->ecly_tooltip_overview_classic,'','','','id="ecf-jtts_samplecla"');
          $this->ecformEvent->fieldset('end'); // Enf of Invisible Sample fieldset
          $this->ecformEvent->fieldset('start','','class="ecf-fieldset" id="ecf-fs_jtts_sambbl"'); // Invisible Sample fieldset
            $this->ecformEvent->custom_code('&nbsp;','ecf-jtts_samplebbl',$this->ecly_tooltip_overview_bubble,'','','','id="ecf-jtts_samplebbl"');
          $this->ecformEvent->fieldset('end'); // Enf of Invisible Sample fieldset
          $this->ecformEvent->custom_code('&nbsp;','ecbuttwrap',ecly_mtButton('brefresh',_c('Refresh Overview','events-calendar')),'','','','id="ecf-btrefresh"');
        $this->ecformEvent->fieldset('end'); // Enf of Tooltips settings fieldset
      	break;
      case 'ecopt_mttec': // EC Tootips settings
        $templates = array('lblue'=>'blue','turquoise'=>'turquoise','lgray'=>'gray','lgreen'=>'green','lpink'=>'pink','lred'=>'red');
        $this->ecformEvent->fieldset('start',_c('EC Tootips settings','events-calendar'),'class="ecf-fsline" id="ecf-fs_ttset"','class="ecf-legend_fieldset"');
          $this->ecformEvent->fieldset('start',_c('General settings','events-calendar'),'class="ecf-fieldset" id="ecf-fs_ttscs"','class="ecf-legend_fieldset"');
            $this->ecformEvent->select('Backgrd color', 'ecopt_ectt_bgc',$this->ecopt_ectt_bgc,$templates,'','','', '', 'single', 6);
            $this->ecformEvent->checkbox_trigger(_c("Track",'events-calendar'),'ecopt_ectt_track','',isset($this->ecopt_ectt_track),'','','','id="ecf-ectt_track"');
            $this->ecformEvent->text('Width','ecopt_ectt_width',$this->ecopt_ectt_width,'',3,3,'','','','id="ecf-ectt_width"');
            $this->ecformEvent->text('Rounded corner size','ecopt_ectt_rcorner',$this->ecopt_ectt_rcorner,'',2,2,_c('Value must be between 0 and 20 max','events-calendar'),'','','id="ecf-ectt_rcorner"');
            $this->ecformEvent->hidden('ecopt_ectt_hidden',$this->ecly_ec_tooltip_content);
          $this->ecformEvent->fieldset('end'); // Enf of EC Tooltips settings fieldset
          $this->ecformEvent->fieldset('start',_c('Tooltip style','events-calendar'),'class="ecf-fieldset" id="ecf-fs_jtts_bbl"','class="ecf-legend_fieldset"');
            $this->ecformEvent->fieldset('start',_c('Events titles style','events-calendar'),'class="ecf-fsline" id="ecf-fs_ectt_top"','class="ecf-legend_fieldset"');
              $this->ecformEvent->select('Font size', 'ecopt_ectt_top_siz',$this->ecopt_ectt_top_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font weight', 'ecopt_ectt_top_wei',$this->ecopt_ectt_top_wei,$this->font_weight,'','','', '', 'single',13);
              $this->ecformEvent->select('Font family', 'ecopt_ectt_top_ffa',$this->ecopt_ectt_top_ffa,$this->font_family,'','','', '', 'single', 7,'id="ecf-ectt_top_ffa"');
              $this->ecformEvent->select('Text align', 'ecopt_ectt_top_tal',$this->ecopt_ectt_top_tal,array('left'=>'left','center'=>'center','right'=>'right'),'','','', '', 'single', 7,'id="ecf-ectt_top_tal"');
              $this->ecformEvent->text('Backgrd color','ecopt_ectt_top_bgc',$this->ecopt_ectt_top_bgc,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->text('Border color','ecopt_ectt_top_bdc',$this->ecopt_ectt_top_bdc,'',7,7,_c('Empty field = no border','events-calendar'),'class="iColorPicker"');
              $this->ecformEvent->text('Text color','ecopt_ectt_top_col',$this->ecopt_ectt_top_col,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Font style', 'ecopt_ectt_top_fst',$this->ecopt_ectt_top_fst,$this->font_style,'','','', '', 'single', 7,'id="ecf-ectt_top_fst"');
            $this->ecformEvent->fieldset('end'); // Enf of Events titles style fieldset
            $this->ecformEvent->fieldset('start',_c('Events Body style','events-calendar'),'class="ecf-fsline" id="ecf-fs_ectt_mid"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Text color','ecopt_ectt_mid_col',$this->ecopt_ectt_mid_col,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Font size', 'ecopt_ectt_mid_siz',$this->ecopt_ectt_mid_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font family', 'ecopt_ectt_mid_ffa',$this->ecopt_ectt_mid_ffa,$this->font_family,'','','', '', 'single', 7,'id="ecf-ectt_mid_ffa"');
              $this->ecformEvent->text('Border color','ecopt_ectt_mid_bdc',$this->ecopt_ectt_mid_bdc,'',7,7,_c('Empty field = no border','events-calendar'),'class="iColorPicker"');
            $this->ecformEvent->fieldset('end'); // Enf of Events Body style fieldset
            $this->ecformEvent->fieldset('start',_c('Bottom style','events-calendar'),'class="ecf-fsline" id="ecf-fs_ectt_bot"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Text color','ecopt_ectt_bot_col',$this->ecopt_ectt_bot_col,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Font size', 'ecopt_ectt_bot_siz',$this->ecopt_ectt_bot_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font weight', 'ecopt_ectt_bot_wei',$this->ecopt_ectt_bot_wei,$this->font_weight,'','','', '', 'single',13);
              $this->ecformEvent->select('Font family', 'ecopt_ectt_bot_ffa',$this->ecopt_ectt_bot_ffa,$this->font_family,'','','', '', 'single', 7,'id="ecf-ectt_bot_ffa"');
              $this->ecformEvent->select('Text align', 'ecopt_ectt_bot_tal',$this->ecopt_ectt_bot_tal,array('left'=>'left','center'=>'center','right'=>'right'),'','','', '', 'single', 7,'id="ecf-ectt_bot_tal"');
              $this->ecformEvent->text('Btm message','ecopt_ectt_btmsg',$this->ecopt_ectt_btmsg,'',15,40,'','','','id="ecf-tt_btmsg"');
            $this->ecformEvent->fieldset('end'); // Enf of Bottom style fieldset
          $this->ecformEvent->fieldset('end'); // Enf of EC Tooltips sample fieldset
          $this->ecformEvent->fieldset('start','','class="ecf-fieldset" id="ecf-fs_ectt_sample"'); // Invisible Sample fieldset
            $this->ecformEvent->custom_code('&nbsp;','ecf-ectt_sample',$this->ecly_ec_tooltip_overview,'','','','id="ecf-ectt_sample"');
          $this->ecformEvent->fieldset('end'); // Enf of EC Tooltips sample fieldset
          $this->ecformEvent->custom_code('&nbsp;','ecbuttwrap',ecly_mtButton('brefresh',_c('Refresh Overview','events-calendar')),'','','','id="ecf-btrefresh"');
        $this->ecformEvent->fieldset('end'); // Enf of EC Tooltips sample fieldset
      	break;
      case 'ecopt_mtcss': // CSS Tootips settings
        $this->ecformEvent->fieldset('start',_c('CSS Tootips settings','events-calendar'),'class="ecf-fsline" id="ecf-fs_ttset"','class="ecf-legend_fieldset"');
          $this->ecformEvent->fieldset('start',_c('Bubble style','events-calendar'),'class="ecf-fieldset" id="ecf-fs_jtts_bbl"','class="ecf-legend_fieldset"');
            $this->ecformEvent->select('Width', 'ecopt_csstt_bbl_width',$this->ecopt_csstt_bbl_width,$bubble_width,'','','', '', 'single', 3,'id="ecf-jtts_bbl_width"');
            $this->ecformEvent->select('Color', 'ecopt_csstt_bbl_col',$this->ecopt_csstt_bbl_col,$bubble_color,'','','', '', 'single', 8);
            $this->ecformEvent->select('Position', 'ecopt_csstt_bbl_pos',$this->ecopt_csstt_bbl_pos,array('right'=>'right','left'=>'left'),'','','', '', 'single', 2);
            $this->ecformEvent->fieldset('start',_c('Events titles style','events-calendar'),'class="ecf-fsline" id="ecf-fs_jtts_bbl_top"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Text color','ecopt_csstt_bbl_top_col',$this->ecopt_csstt_bbl_top_col,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Font size', 'ecopt_csstt_bbl_top_siz',$this->ecopt_csstt_bbl_top_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font weight', 'ecopt_csstt_bbl_top_wei',$this->ecopt_csstt_bbl_top_wei,$this->font_weight,'','','', '', 'single',13);
              $this->ecformEvent->select('Font family', 'ecopt_csstt_bbl_top_ffa',$this->ecopt_csstt_bbl_top_ffa,$this->font_family,'','','', '', 'single', 7,'id="ecf-jtts_bbl_top_ffa"');
              $this->ecformEvent->select('Font style', 'ecopt_csstt_bbl_top_fst',$this->ecopt_csstt_bbl_top_fst,$this->font_style,'','','', '', 'single', 7,'id="ecf-jtts_bbl_top_fst"');
            $this->ecformEvent->fieldset('end'); // Enf of Events titles style fieldset
            $this->ecformEvent->fieldset('start',_c('Events Body style','events-calendar'),'class="ecf-fsline" id="ecf-fs_jtts_bbl_mid"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Text color','ecopt_csstt_bbl_mid_col',$this->ecopt_csstt_bbl_mid_col,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Font size', 'ecopt_csstt_bbl_mid_siz',$this->ecopt_csstt_bbl_mid_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font family', 'ecopt_csstt_bbl_mid_ffa',$this->ecopt_csstt_bbl_mid_ffa,$this->font_family,'','','', '', 'single', 7,'id="ecf-jtts_bbl_mid_ffa"');
              $this->ecformEvent->select('Font style', 'ecopt_csstt_bbl_mid_fst',$this->ecopt_csstt_bbl_mid_fst,$this->font_style,'','','', '', 'single', 7,'id="ecf-jtts_bbl_mid_fst"');
              $this->ecformEvent->checkbox_trigger(_c("Separator",'events-calendar'),'ecopt_csstt_bbl_sep','',isset($this->ecopt_csstt_bbl_sep),'','','','id="ecf-jtts_bbl_sep"');
            $this->ecformEvent->fieldset('end'); // Enf of Events Body style fieldset
            $this->ecformEvent->fieldset('start',_c('Bottom style','events-calendar'),'class="ecf-fsline" id="ecf-fs_jtts_bbl_bot"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Text color','ecopt_csstt_bbl_bot_col',$this->ecopt_csstt_bbl_bot_col,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Font size', 'ecopt_csstt_bbl_bot_siz',$this->ecopt_csstt_bbl_bot_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font weight', 'ecopt_csstt_bbl_bot_wei',$this->ecopt_csstt_bbl_bot_wei,$this->font_weight,'','','', '', 'single',13);
              $this->ecformEvent->select('Font family', 'ecopt_csstt_bbl_bot_ffa',$this->ecopt_csstt_bbl_bot_ffa,$this->font_family,'','','', '', 'single', 7,'id="ecf-jtts_bbl_bot_ffa"');
              $this->ecformEvent->select('Font style', 'ecopt_csstt_bbl_bot_fst',$this->ecopt_csstt_bbl_bot_fst,$this->font_style,'','','', '', 'single', 7,'id="ecf-jtts_bbl_bot_fst"');
              $this->ecformEvent->text('Bottom message','ecopt_csstt_bbl_btmsg',$this->ecopt_csstt_bbl_btmsg,'',40,40,'','','','id="ecf-jtts_bblbtmsg"');
            $this->ecformEvent->fieldset('end'); // Enf of Bottom style fieldset
          $this->ecformEvent->fieldset('end'); // Enf of Bubble style fieldset
          $this->ecformEvent->fieldset('start','','class="ecf-fieldset" id="ecf-fs_jtts_sambbl"'); // Overview fieldset
            $this->ecformEvent->custom_code('&nbsp;','ecf-jtts_samplebbl',$this->ecly_tooltip_overview_bubble,'','','','id="ecf-jtts_samplebbl"');
          $this->ecformEvent->fieldset('end'); // Enf of Invisible Sample fieldset
          $this->ecformEvent->custom_code('&nbsp;','ecbuttwrap',ecly_mtButton('brefresh',_c('Refresh Overview','events-calendar')),'','','','id="ecf-btrefresh"');
        $this->ecformEvent->fieldset('end'); // Enf of Tooltips settings fieldset
      	break;
      default: break;
    } // end of the switch
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');
    return $output;
  }
  /**
   * About : Thickbox tab
   *
   * @return string     HTML
   */
  function funcinsSubMenu_Thickbox() {
    $this->ecformEvent->curtab('item0'); //Current Tab : About
    $this->ecformEvent->cursubtab('s03'); //Current Sub Tab : Credits
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
    switch ($this->ecopt_mtb) {
      case 'ecopt_mtbtb': // jQuery Thickbox
        $this->ecformEvent->fieldset('start',_c('jQuery Thickbox settings','events-calendar'),'class="ecf-fieldset" id="ecf-fs_tbset"','class="ecf-legend_fieldset"');
          $this->ecformEvent->fieldset('start','','id="ecf-fstbaseset"');
            $this->ecformEvent->fieldset('start',_c('Overlay','events-calendar'),'class="ecf-fsline ecf-fstbset"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Bgrnd col','ecopt_jtbs_obgc',$this->ecopt_jtbs_obgc,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->text('Opacity','ecopt_jtbs_opac',$this->ecopt_jtbs_opac,'',3,3,_c('This value must be set between 0 and 1','events-calendar'),'');
            $this->ecformEvent->fieldset('end'); // Enf of the Thickbox overlay settings fieldset
            $this->ecformEvent->fieldset('start',_c('Dimensions','events-calendar'),'class="ecf-fsline ecf-fstbset"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text(_c('Height','events-calendar'),'ecopt_jtbs_height',$this->ecopt_jtbs_height,'',3,3,'','','&nbsp;x&nbsp;');
              $this->ecformEvent->text(_c('Width','events-calendar'),'ecopt_jtbs_width',$this->ecopt_jtbs_width,'',3,3,'','','&nbsp;pixels');
            $this->ecformEvent->fieldset('end'); // Enf of the Thickbox dimensions settings fieldset
          $this->ecformEvent->fieldset('end'); // Enf of the Thickbox base settings fieldset
          $this->ecformEvent->fieldset('start',_c('Border','events-calendar'),'class="ecf-fsline"','class="ecf-legend_fieldset"');
            $this->ecformEvent->select('Width', 'ecopt_jtbs_bdw',$this->ecopt_jtbs_bdw,$this->bord_width,'','','', '', 'single', 7); //,'id="ecf-jtts_cla_bdw"');
            $this->ecformEvent->select('Style', 'ecopt_jtbs_bds',$this->ecopt_jtbs_bds,$this->bord_style,'','','', '', 'single', 7); //,'id="ecf-jtts_cla_bds"');
            $this->ecformEvent->text('Color','ecopt_jtbs_bcol',$this->ecopt_jtbs_bcol,'',7,7,'','class="iColorPicker"');
          $this->ecformEvent->fieldset('end'); // Enf of the Thickbox dimensions settings fieldset
          $this->ecformEvent->fieldset('start',_c('Thickbox title and navigation bar','events-calendar'),'class="ecf-fsline"','class="ecf-legend_fieldset"');
            $this->ecformEvent->text('Backgrnd col','ecopt_jtbs_tb_bgc',$this->ecopt_jtbs_tb_bgc,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->text('Text color','ecopt_jtbs_tb_col',$this->ecopt_jtbs_tb_col,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->select('Font size', 'ecopt_jtbs_tb_siz',$this->ecopt_jtbs_tb_siz,$this->font_size,'','','', '', 'single', 7);
            $this->ecformEvent->select('Font weight', 'ecopt_jtbs_tb_wei',$this->ecopt_jtbs_tb_wei,$this->font_weight,'','','', '', 'single',13);
            $this->ecformEvent->select('Font family', 'ecopt_jtbs_tb_ffa',$this->ecopt_jtbs_tb_ffa,$this->font_family,'','','', '', 'single', 7);
            $this->ecformEvent->select('Font style', 'ecopt_jtbs_tb_fst',$this->ecopt_jtbs_tb_fst,$this->font_style,'','','', '', 'single', 7);
          $this->ecformEvent->fieldset('end'); // Enf of the Thickbox title fieldset
          $this->ecformEvent->fieldset('start',_c('Thickbox content','events-calendar'),'class="ecf-fsline"','class="ecf-legend_fieldset"');
            $this->ecformEvent->text('Backgrnd col','ecopt_jtbs_ct_bgc',$this->ecopt_jtbs_ct_bgc,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->text('Text color','ecopt_jtbs_ct_col',$this->ecopt_jtbs_ct_col,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->select('Font size', 'ecopt_jtbs_ct_siz',$this->ecopt_jtbs_ct_siz,$this->font_size,'','','', '', 'single', 7);
            $this->ecformEvent->select('Font weight', 'ecopt_jtbs_ct_wei',$this->ecopt_jtbs_ct_wei,$this->font_weight,'','','', '', 'single',13);
            $this->ecformEvent->select('Font family', 'ecopt_jtbs_ct_ffa',$this->ecopt_jtbs_ct_ffa,$this->font_family,'','','', '', 'single', 7);
            //$this->ecformEvent->select('Font style', 'ecopt_jtbs_ct_fst',$this->ecopt_jtbs_ct_fst,$this->font_style,'','','', '', 'single', 7,'id="ecf-jtts_bbl_top_fst"');
            //$this->ecformEvent->checkbox_trigger(_c("Fieldset navigation",'events-calendar'),'ecopt_jtbs_ct_nav','',isset($this->ecopt_jtbs_ct_nav));
          $this->ecformEvent->fieldset('end'); // Enf of the Thickbox content fieldset
          $this->ecformEvent->fieldset('start',_c('Event fieldsets','events-calendar'),'class="ecf-fsline"','class="ecf-legend_fieldset"');
            $this->ecformEvent->text('Bgrnd col','ecopt_jtbs_fs_bgc',$this->ecopt_jtbs_fs_bgc,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->select('Font size', 'ecopt_jtbs_fs_siz',$this->ecopt_jtbs_fs_siz,$this->font_size,'','','', '', 'single', 7);
            $this->ecformEvent->select('Font weight', 'ecopt_jtbs_fs_wei',$this->ecopt_jtbs_fs_wei,$this->font_weight,'','','', '', 'single',13);
            $this->ecformEvent->fieldset('start',_c('Event fieldsets legend','events-calendar'),'class="ecf-fsline" id="ecf-fslegend"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Bgrnd col','ecopt_jtbs_fsl_bgc',$this->ecopt_jtbs_fsl_bgc,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Font size', 'ecopt_jtbs_fsl_siz',$this->ecopt_jtbs_fsl_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font weight', 'ecopt_jtbs_fsl_wei',$this->ecopt_jtbs_fsl_wei,$this->font_weight,'','','', '', 'single',13);
              $this->ecformEvent->select('Font style', 'ecopt_jtbs_fsl_fst',$this->ecopt_jtbs_fsl_fst,$this->font_style,'','','', '', 'single', 7);
            $this->ecformEvent->fieldset('end'); // Enf of the Event Fieldsets Legend fieldset
          $this->ecformEvent->fieldset('end'); // Enf of the Event Fieldsets fieldset
        $this->ecformEvent->fieldset('end'); // Enf of the jQuery Thickbox settings fieldset
        $this->ecformEvent->custom_code('&nbsp;','ecbuttwrap',ecly_mtButton('tbOverview',_c('Thickbox Overview','events-calendar')),'','','','id="ecf-tbset_btrefresh"');
        $this->ecformEvent->hidden('ecopt_jtbs_hidden',$this->ecly_tbpopup);
      	break;
      case 'ecopt_mtbsb': // Shadowbox
        $this->ecformEvent->fieldset('start',_c('Shadowbox settings','events-calendar'),'class="ecf-fieldset" id="ecf-fs_tbset"','class="ecf-legend_fieldset"');
          $this->ecformEvent->fieldset('start','','id="ecf-fstbaseset"');
            $this->ecformEvent->fieldset('start',_c('Overlay','events-calendar'),'class="ecf-fsline ecf-fstbset"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Bgrnd col','ecopt_sbtb_obgc',$this->ecopt_sbtb_obgc,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->text('Opacity','ecopt_sbtb_opac',$this->ecopt_sbtb_opac,'',3,3,_c('This value must be set between 0 and 1','events-calendar'),'');
            $this->ecformEvent->fieldset('end'); // Enf of the Shadowbox overlay settings fieldset
            $this->ecformEvent->fieldset('start',_c('Dimensions','events-calendar'),'class="ecf-fsline ecf-fstbset"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text(_c('Height','events-calendar'),'ecopt_sbtb_height',$this->ecopt_sbtb_height,'',3,3,'','','&nbsp;x&nbsp;');
              $this->ecformEvent->text(_c('Width','events-calendar'),'ecopt_sbtb_width',$this->ecopt_sbtb_width,'',3,3,'','','&nbsp;pixels');
            $this->ecformEvent->fieldset('end'); // Enf of the Shadowbox dimensions settings fieldset
          $this->ecformEvent->fieldset('end'); // Enf of the Shadowbox base settings fieldset
          $this->ecformEvent->fieldset('start',_c('Border','events-calendar'),'class="ecf-fsline"','class="ecf-legend_fieldset"');
            $this->ecformEvent->select('Width', 'ecopt_sbtb_bdw',$this->ecopt_sbtb_bdw,$this->bord_width,'','','', '', 'single', 7);
            $this->ecformEvent->select('Style', 'ecopt_sbtb_bds',$this->ecopt_sbtb_bds,$this->bord_style,'','','', '', 'single', 7);
            $this->ecformEvent->text('Color','ecopt_sbtb_bcol',$this->ecopt_sbtb_bcol,'',7,7,'','class="iColorPicker"');
          $this->ecformEvent->fieldset('end'); // Enf of the Shadowbox dimensions settings fieldset
          $this->ecformEvent->fieldset('start',_c('Shadowbox title','events-calendar'),'class="ecf-fsline"','class="ecf-legend_fieldset"');
            $this->ecformEvent->text('Backgrnd col','ecopt_sbtb_tb_bgc',$this->ecopt_sbtb_tb_bgc,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->text('Text color','ecopt_sbtb_tb_col',$this->ecopt_sbtb_tb_col,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->select('Font size', 'ecopt_sbtb_tb_siz',$this->ecopt_sbtb_tb_siz,$this->font_size,'','','', '', 'single', 7);
            $this->ecformEvent->select('Font weight', 'ecopt_sbtb_tb_wei',$this->ecopt_sbtb_tb_wei,$this->font_weight,'','','', '', 'single',13);
            $this->ecformEvent->select('Font family', 'ecopt_sbtb_tb_ffa',$this->ecopt_sbtb_tb_ffa,$this->font_family,'','','', '', 'single', 7);
            $this->ecformEvent->select('Font style', 'ecopt_sbtb_tb_fst',$this->ecopt_sbtb_tb_fst,$this->font_style,'','','', '', 'single', 7);
            $this->ecformEvent->select('Border: Width', 'ecopt_sbtb_tbw',$this->ecopt_sbtb_tbw,$this->bord_width,'','','', '', 'single', 7);
            $this->ecformEvent->select('Style', 'ecopt_sbtb_tbs',$this->ecopt_sbtb_tbs,$this->bord_style,'','','', '', 'single', 7);
            $this->ecformEvent->text('Color','ecopt_sbtb_tbc',$this->ecopt_sbtb_tbc,'',7,7,'','class="iColorPicker"');
          $this->ecformEvent->fieldset('end'); // Enf of the Shadowbox title fieldset
          $this->ecformEvent->fieldset('start',_c('Shadowbox content','events-calendar'),'class="ecf-fsline"','class="ecf-legend_fieldset"');
            $this->ecformEvent->text('Backgrnd col','ecopt_sbtb_ct_bgc',$this->ecopt_sbtb_ct_bgc,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->text('Text color','ecopt_sbtb_ct_col',$this->ecopt_sbtb_ct_col,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->select('Font size', 'ecopt_sbtb_ct_siz',$this->ecopt_sbtb_ct_siz,$this->font_size,'','','', '', 'single', 7);
            $this->ecformEvent->select('Font weight', 'ecopt_sbtb_ct_wei',$this->ecopt_sbtb_ct_wei,$this->font_weight,'','','', '', 'single',13);
            $this->ecformEvent->select('Font family', 'ecopt_sbtb_ct_ffa',$this->ecopt_sbtb_ct_ffa,$this->font_family,'','','', '', 'single', 7);
            //$this->ecformEvent->select('Font style', 'ecopt_sbtb_ct_fst',$this->ecopt_sbtb_ct_fst,$this->font_style,'','','', '', 'single', 7,'id="ecf-jtts_bbl_top_fst"');
            //$this->ecformEvent->checkbox_trigger(_c("Fieldset navigation",'events-calendar'),'ecopt_sbtb_ct_nav','',isset($this->ecopt_sbtb_ct_nav));
          $this->ecformEvent->fieldset('end'); // Enf of the Shadowbox content fieldset
          $this->ecformEvent->fieldset('start',_c('Event fieldsets','events-calendar'),'class="ecf-fsline"','class="ecf-legend_fieldset"');
            $this->ecformEvent->text('Bgrnd col','ecopt_sbtb_fs_bgc',$this->ecopt_sbtb_fs_bgc,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->select('Font size', 'ecopt_sbtb_fs_siz',$this->ecopt_sbtb_fs_siz,$this->font_size,'','','', '', 'single', 7);
            $this->ecformEvent->select('Font weight', 'ecopt_sbtb_fs_wei',$this->ecopt_sbtb_fs_wei,$this->font_weight,'','','', '', 'single',13);
            $this->ecformEvent->fieldset('start',_c('Event fieldsets legend','events-calendar'),'class="ecf-fsline" id="ecf-fslegend"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Bgrnd col','ecopt_sbtb_fsl_bgc',$this->ecopt_sbtb_fsl_bgc,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Font size', 'ecopt_sbtb_fsl_siz',$this->ecopt_sbtb_fsl_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font weight', 'ecopt_sbtb_fsl_wei',$this->ecopt_sbtb_fsl_wei,$this->font_weight,'','','', '', 'single',13);
              $this->ecformEvent->select('Font style', 'ecopt_sbtb_fsl_fst',$this->ecopt_sbtb_fsl_fst,$this->font_style,'','','', '', 'single', 7);
            $this->ecformEvent->fieldset('end'); // Enf of the Event Fieldsets Legend fieldset
          $this->ecformEvent->fieldset('end'); // Enf of the Event Fieldsets fieldset
        $this->ecformEvent->fieldset('end'); // Enf of the jQuery Shadowbox settings fieldset
        $this->ecformEvent->custom_code('&nbsp;','ecbuttwrap',ecly_mtButton('tbOverview',_c('Shadowbox Overview','events-calendar')),'','','','id="ecf-tbset_btrefresh"');
        $this->ecformEvent->hidden('ecopt_sbtb_hidden',$this->ecly_sbpopup);
      	break;
      case 'ecopt_mtblb': //  Lightbox compatible
        // See :
        //        Lightbox Plus : http://wordpress.org/extend/plugins/lightbox-plus/  : issue Colorbox (js) dont set iframe dynamically !!
        //        WP-prettyPhoto : http://wordpress.org/extend/plugins/wp-prettyphoto/ : good but jQuery conflict to correct
        //        SchmancyBox : http://wordpress.org/extend/plugins/schmancy-box/
        // I abandon the idea of Lightbox compatibility because in all cases that break too many problems of adaptation.
        // -------------------------------------------------------------------------------------------------------------
      	break;
      case 'ecopt_mtbcss': // CSS Thickbox
        $this->ecformEvent->fieldset('start',_c('CSS Thickbox settings','events-calendar'),'class="ecf-fieldset" id="ecf-fs_tbset"','class="ecf-legend_fieldset"');
          $this->ecformEvent->fieldset('start','','id="ecf-fstbaseset"');
            $this->ecformEvent->fieldset('start',_c('Overlay','events-calendar'),'class="ecf-fsline ecf-fstbset"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Bgrnd col','ecopt_csstb_obgc',$this->ecopt_csstb_obgc,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->text('Opacity','ecopt_csstb_opac',$this->ecopt_csstb_opac,'',3,3,_c('This value must be set between 0 and 1','events-calendar'),'');
            $this->ecformEvent->fieldset('end'); // Enf of the Thickbox overlay settings fieldset
            $this->ecformEvent->fieldset('start',_c('Dimensions','events-calendar'),'class="ecf-fsline ecf-fstbset"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text(_c('Height','events-calendar'),'ecopt_csstb_height',$this->ecopt_csstb_height,'',3,3,'','','&nbsp;x&nbsp;');
              $this->ecformEvent->text(_c('Width','events-calendar'),'ecopt_csstb_width',$this->ecopt_csstb_width,'',3,3,'','','&nbsp;pixels');
            $this->ecformEvent->fieldset('end'); // Enf of the Thickbox dimensions settings fieldset
          $this->ecformEvent->fieldset('end'); // Enf of the Thickbox base settings fieldset
          $this->ecformEvent->fieldset('start',_c('Border','events-calendar'),'class="ecf-fsline"','class="ecf-legend_fieldset"');
            $this->ecformEvent->select('Width', 'ecopt_csstb_bdw',$this->ecopt_csstb_bdw,$this->bord_width,'','','', '', 'single', 7); //,'id="ecf-jtts_cla_bdw"');
            $this->ecformEvent->select('Style', 'ecopt_csstb_bds',$this->ecopt_csstb_bds,$this->bord_style,'','','', '', 'single', 7); //,'id="ecf-jtts_cla_bds"');
            $this->ecformEvent->text('Color','ecopt_csstb_bcol',$this->ecopt_csstb_bcol,'',7,7,'','class="iColorPicker"');
          $this->ecformEvent->fieldset('end'); // Enf of the Thickbox dimensions settings fieldset
          $this->ecformEvent->fieldset('start',_c('Thickbox title and navigation bar','events-calendar'),'class="ecf-fsline"','class="ecf-legend_fieldset"');
            $this->ecformEvent->text('Backgrnd col','ecopt_csstb_tb_bgc',$this->ecopt_csstb_tb_bgc,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->text('Text color','ecopt_csstb_tb_col',$this->ecopt_csstb_tb_col,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->select('Font size', 'ecopt_csstb_tb_siz',$this->ecopt_csstb_tb_siz,$this->font_size,'','','', '', 'single', 7);
            $this->ecformEvent->select('Font weight', 'ecopt_csstb_tb_wei',$this->ecopt_csstb_tb_wei,$this->font_weight,'','','', '', 'single',13);
            $this->ecformEvent->select('Font family', 'ecopt_csstb_tb_ffa',$this->ecopt_csstb_tb_ffa,$this->font_family,'','','', '', 'single', 7);
            $this->ecformEvent->select('Font style', 'ecopt_csstb_tb_fst',$this->ecopt_csstb_tb_fst,$this->font_style,'','','', '', 'single', 7);
          $this->ecformEvent->fieldset('end'); // Enf of the Thickbox title fieldset
          $this->ecformEvent->fieldset('start',_c('Thickbox content','events-calendar'),'class="ecf-fsline"','class="ecf-legend_fieldset"');
            $this->ecformEvent->text('Backgrnd col','ecopt_csstb_ct_bgc',$this->ecopt_csstb_ct_bgc,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->text('Text color','ecopt_csstb_ct_col',$this->ecopt_csstb_ct_col,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->select('Font size', 'ecopt_csstb_ct_siz',$this->ecopt_csstb_ct_siz,$this->font_size,'','','', '', 'single', 7);
            $this->ecformEvent->select('Font weight', 'ecopt_csstb_ct_wei',$this->ecopt_csstb_ct_wei,$this->font_weight,'','','', '', 'single',13);
            $this->ecformEvent->select('Font family', 'ecopt_csstb_ct_ffa',$this->ecopt_csstb_ct_ffa,$this->font_family,'','','', '', 'single', 7);
            //$this->ecformEvent->select('Font style', 'ecopt_csstb_ct_fst',$this->ecopt_csstb_ct_fst,$this->font_style,'','','', '', 'single', 7,'id="ecf-jtts_bbl_top_fst"');
            //$this->ecformEvent->checkbox_trigger(_c("Fieldset navigation",'events-calendar'),'ecopt_csstb_ct_nav','',isset($this->ecopt_csstb_ct_nav));
          $this->ecformEvent->fieldset('end'); // Enf of the Thickbox content fieldset
          $this->ecformEvent->fieldset('start',_c('Event fieldsets','events-calendar'),'class="ecf-fsline"','class="ecf-legend_fieldset"');
            $this->ecformEvent->text('Bgrnd col','ecopt_csstb_fs_bgc',$this->ecopt_csstb_fs_bgc,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->select('Font size', 'ecopt_csstb_fs_siz',$this->ecopt_csstb_fs_siz,$this->font_size,'','','', '', 'single', 7);
            $this->ecformEvent->select('Font weight', 'ecopt_csstb_fs_wei',$this->ecopt_csstb_fs_wei,$this->font_weight,'','','', '', 'single',13);
            $this->ecformEvent->fieldset('start',_c('Event fieldsets legend','events-calendar'),'class="ecf-fsline" id="ecf-fslegend"','class="ecf-legend_fieldset"');
              $this->ecformEvent->text('Bgrnd col','ecopt_csstb_fsl_bgc',$this->ecopt_csstb_fsl_bgc,'',7,7,'','class="iColorPicker"');
              $this->ecformEvent->select('Font size', 'ecopt_csstb_fsl_siz',$this->ecopt_csstb_fsl_siz,$this->font_size,'','','', '', 'single', 7);
              $this->ecformEvent->select('Font weight', 'ecopt_csstb_fsl_wei',$this->ecopt_csstb_fsl_wei,$this->font_weight,'','','', '', 'single',13);
              $this->ecformEvent->select('Font style', 'ecopt_csstb_fsl_fst',$this->ecopt_csstb_fsl_fst,$this->font_style,'','','', '', 'single', 7);
            $this->ecformEvent->fieldset('end'); // Enf of the Event Fieldsets Legend fieldset
          $this->ecformEvent->fieldset('end'); // Enf of the Event Fieldsets fieldset
        $this->ecformEvent->fieldset('end'); // Enf of the Css Thickbox settings fieldset
        $this->ecformEvent->custom_code('&nbsp;','ecbuttwrap',ecly_mtButton('tbOverview',_c('Thickbox Overview','events-calendar')),'','','','id="ecf-tbset_btrefresh"');
        $this->ecformEvent->hidden('ecopt_csstb_hidden',$this->ecly_tbpopup);
      	break;
      default: break;
    } // end of the switch
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');
    return $output;
  }
  /**
   * Sidebar : No Widget activated frame
   *
   * @return string     HTML
   */
  function funcinsSubMenu_NoWidget() {
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
    $this->ecformEvent->fieldset('start',_c('There is no widget activated !','events-calendar'),'class="ecf-fieldset"','class="ecf-legend_fieldset"');
    $this->ecformEvent->custom_code('&nbsp;','none','<br/><b>'._c('Events-Calendar has not detected any of its widgets','events-calendfar').'</b><br/><br/>'.sprintf(_c('Please enable at least one widget %shere%s to set its options','events-calendar'),'<a href="'.get_bloginfo('wpurl').'/wp-admin/widgets.php">','</a>').'<br/><br/>');
    $this->ecformEvent->fieldset('end'); // Enf of No Active Widget fiealdset
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');

    return $output;
  }
  /**
   * Sidebar : Widget Calendar form tab
   *
   * @return string     HTML
   */
  function funcinsSubMenu_WCalendar() {
    $lmx = 13;
    $this->ecformEvent->curtab('item1'); //Current Tab : Sidebar
    $this->ecformEvent->cursubtab('s10'); //Current Sub Tab : Settings
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
      $this->ecformEvent->fieldset('start',_c('Basic settings','events-calendar'),'class="ecf-fieldset" id="ecf-fs_wcbs"','class="ecf-legend_fieldset"');
        $this->ecformEvent->text(_c('Length of the names of the weekdays','events-calendar'),'ecopt_wc_wdl',$this->ecopt_wc_wdl,'',2,2);
        $this->ecformEvent->text(_c('Events Calendar, dominant color','events-calendar'),'ecopt_wc_ecdc',$this->ecopt_wc_ecdc,'',7,7,'','class="iColorPicker"');
        $this->ecformEvent->text(_c('Posts Calendar, dominant color','events-calendar'),'ecopt_wc_pcdc',$this->ecopt_wc_pcdc,'',7,7,'','class="iColorPicker"');
        $this->ecformEvent->text(_c('Today date color','events-calendar'),'ecopt_wc_todaydcol',$this->ecopt_wc_todaydcol,'',7,7,'','class="iColorPicker"');
        $this->ecformEvent->select(_c('Today Background image','events-calendar'),'ecopt_wc_todaybgimg',$this->ecopt_wc_todaybgimg,$this->ec_imgDirList(),'', _c('This file must be into the &quot;user/images&quot; plugin directory.<hr style=\'color:pink;\'>If you prefer a background color click on my label.','events-calendar'),'','<img onclick="javascript:showImg(\'ecopt_wc_todaybgimg\');" class="showImg">','single',12,'id="ecf-wc_todaybgimg"'.($this->ecopt_wc_todaybgcol?' style="display:none"':''));
        $this->ecformEvent->text(_c('Today Background color','events-calendar'),'ecopt_wc_todaybgcol',$this->ecopt_wc_todaybgcol,'',7,7,'','class="iColorPicker"','<img src="'.EVENTSCALENDARIMAGESURL.'/ques_mark_inv.png" style="margin:2px 3px 0;" tooltiptext="'._c('If you prefer a background image click on my label.','events-calendar').'"/>','id="ecf-wc_todaybgcol"'.($this->ecopt_wc_todaybgcol?'':' style="display:none"'));
      $this->ecformEvent->fieldset('end'); // Enf of Basic settings fieldset
      $this->ecformEvent->fieldset('start',_c("Widget Calendar tabs",'events-calendar'),'class="ecf-fieldset" id="ecf-fs_wcct"','class="ecf-legend_fieldset"'); // Calendar tabs fieldset
        $this->ecformEvent->checkbox_trigger(_c("Allow calendar tabs?",'events-calendar'),'ecopt_wc_tabs','',isset($this->ecopt_wc_tabs));
        $this->ecformEvent->fieldset('start','','id="ecf-fs_tabslist"'); // Invisible fieldset
          $this->ecformEvent->custom_code('&nbsp;','tabs-grid','<table id="tabs-grid" class="scroll" cellpadding="0" cellspacing="0"></table>');
          $this->ecformEvent->text('&nbsp;','ecopt_sertabs',stripslashes(htmlentities($this->ecopt_sertabs)),'',1,15000,_c('Click on a row to edit, Enter for save and Escape for cancel','events-calendar'),'READONLY style="width:0;margin:0;border:none;background-color:#eaf3fa;"');
          $this->ecformEvent->select(_c("Today Event Post'it",'events-calendar'),'ecopt_wc_bkimgtde',$this->ecopt_wc_bkimgtde,$this->ec_imgDirList(),'', _c('This file must be into the &quot;user/images&quot; plugin directory','events-calendar'),'','<img onclick="javascript:showImg(\'ecopt_wc_bkimgtde\');" class="showImg">', 'single', 12 );
        $this->ecformEvent->fieldset('end'); // Enf invisible fieldset
      $this->ecformEvent->fieldset('end'); // Enf of Calendar tabs fieldset
      $this->ecformEvent->fieldset('start','Thickbox Settings','class="ecf-fieldset" id="ecf-fs_wctbs"','class="ecf-legend_fieldset"'); // Thickbox Settings fieldset
        $this->ecformEvent->select(_c('Date Format'),'ecopt_wc_tbdf',$this->ecopt_wc_tbdf,$this->show_date_formats('date','ecopt_wc_tbdf'),'', '','', $this->dtPostExt('date', 'wc_tbdf'), 'single', 6);
        $this->ecformEvent->select(_c('Time Format'),'ecopt_wc_tbtf',$this->ecopt_wc_tbtf,$this->show_date_formats('time','ecopt_wc_tbtf'),'', '','', $this->dtPostExt('time', 'wc_tbtf'), 'single', 6);
        $this->ecformEvent->select(_c('Title Date Format','events-calendar'),'ecopt_wc_dftt',$this->ecopt_wc_dftt,$this->show_date_formats('title','ecopt_wc_dftt'),'','','',$this->dtPostExt('date', 'wc_dftt'), 'single',6);
        $this->ecformEvent->fieldset('start',_c('Display by order','events-calendar'),'class="ecf-fieldset-in" id="ecf-fs_wcdbo"','class="ecf-legend_fieldset"',_c('fs = into a fieldset, order 0 = no display','events-calendar')); // Display by order fieldset
          $this->ecformEvent->select(substr(_c('Event Type','events-calendar'),0,$lmx),'ecopt_wc_tbd_evt',$this->ecopt_wc_tbd_evt,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Description','events-calendar'),0,$lmx),'ecopt_wc_tbd_des',$this->ecopt_wc_tbd_des,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Location','events-calendar'),0,$lmx),'ecopt_wc_tbd_loc',$this->ecopt_wc_tbd_loc,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Link out','events-calendar'),0,$lmx),'ecopt_wc_tbd_lko',$this->ecopt_wc_tbd_lko,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Address','events-calendar'),0,$lmx),'ecopt_wc_tbd_adr',$this->ecopt_wc_tbd_adr,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Manager','events-calendar'),0,$lmx),'ecopt_wc_tbd_man',$this->ecopt_wc_tbd_man,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Contact','events-calendar'),0,$lmx),'ecopt_wc_tbd_ctc',$this->ecopt_wc_tbd_ctc,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Phase','events-calendar'),0,$lmx),'ecopt_wc_tbd_pha',$this->ecopt_wc_tbd_pha,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Participation','events-calendar'),0,$lmx),'ecopt_wc_tbd_par',$this->ecopt_wc_tbd_par,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Cost','events-calendar'),0,$lmx),'ecopt_wc_tbd_cst',$this->ecopt_wc_tbd_cst,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Post link','events-calendar'),0,$lmx),'ecopt_wc_tbd_lkp',$this->ecopt_wc_tbd_lkp,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('GMap link','events-calendar'),0,$lmx),'ecopt_wc_tbd_lkg',$this->ecopt_wc_tbd_lkg,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('GMap iFrm','events-calendar'),0,$lmx),'ecopt_wc_tbd_ggm',$this->ecopt_wc_tbd_ggm,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Cust fields','events-calendar'),0,$lmx),'ecopt_wc_tbd_csf',$this->ecopt_wc_tbd_csf,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
        $this->ecformEvent->fieldset('end'); // Enf of Display by order fieldset
      $this->ecformEvent->fieldset('end'); // Enf of Thickbox Settings fieldset
      $this->ecformEvent->fieldset('start','Tooltips Settings','class="ecf-fieldset" id="ecf-fs_wctts"','class="ecf-legend_fieldset"'); // Tooltips Settings fieldset
        $this->ecformEvent->select(_c('Date Format'),'ecopt_wc_ttdf',$this->ecopt_wc_ttdf,$this->show_date_formats('date','ecopt_wc_ttdf'),'','','', $this->dtPostExt('date', 'wc_ttdf'), 'single', 6);
        $this->ecformEvent->select(_c('Time Format'),'ecopt_wc_tttf',$this->ecopt_wc_tttf,$this->show_date_formats('time','ecopt_wc_tttf'),'', '','', $this->dtPostExt('time', 'wc_tttf'), 'single', 6);
        $this->ecformEvent->checkbox_trigger(_c('Fixed?','events-calendar'),'ecopt_wc_fixed','',isset($this->ecopt_wc_fixed),_c('Track is useful if links are to click in the tooltip','events-calendar'));
        $this->ecformEvent->checkbox(_c('Display','events-calendar'),'ecopt_wc_tt_disp',$this->ecopt_wc_tt_disp,array('ecopt_wc_tt_disp0'=>_c('Event Type','events-calendar'),'ecopt_wc_tt_disp1'=>_c('Description','events-calendar'),'ecopt_wc_tt_disp2'=>_c('Location','events-calendar'),'ecopt_wc_tt_disp3'=>_c('Link out','events-calendar'),'ecopt_wc_tt_disp4'=>_c('Phase','events-calendar'),'ecopt_wc_tt_disp5'=>_c('Participation','events-calendar'),'ecopt_wc_tt_disp6'=>_c('Link to post','events-calendar')),'', 'vertical','', '', '2'); //,'id="ecf-wc_ttdisprow"','id="ecf-wc_ttdispcell"');
      $this->ecformEvent->fieldset('end'); // Enf of Tooltips Settings fieldset
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');
    return $output;
  }
  /**
   * Sidebar : List 1 form tab
   *
   * @return string     HTML
   */
  function funcinsSubMenu_List1() {
    $lmx = 13;
    $this->ecformEvent->curtab('item1'); //Current Tab : Sidebar
    $this->ecformEvent->cursubtab('s11'); //Current Sub Tab : List 1
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
      $this->ecformEvent->fieldset('start',_c('Basic settings','events-calendar'),'class="ecf-fieldset" id="ecf-fs_l1bs"','class="ecf-legend_fieldset"');
        $this->ecformEvent->checkbox_trigger(_c('Allow browsing?','events-calendar'),'ecopt_l1_brs','',isset($this->ecopt_l1_brs),_c('Allow browsing = allows scrolling of the list in time','events-calendar'));
        $this->ecformEvent->text(_c('Number of events displayed','events-calendar'),'ecopt_l1_ned',$this->ecopt_l1_ned,'',2,2,_c('= Number of events in the list','events-calendar'));
        $this->ecformEvent->select(_c('List Date Format','events-calendar'),'ecopt_l1_dfil',$this->ecopt_l1_dfil,$this->show_date_formats('list','ecopt_l1_dfil'),'','','',$this->dtPostExt('date', 'l1_dfil'), 'single',6);
        $this->ecformEvent->text(_c('Width list','events-calendar'),'ecopt_l1_width',$this->ecopt_l1_width,'',3,3,_c('Width of the list to adjust depending of the one of the sidebar of your theme','events-calendar'));
      $this->ecformEvent->fieldset('end'); // Enf of Bottom fieldset
      $this->ecformEvent->fieldset('start','Tooltips Settings','class="ecf-fieldset" id="ecf-fs_l1tts"','class="ecf-legend_fieldset"'); // Top fieldset
        $this->ecformEvent->select(_c('Date Format'),'ecopt_l1_ttdf',$this->ecopt_l1_ttdf,$this->show_date_formats('date','ecopt_l1_ttdf'),'','','', $this->dtPostExt('date', 'l1_ttdf'), 'single', 6);
        $this->ecformEvent->select(_c('Time Format'),'ecopt_l1_tttf',$this->ecopt_l1_tttf,$this->show_date_formats('time','ecopt_l1_tttf'),'', '','', $this->dtPostExt('time', 'l1_tttf'), 'single', 6);
        $this->ecformEvent->checkbox_trigger(_c('Fixed?','events-calendar'),'ecopt_l1_fixed','',isset($this->ecopt_l1_fixed),_c('Track is useful if links are to click in the tooltip','events-calendar'));
        $this->ecformEvent->checkbox(_c('Display','events-calendar'),'ecopt_l1_tt_disp',$this->ecopt_l1_tt_disp,array('ecopt_l1_tt_disp0'=>_c('Event Type','events-calendar'),'ecopt_l1_tt_disp1'=>_c('Description','events-calendar'),'ecopt_l1_tt_disp2'=>_c('Location','events-calendar'),'ecopt_l1_tt_disp3'=>_c('Link out','events-calendar'),'ecopt_l1_tt_disp4'=>_c('Phase','events-calendar'),'ecopt_l1_tt_disp5'=>_c('Participation','events-calendar'),'ecopt_l1_tt_disp6'=>_c('Link to post','events-calendar')),'', 'vertical','', '', '2');
      $this->ecformEvent->fieldset('end'); // Enf of Bottom fieldset
      $this->ecformEvent->fieldset('start','Thickbox Settings','class="ecf-fieldset" id="ecf-fs_l1tbs"','class="ecf-legend_fieldset"'); // Top fieldset
        $this->ecformEvent->fieldset('start','','id="ecf-fs_l1tb"'); // Invisible main fieldset
          $this->ecformEvent->select(_c('Date Format'),'ecopt_l1_tbdf',$this->ecopt_l1_tbdf,$this->show_date_formats('date','ecopt_l1_tbdf'),'', '','', $this->dtPostExt('date', 'l1_tbdf'), 'single', 6);
          $this->ecformEvent->select(_c('Time Format'),'ecopt_l1_tbtf',$this->ecopt_l1_tbtf,$this->show_date_formats('time','ecopt_l1_tbtf'),'', '','', $this->dtPostExt('time', 'l1_tbtf'), 'single', 6);
          $this->ecformEvent->select(_c('Title Date Format','events-calendar'),'ecopt_l1_dftt',$this->ecopt_l1_dftt,$this->show_date_formats('title','ecopt_l1_dftt'),'','','',$this->dtPostExt('date', 'l1_dftt'), 'single',6);
        $this->ecformEvent->fieldset('end'); // Enf of invisible fieldset
        $this->ecformEvent->fieldset('start',_c('Display by order','events-calendar'),'class="ecf-fieldset-in" id="ecf-fs_l1dbo"','class="ecf-legend_fieldset"',_c('fs = into a fieldset, order 0 = no display','events-calendar')); // Display by order fieldset
          $this->ecformEvent->select(substr(_c('Event Type','events-calendar'),0,$lmx),'ecopt_l1_tbd_evt',$this->ecopt_l1_tbd_evt,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Description','events-calendar'),0,$lmx),'ecopt_l1_tbd_des',$this->ecopt_l1_tbd_des,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Location','events-calendar'),0,$lmx),'ecopt_l1_tbd_loc',$this->ecopt_l1_tbd_loc,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Link out','events-calendar'),0,$lmx),'ecopt_l1_tbd_lko',$this->ecopt_l1_tbd_lko,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Address','events-calendar'),0,$lmx),'ecopt_l1_tbd_adr',$this->ecopt_l1_tbd_adr,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Manager','events-calendar'),0,$lmx),'ecopt_l1_tbd_man',$this->ecopt_l1_tbd_man,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Contact','events-calendar'),0,$lmx),'ecopt_l1_tbd_ctc',$this->ecopt_l1_tbd_ctc,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Phase','events-calendar'),0,$lmx),'ecopt_l1_tbd_pha',$this->ecopt_l1_tbd_pha,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Participation','events-calendar'),0,$lmx),'ecopt_l1_tbd_par',$this->ecopt_l1_tbd_par,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Cost','events-calendar'),0,$lmx),'ecopt_l1_tbd_cst',$this->ecopt_l1_tbd_cst,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Post link','events-calendar'),0,$lmx),'ecopt_l1_tbd_lkp',$this->ecopt_l1_tbd_lkp,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('GMap link','events-calendar'),0,$lmx),'ecopt_l1_tbd_lkg',$this->ecopt_l1_tbd_lkg,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('GMap iFrm','events-calendar'),0,$lmx),'ecopt_l1_tbd_ggm',$this->ecopt_l1_tbd_ggm,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Cust fields','events-calendar'),0,$lmx),'ecopt_l1_tbd_csf',$this->ecopt_l1_tbd_csf,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
        $this->ecformEvent->fieldset('end'); // Enf of Bottom fieldset
      $this->ecformEvent->fieldset('end'); // Enf of Bottom fieldset
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');
    return $output;
  }
  /**
   * Sidebar : List 2 form tab
   *
   * @return string     HTML
   */
  function funcinsSubMenu_List2() {
    $lmx = 13; $size_label = str_pad(_c('Size:','events-calendar'),100,'&nbsp;')._c('height','events-calendar');
    $this->ecformEvent->curtab('item1'); //Current Tab : Sidebar
    $this->ecformEvent->cursubtab('s12'); //Current Sub Tab : List 2
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
      $this->ecformEvent->fieldset('start',_c('Basic settings','events-calendar'),'class="ecf-fieldset" id="ecf-fs_l2bs"','class="ecf-legend_fieldset"');
        $this->ecformEvent->custom_code(_c('Dimensions','events-calendar'),'size','&nbsp;','','','','id="ecf-l2sizeRow"','id="ecf-l2sizeCell"');
        $this->ecformEvent->text(_c('height','events-calendar'),'ecopt_l2_height',$this->ecopt_l2_height,'',3,3,'','','&nbsp;x&nbsp;','id="ecf-l2heightRow"','id="ecf-l2heightCell"');
        $this->ecformEvent->text(_c('width','events-calendar'),'ecopt_l2_width',$this->ecopt_l2_width,'',3,3,'','','&nbsp;pixels','id="ecf-l2widthRow"','id="ecf-l2widthCell"');
        $this->ecformEvent->select(_c('List Date Format','events-calendar'),'ecopt_l2_dfil',$this->ecopt_l2_dfil,$this->show_date_formats('list','ecopt_l2_dfil'),'','','',$this->dtPostExt('date', 'l2_dfil'), 'single',6);
        $this->ecformEvent->checkbox_trigger(_c('View previous events?','events-calendar'),'ecopt_l2_prevts','',isset($this->ecopt_l2_prevts),'','style="margin-right:22px;"','','id="ecf-reccstatusrow"','id="ecf-reccstatuscell"');
      $this->ecformEvent->fieldset('end'); // Enf of Bottom fieldset
      $this->ecformEvent->fieldset('start','Tooltips Settings','class="ecf-fieldset" id="ecf-fs_l2tts"','class="ecf-legend_fieldset"'); // Top fieldset
        $this->ecformEvent->select(_c('Date Format'),'ecopt_l2_ttdf',$this->ecopt_l2_ttdf,$this->show_date_formats('date','ecopt_l2_ttdf'),'','','', $this->dtPostExt('date', 'l2_ttdf'), 'single', 6);
        $this->ecformEvent->select(_c('Time Format'),'ecopt_l2_tttf',$this->ecopt_l2_tttf,$this->show_date_formats('time','ecopt_l2_tttf'),'', '','', $this->dtPostExt('time', 'l2_tttf'), 'single', 6);
        $this->ecformEvent->checkbox_trigger(_c('Fixed?','events-calendar'),'ecopt_l2_fixed','',isset($this->ecopt_l2_fixed),_c('Track is useful if links are to click in the tooltip','events-calendar'));
        $this->ecformEvent->checkbox(_c('Display','events-calendar'),'ecopt_l2_tt_disp',$this->ecopt_l2_tt_disp,array('ecopt_l2_tt_disp0'=>_c('Event Type','events-calendar'),'ecopt_l2_tt_disp1'=>_c('Description','events-calendar'),'ecopt_l2_tt_disp2'=>_c('Location','events-calendar'),'ecopt_l2_tt_disp3'=>_c('Link out','events-calendar'),'ecopt_l2_tt_disp4'=>_c('Phase','events-calendar'),'ecopt_l2_tt_disp5'=>_c('Participation','events-calendar'),'ecopt_l2_tt_disp6'=>_c('Link to post','events-calendar')),'', 'vertical','', '', '2','id="ecf-reccbwdayrow"','id="ecf-reccbwdaycell"');
      $this->ecformEvent->fieldset('end'); // Enf of Bottom fieldset
      $this->ecformEvent->fieldset('start','Thickbox Settings','class="ecf-fieldset" id="ecf-fs_l2tbs"','class="ecf-legend_fieldset"'); // Top fieldset
        $this->ecformEvent->fieldset('start','','id="ecf-fs_l2tb"'); // Invisible fieldset
          $this->ecformEvent->select(_c('Date Format'),'ecopt_l2_tbdf',$this->ecopt_l2_tbdf,$this->show_date_formats('date','ecopt_l2_tbdf'),'', '','', $this->dtPostExt('date', 'l2_tbdf'), 'single', 6);
          $this->ecformEvent->select(_c('Time Format'),'ecopt_l2_tbtf',$this->ecopt_l2_tbtf,$this->show_date_formats('time','ecopt_l2_tbtf'),'', '','', $this->dtPostExt('time', 'l2_tbtf'), 'single', 6);
          $this->ecformEvent->select(_c('Title Date Format','events-calendar'),'ecopt_l2_dftt',$this->ecopt_l2_dftt,$this->show_date_formats('title','ecopt_l2_dftt'),'','','',$this->dtPostExt('date', 'l2_dftt'), 'single',6);
        $this->ecformEvent->fieldset('end'); // Enf of invisible fieldset
        $this->ecformEvent->fieldset('start',_c('Display by order','events-calendar'),'class="ecf-fieldset-in" id="ecf-fs_l2dbo"','class="ecf-legend_fieldset"',_c('fs = into a fieldset, order 0 = no display','events-calendar')); // Display by order fieldset
          $this->ecformEvent->select(substr(_c('Event Type','events-calendar'),0,$lmx),'ecopt_l2_tbd_evt',$this->ecopt_l2_tbd_evt,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Description','events-calendar'),0,$lmx),'ecopt_l2_tbd_des',$this->ecopt_l2_tbd_des,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Location','events-calendar'),0,$lmx),'ecopt_l2_tbd_loc',$this->ecopt_l2_tbd_loc,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Link out','events-calendar'),0,$lmx),'ecopt_l2_tbd_lko',$this->ecopt_l2_tbd_lko,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Address','events-calendar'),0,$lmx),'ecopt_l2_tbd_adr',$this->ecopt_l2_tbd_adr,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Manager','events-calendar'),0,$lmx),'ecopt_l2_tbd_man',$this->ecopt_l2_tbd_man,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Contact','events-calendar'),0,$lmx),'ecopt_l2_tbd_ctc',$this->ecopt_l2_tbd_ctc,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Phase','events-calendar'),0,$lmx),'ecopt_l2_tbd_pha',$this->ecopt_l2_tbd_pha,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Participation','events-calendar'),0,$lmx),'ecopt_l2_tbd_par',$this->ecopt_l2_tbd_par,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Cost','events-calendar'),0,$lmx),'ecopt_l2_tbd_cst',$this->ecopt_l2_tbd_cst,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Post link','events-calendar'),0,$lmx),'ecopt_l2_tbd_lkp',$this->ecopt_l2_tbd_lkp,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('GMap link','events-calendar'),0,$lmx),'ecopt_l2_tbd_lkg',$this->ecopt_l2_tbd_lkg,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('GMap iFrm','events-calendar'),0,$lmx),'ecopt_l2_tbd_ggm',$this->ecopt_l2_tbd_ggm,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->select(substr(_c('Cust fields','events-calendar'),0,$lmx),'ecopt_l2_tbd_csf',$this->ecopt_l2_tbd_csf,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
        $this->ecformEvent->fieldset('end'); // Enf of Display by order fieldset
      $this->ecformEvent->fieldset('end'); // Enf of Thickbox settings fieldset
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');
    return $output;
  }
  /**
   * Sidebar : List 3 form tab
   * Not implemented in this version
   *
   * @return string     HTML
   */
  function funcinsSubMenu_List3() {
    $this->ecformEvent->curtab('item1'); //Current Tab : Sidebar
    $this->ecformEvent->cursubtab('s13'); //Current Sub Tab : List 3
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
    $this->ecformEvent->fieldset('start','','id="ecf-fs_except_1"'); // Top fieldset
    $this->ecformEvent->fieldset('end'); // Enf of Bottom fieldset
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');
    return $output;
  }
  /**
   * Large calendar settings tab
   *
   * @return string     HTML
   */
   function funcinsMenu_LargeCal() {
    $lmx = 13;
    $drop_down_page = wp_dropdown_pages('echo=0');
    $drop_down_page = str_replace('page_id','ecopt_lc_page',$drop_down_page);
    if($this->ecopt_lc_page) {
      $search = 'value="'.$this->ecopt_lc_page.'"';
      $replace = $search.' selected="selected"';
      $drop_down_page = str_replace($search,$replace,$drop_down_page);
    }
    $this->ecformEvent->curtab('item2'); //Current Tab : Large Calendar
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
      $this->ecformEvent->fieldset('start',_c('Basic settings','events-calendar'),'class="ecf-fieldset" id="ecf-fs_lcbs"','class="ecf-legend_fieldset"'); // LC Basic Settings top fieldset
        $this->ecformEvent->text(_c('Large Calendar, dominant color','events-calendar'),'ecopt_lc_ecdc',$this->ecopt_lc_ecdc,'',7,7,'','class="iColorPicker"','','id="ecf-endtime"');
        $this->ecformEvent->select(_c('Today Background image','events-calendar'), 'ecopt_lc_todaybgimg',$this->ecopt_lc_todaybgimg,$this->ec_imgDirList(),'', _c('This file must be into the &quot;user/images&quot; plugin directory.<hr>If you prefer a background color click on my label.','events-calendar'),'','<img onclick="javascript:showImg(\'ecopt_lc_todaybgimg\');" class="showImg">','single',12,'id="ecf-lc_todaybgimg"'.($this->ecopt_lc_todaybgcol?' style="display:none"':''));
        $this->ecformEvent->text(_c('Today Background color','events-calendar'),'ecopt_lc_todaybgcol',$this->ecopt_lc_todaybgcol,'',7,7,'','class="iColorPicker"','<img src="'.EVENTSCALENDARIMAGESURL.'/ques_mark_inv.png" style="margin:2px 3px 0;" tooltiptext="'._c('If you prefer a background image click on my label.','events-calendar').'"/>','id="ecf-lc_todaybgcol"'.($this->ecopt_lc_todaybgcol?'':' style="display:none"'));
        $this->ecformEvent->radio(_c('Date position','events-calendar'),'ecopt_lc_datepos',$this->ecopt_lc_datepos,array('ecopt_lc_dpleft'=>_c('Left','events-calendar'),'ecopt_lc_dpcenter'=>_c('Center','events-calendar'),'ecopt_lc_dpright'=>_c('Right','events-calendar')),'','',_c('The position of the date in the cell of a day.','events-calendar'));
      $this->ecformEvent->fieldset('end'); // Enf of Basic settings fieldset
      $this->ecformEvent->fieldset('start',_c('Tooltips Settings','events-calendar'),'class="ecf-fieldset" id="ecf-fs_lctts"','class="ecf-legend_fieldset"'); // Tooltips fieldset
        $this->ecformEvent->select(_c('Date Format'),'ecopt_lc_ttdf',$this->ecopt_lc_ttdf,$this->show_date_formats('date','ecopt_lc_ttdf'),'','','', $this->dtPostExt('date', 'lc_ttdf'), 'single', 6);
        $this->ecformEvent->select(_c('Time Format'),'ecopt_lc_tttf',$this->ecopt_lc_tttf,$this->show_date_formats('time','ecopt_lc_tttf'),'', '','', $this->dtPostExt('time', 'lc_tttf'), 'single', 6);
        $this->ecformEvent->checkbox_trigger(_c('Fixed?','events-calendar'),'ecopt_lc_fixed','',isset($this->ecopt_lc_fixed),_c('Track is useful if links are to click in the tooltip','events-calendar'));
        $this->ecformEvent->checkbox(_c('Display','events-calendar'),'ecopt_lc_tt_disp',$this->ecopt_lc_tt_disp,array('ecopt_lc_tt_disp0'=>_c('Event Type','events-calendar'),'ecopt_lc_tt_disp1'=>_c('Description','events-calendar'),'ecopt_lc_tt_disp2'=>_c('Location','events-calendar'),'ecopt_lc_tt_disp3'=>_c('Link out','events-calendar'),'ecopt_lc_tt_disp4'=>_c('Phase','events-calendar'),'ecopt_lc_tt_disp5'=>_c('Participation','events-calendar'),'ecopt_lc_tt_disp6'=>_c('Link to post','events-calendar')),'', 'vertical','', '', '2');
      $this->ecformEvent->fieldset('end'); // Enf of Tooltips fieldset
      $this->ecformEvent->fieldset('start','','class="ecf-fieldset" id="ecf-fs_lcbc"','class="ecf-legend_fieldset"'); // Click behavior fieldset
        $this->ecformEvent->checkbox_trigger(_c('Trigger the Thickbox on click event?','events-calendar'),'ecopt_lc_dtb','',isset($this->ecopt_lc_dtb));
        $this->ecformEvent->fieldset('start','','id="ecf-fs_lclnk"'); // Invisible fieldset
          $this->ecformEvent->custom_code('','','<p id="ecf-txt_lctbs">'._c('No Thickbox? Ok, so chose a trigger on click.','events-calendar').'</p>');
          $this->ecformEvent->radio(_c('Link to','events-calendar'),'ecopt_lc_clklink',$this->ecopt_lc_clklink,array('ecopt_lc_lkpost'=>_c('Associated post','events-calendar'),'ecopt_lc_lklkout'=>_c('Link out','events-calendar'),'ecopt_lc_lknone'=>_c('None','events-calendar')));
        $this->ecformEvent->fieldset('end'); // Enf of Invisible fieldset
        $this->ecformEvent->fieldset('start','','id="ecf-fs_lctbs"'); // Invisible fieldset
          $this->ecformEvent->custom_code(_c('Thickbox Settings','events-calendar'),'','&nbsp;','','','','id="ecopt_lab-lctbset"');
          $this->ecformEvent->select(_c('Date Format'),'ecopt_lc_tbdf',$this->ecopt_lc_tbdf,$this->show_date_formats('date','ecopt_lc_tbdf'),'', '','', $this->dtPostExt('date', 'lc_tbdf'), 'single', 6);
          $this->ecformEvent->select(_c('Time Format'),'ecopt_lc_tbtf',$this->ecopt_lc_tbtf,$this->show_date_formats('time','ecopt_lc_tbtf'),'', '','', $this->dtPostExt('time', 'lc_tbtf'), 'single', 6);
          $this->ecformEvent->select(_c('Title Date Format','events-calendar'),'ecopt_lc_dftt',$this->ecopt_lc_dftt,$this->show_date_formats('title','ecopt_lc_dftt'),'','','',$this->dtPostExt('date', 'lc_dftt'), 'single',6);
          $this->ecformEvent->fieldset('start',_c('Display by order','events-calendar'),'class="ecf-fieldset-in" id="ecf-fs_lcdbo"','class="ecf-legend_fieldset"',_c('fs = into a fieldset, order 0 = no display','events-calendar')); // Display by order fieldset
            $this->ecformEvent->select(substr(_c('Event Type','events-calendar'),0,$lmx),'ecopt_lc_tbd_evt',$this->ecopt_lc_tbd_evt,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
            $this->ecformEvent->select(substr(_c('Description','events-calendar'),0,$lmx),'ecopt_lc_tbd_des',$this->ecopt_lc_tbd_des,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
            $this->ecformEvent->select(substr(_c('Location','events-calendar'),0,$lmx),'ecopt_lc_tbd_loc',$this->ecopt_lc_tbd_loc,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
            $this->ecformEvent->select(substr(_c('Link out','events-calendar'),0,$lmx),'ecopt_lc_tbd_lko',$this->ecopt_lc_tbd_lko,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
            $this->ecformEvent->select(substr(_c('Address','events-calendar'),0,$lmx),'ecopt_lc_tbd_adr',$this->ecopt_lc_tbd_adr,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
            $this->ecformEvent->select(substr(_c('Manager','events-calendar'),0,$lmx),'ecopt_lc_tbd_man',$this->ecopt_lc_tbd_man,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
            $this->ecformEvent->select(substr(_c('Contact','events-calendar'),0,$lmx),'ecopt_lc_tbd_ctc',$this->ecopt_lc_tbd_ctc,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
            $this->ecformEvent->select(substr(_c('Phase','events-calendar'),0,$lmx),'ecopt_lc_tbd_pha',$this->ecopt_lc_tbd_pha,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
            $this->ecformEvent->select(substr(_c('Participation','events-calendar'),0,$lmx),'ecopt_lc_tbd_par',$this->ecopt_lc_tbd_par,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
            $this->ecformEvent->select(substr(_c('Cost','events-calendar'),0,$lmx),'ecopt_lc_tbd_cst',$this->ecopt_lc_tbd_cst,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
            $this->ecformEvent->select(substr(_c('Post link','events-calendar'),0,$lmx),'ecopt_lc_tbd_lkp',$this->ecopt_lc_tbd_lkp,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
            $this->ecformEvent->select(substr(_c('GMap link','events-calendar'),0,$lmx),'ecopt_lc_tbd_lkg',$this->ecopt_lc_tbd_lkg,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
            $this->ecformEvent->select(substr(_c('GMap iFrm','events-calendar'),0,$lmx),'ecopt_lc_tbd_ggm',$this->ecopt_lc_tbd_ggm,$this->tbDispOrder_arr,'', '','', '', 'single', 12);
            $this->ecformEvent->select(substr(_c('Cust fields','events-calendar'),0,$lmx),'ecopt_lc_tbd_csf',$this->ecopt_lc_tbd_csf,$this->tbDispOrderWfs_arr,'', '','', '', 'single', 12);
          $this->ecformEvent->fieldset('end'); // Enf of Display by order fieldset
        $this->ecformEvent->fieldset('end'); // Enf of invisible fieldset
      $this->ecformEvent->fieldset('end'); // Enf of invisible fieldset
      $this->ecformEvent->fieldset('start',_c('Display in a thickbox','events-calendar'),'class="ecf-fieldset" id="ecf-fs_lcitb"','class="ecf-legend_fieldset"',_c('It\'s a display from a page link','events-calendar')); // Display by order fieldset
        $this->ecformEvent->checkbox_trigger(_c('Check for yes','events-calendar'),'ecopt_lc_itb','',isset($this->ecopt_lc_itb));
        $this->ecformEvent->custom_code(_c('Select a page','events-calendar'),'ecopt_lc_page',$drop_down_page,_c('A blank published page, no need more','events-calendar'),'','','class="fieldRowselect"','class="fieldCellselect"');
      $this->ecformEvent->fieldset('end'); // Enf of Display in a thickbox fieldset
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');
    return $output;
  }
  /**
   * Events : Events choices tab (labeled Settings)
   *
   * @return string     HTML
   */
  function funcinsSubMenu_Choices() {
    // Event Date Entry Order array
    $evdeo = array('mdy'=>_c('Month->Day->Year','events-calendar'),
                   'dmy'=>_c('Day->Month->Year','events-calendar'),
                   'ydm'=>_c('Year->Day->Month','events-calendar'),
                   'myd'=>_c('Month->Year->Day','events-calendar'),
                   'ymd'=>_c('Year->Month->Day','events-calendar'));
    $this->ecformEvent->curtab('item3'); //Current Tab : Events
    $this->ecformEvent->cursubtab('s20'); //Current Sub Tab : Choices
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
      $this->ecformEvent->fieldset('start',_c('Basic settings','events-calendar'),'class="ecf-fieldset" id="ecf-fs_evbs"','class="ecf-legend_fieldset"'); // Top fieldset
        $this->ecformEvent->checkbox_trigger(_c('Access to the "Extended" tab?','events-calendar'),'ecopt_ev_ext','',isset($this->ecopt_ev_ext));
        $this->ecformEvent->checkbox_trigger(_c("Allow events types?",'events-calendar'),'ecopt_ev_types','',isset($this->ecopt_ev_types));
        $this->ecformEvent->checkbox_trigger(_c("Allow phase field?",'events-calendar'),'ecopt_ev_phase','',isset($this->ecopt_ev_phase));
        $this->ecformEvent->checkbox_trigger(_c("Allow participation field?",'events-calendar'),'ecopt_ev_part','',isset($this->ecopt_ev_part));
        $this->ecformEvent->checkbox_trigger(_c("Allow creation of a post?",'events-calendar'),'ecopt_ev_post','',isset($this->ecopt_ev_post));
        $this->ecformEvent->select(_c('Dates entry order'),'ecopt_ev_deo',$this->ecopt_ev_deo,$evdeo,'',_c('Option fields for Start and End Date of event.','events-calendar'),'','', 'single',5);
        $this->ecformEvent->checkbox_trigger(_c("Military time format?",'events-calendar'),'ecopt_ev_miltime','',isset($this->ecopt_ev_miltime),_c('This is the time format without AM or PM','events-calendar'));
      $this->ecformEvent->fieldset('end'); // Enf of Basic settings fieldset
      $this->ecformEvent->fieldset('start',_c('Recurrence  settings','events-calendar'),'class="ecf-fieldset" id="ecf-fs_evrs"','class="ecf-legend_fieldset"'); // Top fieldset
        $this->ecformEvent->checkbox_trigger(_c('Management of recurrent events?','events-calendar'),'ecopt_ev_recc','',isset($this->ecopt_ev_recc));
        $this->ecformEvent->fieldset('start','','id="ecf-fs_evrecc"'); // Invisible fieldset
          $this->ecformEvent->checkbox_trigger(_c('Management of the exceptions of recurrences?','events-calendar'),'ecopt_ev_exrec','',isset($this->ecopt_ev_exrec));
          $this->ecformEvent->fieldset('start',_c('Colors associated with each type of recurrence','events-calendar'),'class="ecf-fieldset-in" id="ecf-fs_evtcol"','class="ecf-legend_fieldset"'); // Top fieldset
            $this->ecformEvent->text(wpec_recLabel(1),'ecopt_ev_rec1',$this->ecopt_ev_rec1,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->text(wpec_recLabel(2),'ecopt_ev_rec2',$this->ecopt_ev_rec2,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->text(wpec_recLabel(3),'ecopt_ev_rec3',$this->ecopt_ev_rec3,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->text(wpec_recLabel(4),'ecopt_ev_rec4',$this->ecopt_ev_rec4,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->text(wpec_recLabel(6),'ecopt_ev_rec6',$this->ecopt_ev_rec6,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->text(wpec_recLabel(7),'ecopt_ev_rec7',$this->ecopt_ev_rec7,'',7,7,'','class="iColorPicker"');
            $this->ecformEvent->text(wpec_recLabel(8),'ecopt_ev_rec8',$this->ecopt_ev_rec8,'',7,7,'','class="iColorPicker"');
          $this->ecformEvent->fieldset('end'); // Enf of Colors associated fieldset
        $this->ecformEvent->fieldset('end'); // Enf of invisible fieldset
      $this->ecformEvent->fieldset('end'); // Enf of Recurrence  settings fieldset
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');
    return $output;
  }
  /**
   * Events : Types list management tab
   *
   * @return string     HTML
   */
  function funcinsSubMenu_Types() {
    $this->ecformEvent->curtab('item3'); //Current Tab : Events
    $this->ecformEvent->cursubtab('s21'); //Current Sub Tab : Choices
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
      $this->ecformEvent->fieldset('start','','id="ecf-fs_evtypes"'); // Evnt Types fieldset
        $this->ecformEvent->custom_code('&nbsp;','types-grid','<table id="types-grid" class="scroll" cellpadding="0" cellspacing="0"></table><div id="types-pager" class="scroll" style="text-align:center;"></div>','','','','id="types-row"','');
        $this->ecformEvent->text('&nbsp;','ecopt_sertypes',stripslashes(htmlspecialchars($this->ecopt_sertypes)),'',1,20000,_c('Click on a row to edit, Enter for save and Escape for cancel.<br/>The names of custom fields are seized to the chain and separated by a semicolon.<br/>ie. &quot;First field;Second field; etc&quot;','events-calendar'),'READONLY style="width:0;margin:0;border:none;background-color:#fff7ef;"');
      $this->ecformEvent->fieldset('end'); // Enf of Evnt Types fieldset
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');
    return $output;
  }
  /**
   * About : Help form tab
   *
   * @return string     HTML
   */
  function funcinsSubMenu_Help() {
    $this->ecformEvent->curtab('item4'); //Current Tab : About
    $this->ecformEvent->cursubtab('s30'); //Current Sub Tab : Help
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
    $this->ecformEvent->fieldset('start','','id="ecf-fs_except_1"'); // Top fieldset
    $this->ecformEvent->fieldset('end'); // Enf of Bottom fieldset
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');
    return $output;
  }

  /**
   * About : Uninstall form tab
   *
   * @return string     HTML
   */
  function funcinsSubMenu_Uninstall() {
    $this->ecformEvent->curtab('item4'); //Current Tab : About
    $this->ecformEvent->cursubtab('s31'); //Current Sub Tab : Uninstall
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
    $this->ecformEvent->fieldset('start','','id="ecf-fs_except_1"'); // Top fieldset
    $this->ecformEvent->fieldset('end'); // Enf of Bottom fieldset
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');
    return $output;
  }

  /**
   * About : Credits form tab
   *
   * @return string     HTML
   */
  function funcinsSubMenu_Credits() {
    $this->ecformEvent->curtab('item4'); //Current Tab : About
    $this->ecformEvent->cursubtab('s32'); //Current Sub Tab : Credits
    $this->ecformEvent->fieldset('start','','class="ecf-fieldset_main"'); // Invisible main fieldset
    $this->ecformEvent->fieldset('start','','id="ecf-fs_except_1"'); // Top fieldset
    $this->ecformEvent->fieldset('end'); // Enf of Bottom fieldset
    $this->ecformEvent->fieldset('end'); // Enf of main fieldset
    $output .= $this->ecformEvent->display('body');
    return $output;
  }
}
endif;
?>