<?php
/*
Plugin Name: WP Events Calendar
Plugin URI: http://www.wp-eventscalendar.com/
Description: Visit http://www.wp-eventscalendar.com/ for help and to report bugs.
Version: 7.0-dev
Author: Luke Howell
Author URI: http://www.lukehowell.com/

---------------------------------------------------------------------------
This file is part of the WP Events Calendar project.
  
For questions, help, comments, discussion, etc., please join our
forum at {@link http://www.wp-eventscalendar.com/forum}. You can
also go to Luke's ({@link http://www.lukehowelll.com}) blog.
 
WP Events Calendar is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
-----------------------------------------------------------------------------
*/

/**
 * This file contains the WP Events Calendar main file.
 *
 * Long description to be done.
 *
 * @package			WP-Events-Calendar
 * @subpackage 	Core
 * @author        
 *                - Luke Howell <luke@wp-eventscalendar.com>
 *                - Brad Bodine <brad@wp-eventscalendar.com>
 * @link          
 *                - http://wp-eventscalendar.com/
 *                - http://www.lukehowell.com
 *                - http://myboxtool.com/
 * @since         1.0.0
 * @copyright     
 *                - Copyright (c) 2007-2009 Luke Howell
 *                - Copyright (c) 2007-2009 Brad Bodine
 * @license			GPLv3 {@link http://www.gnu.org/licenses/gpl}
 * @filesource
 *
 */ 

/** Events-Calendar version */
define('EVENTSCALENDARVERS', 'Version: 7.0-dev');
/** Dedicaced to the WP 2.8*/
/** This define prevents the concatenation of scripts and CSS until a better solution.*/
define('SCRIPT_DEBUG', true);
/** Defines the plugin absolute path */
define('EVENTSCALENDARPATH', ABSPATH.'wp-content/plugins/events-calendar');
/** Defines the absolute path to the user path within the EC directory */
define('EVENTSCALENDARUSERPATH', ABSPATH.'wp-content/plugins/events-calendar/user');
/** Defines the relative path to the user path within the EC directory */
define('EVENTSCALENDARGLOBPATH', '../wp-content/plugins/events-calendar/user');
/** Defines WPEC absolute path for the classes */
define('EVENTSCALENDARCLASSPATH', EVENTSCALENDARPATH);
/** Defines the images relative path */
define('EVENTSCALENDARIMAGESPATH', '../wp-content/plugins/events-calendar/images');
/** Defines the plugin URL */
define('EVENTSCALENDARURL', get_bloginfo('wpurl').'/wp-content/plugins/events-calendar');
/** Defines the JS URL */
define('EVENTSCALENDARJSURL', EVENTSCALENDARURL.'/js');
/** Defines the CSS URL */
define('EVENTSCALENDARCSSURL', EVENTSCALENDARURL.'/css');
/** Defines the images URL */
define('EVENTSCALENDARIMAGESURL', EVENTSCALENDARURL.'/images');
/** Defines the user images URL */
define('EVENTSCALENDARUSRIMAGESURL', EVENTSCALENDARURL.'/user/images');
/** Defines the absolute path of the WP include directory */
define('ABSWPINCLUDE', ABSPATH.WPINC);
/** Defines the server URI */
define('EVENTSCALENDARSRVURI', $_SERVER['REQUEST_URI']);

/** Defines global Wordpress inherited constants **/
/** Defines the first day of the week */
define('WPECFDW', get_option('start_of_week'));

/** Load the EC functions library */
require_once(EVENTSCALENDARCLASSPATH.'/ec_functions.php');

/** Load the EC DB class */
require_once(EVENTSCALENDARCLASSPATH.'/ec_db.class.php');

/*
* Ajax Entry to Display the widget Calendar content
*/
if(isset($_GET['EC_action']) && $_GET['EC_action'] == 'switchMonth') {
  require_once(EVENTSCALENDARCLASSPATH.'/ec_widget-calendar.class.php');
  $calendar = new EC_WCalendar();
  $calendar->displayWidget($_GET['EC_year'], $_GET['EC_month'], true);
  exit();
}

if (is_admin()) { // if admin mode entry
/**
* Ajax Entries
*/
  if(isset($_GET['EC_action'])) {
    switch ($_GET['EC_action']) {
    // Actions required by the rest of teh plugin  
    case 'edit': case 'navigILList': case 'navigList': case 'switchMonthLarge':
    case 'switchMonthAdmin': case 'switchMonth': 
      break;
    /**
    * Get jSON datas for admin calendar 
    */
    case 'ajaxGetMonthEvents': 
      require_once(EVENTSCALENDARCLASSPATH.'/ec_admin-calendar.class.php');
      $evmonth = new EC_ACalendar();
      if(isset($_GET['EC_year'])) $evmonth->calendarData($_GET['EC_year'], $_GET['EC_month']);
      else $evmonth->calendarData($_GET['EC_start'], $_GET['EC_end']);
      exit();
    /**
    * Get cust field names in events management 
    */
    case 'ajaxCustFieldNames': 
      ajaxGetCustFieldNames();  
      exit();
    /**
    * Get events informations from a date (in events manager form) 
    */
    case 'ajaxGetEvent': 
      require_once(EVENTSCALENDARCLASSPATH.'/ec_ajaxday.class.php');
      $day = new EC_ajaxDay();
      $day->ajaxDisplay($_GET['EC_date']);
      exit();
    /**
    * Delete an event in database
    */
    case 'ajaxDelete': 
      $db = new EC_DB();
      $db->deleteEvent($_GET['EC_id']);
      exit(); 
    /**
    * Uncanceling an exception in admin calendar 
    */
    case 'ajaxActivExcept': 
      $db = new EC_DB();
      $db->activExcept($_GET['EC_id'], $_GET['EC_start']);
      exit();
    /**
    * Canceling a recurrence in admin calendar
    */
    case 'ajaxCancelRec': 
      $db = new EC_DB();
      $db->cancelRec($_GET['EC_id'], $_GET['EC_start']);
      exit();
    /**
    * Move a recurrence date in admin calendar
    */
    case 'ajaxMoveRec': 
      $db = new EC_DB();
      $db->moveRec($_GET['EC_id'], $_GET['EC_start'], $_GET['EC_new'], $_GET['EC_org']);
      exit();
    /**
    * Move a event date in admin calendar
    */
    case 'ajaxMoveEvent': 
      $db = new EC_DB();
      $db->moveEvent($_GET['EC_id'], $_GET['EC_new']);
      exit();
    default: exit();
    }
  }

  /**
	* Register Widget modules, only if the theme is widget ready, and if we are in the widget control page.
   */
  function EventsCalendarINIT() {
    global $ec_widget_ec, $ec_widget_evlist_with_recc, $ec_widget_evlist_without_recc;
    if(function_exists('register_sidebar_widget') && strstr(EVENTSCALENDARSRVURI, 'widget')) {
      require_once(EVENTSCALENDARCLASSPATH.'/ec_widget.class.php');
      $widget = new EC_Widget();
      // Register the Widget Events Calendar (little calendar)
      $wtitle = _c('Events Calendar','events-calendar');
      wp_register_sidebar_widget('events-calendar',$wtitle,array(&$widget, 'displayWCalendar'),array('classname' => 'events_calendar', 'description' => _c('Displays Events Calendar Widget','events-calendar')));      
      wp_register_widget_control('events-calendar',$wtitle,array(&$widget, 'widgetControlCalendar'));
      // Register the Widget Events List 1 (with recc events)
      $wtitle = _c('EC List 1','events-calendar');
      wp_register_sidebar_widget('events-list-1',$wtitle,array(&$widget, 'displayWEvILList'),array('classname' => 'events-recc-list', 'description' => _c('Displays Events List With Recurrences','events-calendar')));      
      wp_register_widget_control('events-list-1',$wtitle,array(&$widget, 'widgetControlEvILList'));
      // Register the Widget Events List 2 (WITHOUT recc events, ILayer)
      $wtitle = _c('EC List 2','events-calendar');
      wp_register_sidebar_widget('events-list-2',$wtitle,array(&$widget, 'displayWEvList'),array('classname' => 'events-il-list', 'description' => _c('Displays Events List Without Recurrences','events-calendar')));      
      wp_register_widget_control('events-list-2',$wtitle,array(&$widget, 'widgetControlEvList'));
    }
  }
  /**
  * Init Management objets
  * This function creates the admin menu and inserts the needed javascript through wp_enqueue_script().
  */
  function EventsCalendarManagementINIT() {
    global $wp_version, $is_IE;
    $options_rights = wpec_usercan();
    /* Right 0 => Access to the management of Events-Calendar */
    $EC_userLevel = $options_rights['user_rights'][0] ? 'level_0' : 'level_10';  
    add_menu_page(__('Events Calendar','events-calendar'), __('Events Calendar','events-calendar'), $EC_userLevel, 'events-calendar-main', array(&$management, 'display'));
    if ($wp_version < 2.7) 
      add_submenu_page('events-calendar-main', __('Events Calendar','events-calendar'), __('Calendar','events-calendar'), $EC_userLevel,  'events-calendar-main', array(&$options, 'calendarOptions'));
    /*  Rights :
      *   7 => Access to all the options
      *   8 => Access to options without rights management
      *   9 => Access to options without evts types managmnt
    */
    $EC_userLevel = ($options_rights['user_rights'][7] || $options_rights['user_rights'][8] || $options_rights['user_rights'][9])? 'level_0' : 'level_10';
    add_submenu_page('events-calendar-main', __('Events Calendar Options','events-calendar'), __('Options','events-calendar'), $EC_userLevel, 'events-calendar-options', array(&$options, 'calendarOptions'));
    /* Right 10 => Access to the import/export of events */
    $EC_userLevel = $options_rights['user_rights'][10] ? 'level_0' : 'level_10';
    add_submenu_page('events-calendar-main', __('Events Calendar Import/Export','events-calendar'), __('Import/Export','events-calendar'), $EC_userLevel, 'events-calendar-impexp', array(&$impexp, 'ec_ImportExport'));
    /* Right 1 => Creation of events */
    $EC_userLevel = $options_rights['user_rights'][1] ? 'level_0' : 'level_10';
    add_submenu_page('events-calendar-main', __('Events Calendar Add Event','events-calendar'), __('Add Event','events-calendar'), $EC_userLevel, 'events-calendar-manage', array(&$addevent, 'ec_manEventsForm'));
    //add_submenu_page('events-calendar', __('Events Calendar','events-calendar'), __('Add Event','events-calendar'), $EC_userLevel, '#addEventform', '');
    $page = parse_url(EVENTSCALENDARSRVURI); $page = $page[query]; parse_str($page);
    if($EC_action == 'edit') $page = 'events-calendar-manage';
    /**
    * Here we need the jQuery last version 1.3.2
    * So - if WP vers is older than 2.8 - we deregister the old version of jQuery and we use the one in the plugin 
    */
    if ($wp_version < 2.8) {         
      wp_deregister_script( 'jquery' );
      wp_register_script( 'jquery', EVENTSCALENDARJSURL.'/jquery.js', false, '1.3.2' );
      //wp_register_script( 'jquery', 'http://ajax.googleapis.com/ajax/libs/jquery/1.3.2/jquery.min.js', false, '1.3.2' );
    }
    switch ($page) {
      case 'events-calendar-manage' :
        require_once(EVENTSCALENDARCLASSPATH.'/ec_management.class.php');
        $management = new EC_Management();
        require_once(EVENTSCALENDARCLASSPATH.'/ec_manage-event.class.php');
        $addevent = new EC_ManageEvents();
        insertJsDateClockPicker();
        insertJqTooltips();
        wp_enqueue_script('autotab', '/wp-content/plugins/events-calendar/js/jquery.autotab.js', array('jquery'), '1.0');        
        wp_enqueue_script('ecroundedcorners', '/wp-content/plugins/events-calendar/js/ec_rounded-corners.js');
        wp_enqueue_script('ectooltips', '/wp-content/plugins/events-calendar/js/ec_tooltip.js');        
        // if (user_can_richedit())
        wp_enqueue_script(�tiny_mce�, '/wp-includes/js/tinymce/tiny_mce.js','','');
        break;
      case 'events-calendar-options' :
        require_once(EVENTSCALENDARCLASSPATH.'/ec_options.class.php');
        $options = new EC_Options();   
        wp_enqueue_script('jqgrid', '/wp-content/plugins/events-calendar/js/jgrid/jquery.jqGrid.js', array('jquery'), '3.3.1');
        wp_enqueue_script('jqgridDnR', '/wp-content/plugins/events-calendar/js/jgrid/jqDnR.js', array('jquery'), '1.0');
        wp_enqueue_script('jqgridModal', '/wp-content/plugins/events-calendar/js/jgrid/jqModal.js', array('jquery'), '1.0');
        wp_enqueue_script('ecroundedcorners', '/wp-content/plugins/events-calendar/js/ec_rounded-corners.js', array('jquery'), '1.0');
        if($is_IE)wp_enqueue_script('jquerybgiframe', '/wp-content/plugins/events-calendar/js/jquery.bgiframe.js', array('jquery'), '2.1');
        wp_enqueue_script('ectooltips', '/wp-content/plugins/events-calendar/js/ec_tooltip.js', array('jquery'), '1.0');
        //wp_enqueue_script('ecoptions', '/wp-content/plugins/events-calendar/js/ec-options.js', array('jquery'), '1.0');
        break;
      case 'events-calendar-impexp' :
        require_once(EVENTSCALENDARCLASSPATH.'/ec_impexp.php');
        $impexp = new EC_ImpExp();
        break;      
      default: // = ($page == 'events-calendar-main') 
        require_once(EVENTSCALENDARCLASSPATH.'/ec_management.class.php');
        $management = new EC_Management();
        insertJqTooltips();
        wp_enqueue_style('fullcalendar', '/wp-content/plugins/events-calendar/css/fullcalendar.css', false, '', 'screen' );
        wp_enqueue_style('jquery-alerts', '/wp-content/plugins/events-calendar/css/jquery.alerts.css', false, '', 'screen' );
        wp_enqueue_script('ec-form', '/wp-content/plugins/events-calendar/js/ec-form.js', '', '1.0');                
        wp_enqueue_script('jquery-ui-ecuicore', '/wp-content/plugins/events-calendar/js/ui.core.js', array('jquery'), '1.7');
        wp_enqueue_script('jquery-ui-draggable', '/wp-content/plugins/events-calendar/js/ui.draggable.js', array('jquery'), '1.7');
        wp_enqueue_script('jquery-fullcalendar', '/wp-content/plugins/events-calendar/js/fullcalendar.js', array('jquery'), '1.2.1');
        wp_enqueue_script('jquery-alerts', '/wp-content/plugins/events-calendar/js/jquery.alerts.js', array('jquery'), '1.2.1');
    	break;
    }
  }
  /**
  * Insert Date & Clock Pickers JS files
  *
  * @global string Used to load the correct datepicker language file
  */
  function insertJsDateClockPicker() {
    global $loc_lang;
    wp_enqueue_script('jquery-ui-core', '/wp-content/plugins/events-calendar/js/ui.core.min.js', array('jquery'), '1.5.2');
    wp_enqueue_script('jquery-ui-datepicker', '/wp-content/plugins/events-calendar/js/ui.datepicker.js', array('jquery'), '1.5.2');
    if ($loc_lang != 'en') wp_enqueue_script('jquery-ui-datepicker-lang', '/wp-content/plugins/events-calendar/js/i18n/ui.datepicker-'.$loc_lang.'.js', array('jquery'), '1.5.2');
    wp_enqueue_script('jquery-clockpicker', '/wp-content/plugins/events-calendar/js/jquery.clockpick.min.js', array('jquery'), '1.2.4');
  }
  /**
  * Insert jQuery Tooltips
  */
  function insertJqTooltips() {
    wp_enqueue_script('jquery-bgiframe', '/wp-content/plugins/events-calendar/js/jquery.bgiframe.js', array('jquery'), '2.1');
    wp_enqueue_script('jquery-dimensions', '/wp-content/plugins/events-calendar/js/jquery.dimensions.js', array('jquery'), '1.0b2');
    wp_enqueue_script('jquery-tooltip', '/wp-content/plugins/events-calendar/js/jquery.tooltip.js', array('jquery'), '1.3');
  }
  /**
  * Inserts the Admin registration style sheets.
  */
  function EventsCalendarAdminHeaderScript() {
    $page = parse_url(EVENTSCALENDARSRVURI); $page = $page[query]; parse_str($page);
    //echo $page;
    if  ($page == 'events-calendar-main' && $EC_action != 'edit') {
   

    } elseif ($page == 'events-calendar-manage' || $EC_action == 'edit') {    
?>
<link type="text/css" rel="stylesheet" media="screen" href="<?php echo EVENTSCALENDARCSSURL;?>/events-calendar-management.css" />
<link type="text/css" rel="stylesheet" media="screen" href="<?php echo EVENTSCALENDARCSSURL;?>/ui.datepicker.css" />
<link type="text/css" rel="stylesheet" media="screen" href="<?php echo EVENTSCALENDARCSSURL;?>/clockpick.css" />
<link type="text/css" rel="stylesheet" media="screen" href="<?php echo EVENTSCALENDARCSSURL;?>/jgrid/basic/grid.css"/>
<link type="text/css" rel="stylesheet" media="screen" href="<?php echo EVENTSCALENDARCSSURL;?>/ec_tooltip.css" />
<link type="text/css" rel="stylesheet" media="screen" href="<?php echo EVENTSCALENDARCSSURL;?>/ec_manage-event.css" />
<link type="text/css" rel="stylesheet" media="screen" href="<?php echo EVENTSCALENDARCSSURL;?>/events-calendar.css" />
<?php
    } elseif ($page == 'events-calendar-options') {
?>
<script type="text/javascript">
var iconcolorpicker = "<?php echo EVENTSCALENDARIMAGESURL;?>/pipette.gif"
var witnesscolorpicker = "<?php echo EVENTSCALENDARIMAGESURL;?>/witness.gif"
</script>
<script type="text/javascript" src="<?php echo EVENTSCALENDARJSURL;?>/iColorPicker.js"></script>
<link type="text/css" rel="stylesheet" media="screen" href="<?php echo EVENTSCALENDARCSSURL;?>/jgrid/steel/grid.css"/>
<link type="text/css" rel="stylesheet" media="screen" href="<?php echo EVENTSCALENDARCSSURL;?>/jgrid/jqModal.css"/>
<link type="text/css" rel="stylesheet" media="screen" href="<?php echo EVENTSCALENDARCSSURL;?>/ec_tooltip.css" />
<link type="text/css" rel="stylesheet" media="screen" href="<?php echo EVENTSCALENDARCSSURL;?>/ec_options.css" />
<?php
    }
  }
  add_action('admin_menu', 'EventsCalendarManagementINIT');
  add_action('admin_head', 'EventsCalendarAdminHeaderScript');  
  add_action('activate_events-calendar/events-calendar.php', 'EventsCalendarActivated');
  add_action('plugins_loaded', 'EventsCalendarINIT');
  
} else {  // If front blog entry----------------------------------------------------------------------------------------

  //require_once(ABSWPINCLUDE.'/pluggable.php');
  require_once(ABSWPINCLUDE.'/capabilities.php');
  $wp_rewrite = new WP_Rewrite;
  /*
  * Display de large calender thickbox 
  */
  if(isset($_GET['EC_action']) && $_GET['EC_action'] == 'tblcal') {
    class_exists('EC_LCalendar') || require(EVENTSCALENDARCLASSPATH.'/ec_large-calendar.class.php');
    $tblcalendar = new EC_LCalendar();
    $tblcalendar->displayTBLarge();    
    exit();
  }
  /*
  * Display de thickbox content : 1 day
  */
  if(isset($_GET['EC_view']) && $_GET['EC_view'] == 'day') {
    $EC_date = date('Y-m-d', mktime(0, 0, 0, $_GET['EC_month'], $_GET['EC_day'], $_GET['EC_year']));
    require_once(EVENTSCALENDARCLASSPATH.'/ec_day.class.php');
    $day = new EC_Day();
    $day->display($EC_date, $_GET['EC_recc']);
    exit();
  }
  /*
  * Ajax Entry to Display the Large Calendar in a post
  */
  if(isset($_GET['EC_action']) && $_GET['EC_action'] == 'switchMonthLarge') {
    require_once(EVENTSCALENDARCLASSPATH.'/ec_large-calendar.class.php');
    $lcalendar = new EC_LCalendar();
    $lcalendar->displayLarge($_GET['EC_year'], $_GET['EC_month']);
    exit();
  }
  /*
  * Ajax Entry to Display the Basic Events List (without recc events))
  */
  if(isset($_GET['EC_action']) && $_GET['EC_action'] == 'navigList') {
    require_once(EVENTSCALENDARCLASSPATH.'/ec_event-list.class.php');
    $evlist = new EC_EventList();
    $evlist->displayEventList($_GET['EC_num'], $_GET['EC_incr'], $_GET['EC_sens'], $_GET['EC_date']);
    exit();
  }
  /*
  * Ajax Entry to Display the Events ILayer List (WITH recc events))
  */
  if(isset($_GET['EC_action']) && $_GET['EC_action'] == 'navigILList') {
    require_once(EVENTSCALENDARCLASSPATH.'/ec_event-il-list.class.php');
    $evillist = new EC_EventILList();
    $evillist->displayEventILList($_GET['EC_sens'], $_GET['EC_date']);
    exit();
  }
  /**
  * Init Front Blog objets
  */
  function EventsCalendarINIT() {
    wp_enqueue_script('jquerybgiframe', '/wp-content/plugins/events-calendar/js/jquery.bgiframe.js', array('jquery'), '2.1');
    wp_enqueue_script('jquerydimensions', '/wp-content/plugins/events-calendar/js/jquery.dimensions.js', array('jquery'), '1.0b2');
    wp_enqueue_script('jquerytooltip', '/wp-content/plugins/events-calendar/js/jquery.tooltip.min.js', array('jquery'), '1.3');
    wp_enqueue_script('jqueryeventdrag', '/wp-content/plugins/events-calendar/js/jquery.event.drag-1.0.js', array('jquery'), '1.0');
    wp_enqueue_script('thickbox');
    if (function_exists('register_sidebar_widget')) {
      require_once(EVENTSCALENDARCLASSPATH.'/ec_widget.class.php');
      $widget = new EC_Widget();
      // Display the Widget Events Calendar (little calendar)
      register_sidebar_widget('events-calendar', array(&$widget, 'displayWCalendar'));
      // Display the Widget Events List 1 (with recc events)
      register_sidebar_widget('events-list-1', array(&$widget, 'displayWEvILList'));
      // Register the Widget Events List 2 (WITHOUT recc events, ILayer)
      register_sidebar_widget('events-list-2', array(&$widget, 'displayWEvList'));
    }
  }
  /**
  * Front Blog Header Script
  */
  function EventsCalendarHeaderScript() {
  ?>
  <!-- Start Of Script Generated By Events-Calendar [Luke Howell | www.lukehowell.com] and [R. MALKA | www.heirem.fr] -->
    <!--[if lt IE 7]>
      <script src="<?php echo EVENTSCALENDARJSURL;?>/IE7.js" type="text/javascript"></script>
    <![endif]-->
    <!--[if lt IE 8]>
      <script src="<?php echo EVENTSCALENDARJSURL;?>/IE8.js" type="text/javascript"></script>
    <![endif]-->

    <link type="text/css" rel="stylesheet" href="<?php bloginfo('wpurl');?>/wp-includes/js/thickbox/thickbox.css" />
    <link type="text/css" rel="stylesheet" href="<?php echo EVENTSCALENDARCSSURL;?>/events-calendar.css" />

  <?php
    require_once(ABSPATH . 'wp-admin/admin-functions.php');
    // jQuery Dom Extrem protection management
    $options = get_option('optionsEventsCalendar');
      echo '  <script type="text/javascript">',"\n\t";
      echo '// <![CDATA[',"\n\t";
        echo 'var ecd = {};',"\n\t";
        echo 'ecd.jq= jQuery.noConflict('.$options['jqueryextremstatus'].');',"\n\t";
/*        echo '(function($) {jQuery("document").ready(function(){
                jQuery("a[title=\'A propos\']").click(function(event) {
                  event.preventDefault();
                  tb_show("A propos", "'.get_bloginfo('wpurl').'?EC_action=tblcal&TB_iframe=true&width=640&height=600", false);
                });
              });
              })(jQuery);                
             ';   
*/
        echo '//]]>',"\n";
      echo '  </script>',"\n";      
    echo "<!-- End Of Script Generated By Events-Calendar - ".EVENTSCALENDARVERS." -->\n";
  }

  add_action('init', 'EventsCalendarINIT');
  add_action('wp_head', 'EventsCalendarHeaderScript');
  add_filter('the_content', 'filterEventsCalendarLarge'); // filterEventsCalendarLarge() is in ec_function.php 
} // Enf of if admin mode entry
?>